(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.1'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    129195,       3347]*)
(*NotebookOutlinePosition[    129886,       3371]*)
(*  CellTagsIndexPosition[    129842,       3367]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["SnegSimplify", "ObjectName"],

Cell[TextData[{
  "\[FilledSmallSquare] Sneg",
  StyleBox["Simplify[", "MR"],
  StyleBox["expr", "TI"],
  StyleBox["]", "MR"],
  " attempts to rewrite an expression in terms of higher level sneg \
functions."
}], "Usage"],

Cell[TextData[{
  "\[FilledSmallSquare] ",
  StyleBox["SnegSimplify", "MR"],
  " handles expressions featuring number, Hubbard, spin and hopping \
operators."
}], "Notes"],

Cell[TextData[{
  "\[FilledSmallSquare] See also: ",
  ButtonBox["sumSimplifyKD",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["sumSimplify",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["SimplifyKD",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes"],

Cell[CellGroupData[{

Cell["Further examples", "ExampleSection"],

Cell[TextData[{
  "Load sneg and declare ",
  StyleBox["c", "IT"],
  " and ",
  StyleBox["d", "IT"],
  " to be fermionic operators."
}], "ExampleText"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(<< sneg`sneg`;\)\), "\[IndentingNewLine]", 
    \(\(snegfermionoperators[c, d];\)\)}], "Input",
  CellLabel->"In[1]:="],

Cell[BoxData[
    \("sneg 1.168 Copyright (C) 2007 Rok Zitko"\)], "Print",
  CellLabel->"From In[1]:="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(number[c[]]\), "\[IndentingNewLine]", 
    \(SnegSimplify[%]\)}], "Input",
  CellLabel->"In[3]:="],

Cell[BoxData[
    RowBox[{
      RowBox[{
        TagBox[
          StyleBox[
            InterpretationBox[
              SubsuperscriptBox["c", 
                TagBox[
                  StyleBox["\<\"\[DownArrow]\"\>",
                    FontColor->RGBColor[0, 0, 1]],
                  (
                  StyleForm[ #, FontColor -> RGBColor[ 
                    0, 0, 1]]&)], "\<\"\[Dagger]\"\>"],
              Subsuperscript[ c, 
                RowBox[ {
                  StyleForm[ 
                  "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], 
                "\[Dagger]"],
              Editable->False],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm], 
        StyleBox["\[CenterDot]",
          FontColor->RGBColor[0, 0.392187, 0]], 
        TagBox[
          StyleBox[
            InterpretationBox[
              SubsuperscriptBox["c", 
                TagBox[
                  StyleBox["\<\"\[DownArrow]\"\>",
                    FontColor->RGBColor[0, 0, 1]],
                  (
                  StyleForm[ #, FontColor -> RGBColor[ 
                    0, 0, 1]]&)], "\<\"\"\>"],
              Subsuperscript[ c, 
                RowBox[ {
                  StyleForm[ 
                  "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], ""],
              Editable->False],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm]}], "+", 
      RowBox[{
        TagBox[
          StyleBox[
            InterpretationBox[
              SubsuperscriptBox["c", 
                TagBox[
                  StyleBox["\<\"\[UpArrow]\"\>",
                    FontColor->RGBColor[1, 0, 0]],
                  (
                  StyleForm[ #, FontColor -> RGBColor[ 
                    1, 0, 0]]&)], "\<\"\[Dagger]\"\>"],
              Subsuperscript[ c, 
                RowBox[ {
                  StyleForm[ "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}],
                 "\[Dagger]"],
              Editable->False],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm], 
        StyleBox["\[CenterDot]",
          FontColor->RGBColor[0, 0.392187, 0]], 
        TagBox[
          StyleBox[
            InterpretationBox[
              SubsuperscriptBox["c", 
                TagBox[
                  StyleBox["\<\"\[UpArrow]\"\>",
                    FontColor->RGBColor[1, 0, 0]],
                  (
                  StyleForm[ #, FontColor -> RGBColor[ 
                    1, 0, 0]]&)], "\<\"\"\>"],
              Subsuperscript[ c, 
                RowBox[ {
                  StyleForm[ "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}],
                 ""],
              Editable->False],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm]}]}]], "Output",
  CellLabel->"Out[3]="],

Cell[BoxData[
    TagBox[\(number[c[]]\),
      HoldForm]], "Output",
  CellLabel->"Out[4]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(hubbard[c[]]\), "\[IndentingNewLine]", 
    \(SnegSimplify[%]\)}], "Input",
  CellLabel->"In[5]:="],

Cell[BoxData[
    RowBox[{"\<\"-\"\>", 
      RowBox[{
        TagBox[
          StyleBox[
            InterpretationBox[
              SubsuperscriptBox["c", 
                TagBox[
                  StyleBox["\<\"\[DownArrow]\"\>",
                    FontColor->RGBColor[0, 0, 1]],
                  (
                  StyleForm[ #, FontColor -> RGBColor[ 
                    0, 0, 1]]&)], "\<\"\[Dagger]\"\>"],
              Subsuperscript[ c, 
                RowBox[ {
                  StyleForm[ 
                  "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], 
                "\[Dagger]"],
              Editable->False],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm], 
        StyleBox["\[CenterDot]",
          FontColor->RGBColor[0, 0.392187, 0]], 
        TagBox[
          StyleBox[
            InterpretationBox[
              SubsuperscriptBox["c", 
                TagBox[
                  StyleBox["\<\"\[UpArrow]\"\>",
                    FontColor->RGBColor[1, 0, 0]],
                  (
                  StyleForm[ #, FontColor -> RGBColor[ 
                    1, 0, 0]]&)], "\<\"\[Dagger]\"\>"],
              Subsuperscript[ c, 
                RowBox[ {
                  StyleForm[ "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}],
                 "\[Dagger]"],
              Editable->False],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm], 
        StyleBox["\[CenterDot]",
          FontColor->RGBColor[0, 0.392187, 0]], 
        TagBox[
          StyleBox[
            InterpretationBox[
              SubsuperscriptBox["c", 
                TagBox[
                  StyleBox["\<\"\[DownArrow]\"\>",
                    FontColor->RGBColor[0, 0, 1]],
                  (
                  StyleForm[ #, FontColor -> RGBColor[ 
                    0, 0, 1]]&)], "\<\"\"\>"],
              Subsuperscript[ c, 
                RowBox[ {
                  StyleForm[ 
                  "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], ""],
              Editable->False],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm], 
        StyleBox["\[CenterDot]",
          FontColor->RGBColor[0, 0.392187, 0]], 
        TagBox[
          StyleBox[
            InterpretationBox[
              SubsuperscriptBox["c", 
                TagBox[
                  StyleBox["\<\"\[UpArrow]\"\>",
                    FontColor->RGBColor[1, 0, 0]],
                  (
                  StyleForm[ #, FontColor -> RGBColor[ 
                    1, 0, 0]]&)], "\<\"\"\>"],
              Subsuperscript[ c, 
                RowBox[ {
                  StyleForm[ "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}],
                 ""],
              Editable->False],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm]}]}]], "Output",
  CellLabel->"Out[5]="],

Cell[BoxData[
    TagBox[\(hubbard[c[]]\),
      HoldForm]], "Output",
  CellLabel->"Out[6]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(hop[c[], d[]]\), "\[IndentingNewLine]", 
    \(SnegSimplify[%]\)}], "Input",
  CellLabel->"In[7]:="],

Cell[BoxData[
    RowBox[{
      RowBox[{
        TagBox[
          StyleBox[
            InterpretationBox[
              SubsuperscriptBox["c", 
                TagBox[
                  StyleBox["\<\"\[DownArrow]\"\>",
                    FontColor->RGBColor[0, 0, 1]],
                  (
                  StyleForm[ #, FontColor -> RGBColor[ 
                    0, 0, 1]]&)], "\<\"\[Dagger]\"\>"],
              Subsuperscript[ c, 
                RowBox[ {
                  StyleForm[ 
                  "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], 
                "\[Dagger]"],
              Editable->False],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm], 
        StyleBox["\[CenterDot]",
          FontColor->RGBColor[0, 0.392187, 0]], 
        TagBox[
          StyleBox[
            InterpretationBox[
              SubsuperscriptBox["d", 
                TagBox[
                  StyleBox["\<\"\[DownArrow]\"\>",
                    FontColor->RGBColor[0, 0, 1]],
                  (
                  StyleForm[ #, FontColor -> RGBColor[ 
                    0, 0, 1]]&)], "\<\"\"\>"],
              Subsuperscript[ d, 
                RowBox[ {
                  StyleForm[ 
                  "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], ""],
              Editable->False],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm]}], "+", 
      RowBox[{
        TagBox[
          StyleBox[
            InterpretationBox[
              SubsuperscriptBox["c", 
                TagBox[
                  StyleBox["\<\"\[UpArrow]\"\>",
                    FontColor->RGBColor[1, 0, 0]],
                  (
                  StyleForm[ #, FontColor -> RGBColor[ 
                    1, 0, 0]]&)], "\<\"\[Dagger]\"\>"],
              Subsuperscript[ c, 
                RowBox[ {
                  StyleForm[ "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}],
                 "\[Dagger]"],
              Editable->False],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm], 
        StyleBox["\[CenterDot]",
          FontColor->RGBColor[0, 0.392187, 0]], 
        TagBox[
          StyleBox[
            InterpretationBox[
              SubsuperscriptBox["d", 
                TagBox[
                  StyleBox["\<\"\[UpArrow]\"\>",
                    FontColor->RGBColor[1, 0, 0]],
                  (
                  StyleForm[ #, FontColor -> RGBColor[ 
                    1, 0, 0]]&)], "\<\"\"\>"],
              Subsuperscript[ d, 
                RowBox[ {
                  StyleForm[ "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}],
                 ""],
              Editable->False],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm]}], "+", 
      RowBox[{
        TagBox[
          StyleBox[
            InterpretationBox[
              SubsuperscriptBox["d", 
                TagBox[
                  StyleBox["\<\"\[DownArrow]\"\>",
                    FontColor->RGBColor[0, 0, 1]],
                  (
                  StyleForm[ #, FontColor -> RGBColor[ 
                    0, 0, 1]]&)], "\<\"\[Dagger]\"\>"],
              Subsuperscript[ d, 
                RowBox[ {
                  StyleForm[ 
                  "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], 
                "\[Dagger]"],
              Editable->False],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm], 
        StyleBox["\[CenterDot]",
          FontColor->RGBColor[0, 0.392187, 0]], 
        TagBox[
          StyleBox[
            InterpretationBox[
              SubsuperscriptBox["c", 
                TagBox[
                  StyleBox["\<\"\[DownArrow]\"\>",
                    FontColor->RGBColor[0, 0, 1]],
                  (
                  StyleForm[ #, FontColor -> RGBColor[ 
                    0, 0, 1]]&)], "\<\"\"\>"],
              Subsuperscript[ c, 
                RowBox[ {
                  StyleForm[ 
                  "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], ""],
              Editable->False],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm]}], "+", 
      RowBox[{
        TagBox[
          StyleBox[
            InterpretationBox[
              SubsuperscriptBox["d", 
                TagBox[
                  StyleBox["\<\"\[UpArrow]\"\>",
                    FontColor->RGBColor[1, 0, 0]],
                  (
                  StyleForm[ #, FontColor -> RGBColor[ 
                    1, 0, 0]]&)], "\<\"\[Dagger]\"\>"],
              Subsuperscript[ d, 
                RowBox[ {
                  StyleForm[ "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}],
                 "\[Dagger]"],
              Editable->False],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm], 
        StyleBox["\[CenterDot]",
          FontColor->RGBColor[0, 0.392187, 0]], 
        TagBox[
          StyleBox[
            InterpretationBox[
              SubsuperscriptBox["c", 
                TagBox[
                  StyleBox["\<\"\[UpArrow]\"\>",
                    FontColor->RGBColor[1, 0, 0]],
                  (
                  StyleForm[ #, FontColor -> RGBColor[ 
                    1, 0, 0]]&)], "\<\"\"\>"],
              Subsuperscript[ c, 
                RowBox[ {
                  StyleForm[ "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}],
                 ""],
              Editable->False],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm]}]}]], "Output",
  CellLabel->"Out[7]="],

Cell[BoxData[
    TagBox[\(hop[c[], d[]]\),
      HoldForm]], "Output",
  CellLabel->"Out[8]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(spinx[c[]]\), "\[IndentingNewLine]", 
    \(SnegSimplify[%]\), "\[IndentingNewLine]", 
    \(spiny[c[]]\), "\n", 
    \(SnegSimplify[%]\), "\[IndentingNewLine]", 
    \(spinz[c[]]\), "\n", 
    \(SnegSimplify[%]\)}], "Input",
  CellLabel->"In[9]:="],

Cell[BoxData[
    RowBox[{\(1\/2\), " ", 
      RowBox[{"(", 
        RowBox[{
          RowBox[{
            TagBox[
              StyleBox[
                InterpretationBox[
                  SubsuperscriptBox["c", 
                    TagBox[
                      StyleBox["\<\"\[DownArrow]\"\>",
                        FontColor->RGBColor[0, 0, 1]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        0, 0, 1]]&)], "\<\"\[Dagger]\"\>"],
                  Subsuperscript[ c, 
                    RowBox[ {
                      StyleForm[ 
                      "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], 
                    "\[Dagger]"],
                  Editable->False],
                ScriptSizeMultipliers->1,
                ScriptBaselineShifts->{1, 1}],
              DisplayForm], 
            StyleBox["\[CenterDot]",
              FontColor->RGBColor[0, 0.392187, 0]], 
            TagBox[
              StyleBox[
                InterpretationBox[
                  SubsuperscriptBox["c", 
                    TagBox[
                      StyleBox["\<\"\[UpArrow]\"\>",
                        FontColor->RGBColor[1, 0, 0]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        1, 0, 0]]&)], "\<\"\"\>"],
                  Subsuperscript[ c, 
                    RowBox[ {
                      StyleForm[ 
                      "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], ""],
                  Editable->False],
                ScriptSizeMultipliers->1,
                ScriptBaselineShifts->{1, 1}],
              DisplayForm]}], "+", 
          RowBox[{
            TagBox[
              StyleBox[
                InterpretationBox[
                  SubsuperscriptBox["c", 
                    TagBox[
                      StyleBox["\<\"\[UpArrow]\"\>",
                        FontColor->RGBColor[1, 0, 0]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        1, 0, 0]]&)], "\<\"\[Dagger]\"\>"],
                  Subsuperscript[ c, 
                    RowBox[ {
                      StyleForm[ 
                      "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                    "\[Dagger]"],
                  Editable->False],
                ScriptSizeMultipliers->1,
                ScriptBaselineShifts->{1, 1}],
              DisplayForm], 
            StyleBox["\[CenterDot]",
              FontColor->RGBColor[0, 0.392187, 0]], 
            TagBox[
              StyleBox[
                InterpretationBox[
                  SubsuperscriptBox["c", 
                    TagBox[
                      StyleBox["\<\"\[DownArrow]\"\>",
                        FontColor->RGBColor[0, 0, 1]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        0, 0, 1]]&)], "\<\"\"\>"],
                  Subsuperscript[ c, 
                    RowBox[ {
                      StyleForm[ 
                      "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], ""],
                  
                  Editable->False],
                ScriptSizeMultipliers->1,
                ScriptBaselineShifts->{1, 1}],
              DisplayForm]}]}], ")"}]}]], "Output",
  CellLabel->"Out[9]="],

Cell[BoxData[
    TagBox[\(spinx[c[]]\),
      HoldForm]], "Output",
  CellLabel->"Out[10]="],

Cell[BoxData[
    RowBox[{\(1\/2\), " ", 
      RowBox[{"(", 
        RowBox[{
          RowBox[{"\[ImaginaryI]", 
            RowBox[{
              TagBox[
                StyleBox[
                  InterpretationBox[
                    SubsuperscriptBox["c", 
                      TagBox[
                        StyleBox["\<\"\[DownArrow]\"\>",
                          FontColor->RGBColor[0, 0, 1]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          0, 0, 1]]&)], "\<\"\[Dagger]\"\>"],
                    Subsuperscript[ c, 
                      RowBox[ {
                        StyleForm[ 
                        "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], 
                      "\[Dagger]"],
                    Editable->False],
                  ScriptSizeMultipliers->1,
                  ScriptBaselineShifts->{1, 1}],
                DisplayForm], 
              StyleBox["\[CenterDot]",
                FontColor->RGBColor[0, 0.392187, 0]], 
              TagBox[
                StyleBox[
                  InterpretationBox[
                    SubsuperscriptBox["c", 
                      TagBox[
                        StyleBox["\<\"\[UpArrow]\"\>",
                          FontColor->RGBColor[1, 0, 0]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          1, 0, 0]]&)], "\<\"\"\>"],
                    Subsuperscript[ c, 
                      RowBox[ {
                        StyleForm[ 
                        "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], ""],
                    
                    Editable->False],
                  ScriptSizeMultipliers->1,
                  ScriptBaselineShifts->{1, 1}],
                DisplayForm]}]}], "-", 
          RowBox[{"\[ImaginaryI]", 
            RowBox[{
              TagBox[
                StyleBox[
                  InterpretationBox[
                    SubsuperscriptBox["c", 
                      TagBox[
                        StyleBox["\<\"\[UpArrow]\"\>",
                          FontColor->RGBColor[1, 0, 0]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          1, 0, 0]]&)], "\<\"\[Dagger]\"\>"],
                    Subsuperscript[ c, 
                      RowBox[ {
                        StyleForm[ 
                        "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                      "\[Dagger]"],
                    Editable->False],
                  ScriptSizeMultipliers->1,
                  ScriptBaselineShifts->{1, 1}],
                DisplayForm], 
              StyleBox["\[CenterDot]",
                FontColor->RGBColor[0, 0.392187, 0]], 
              TagBox[
                StyleBox[
                  InterpretationBox[
                    SubsuperscriptBox["c", 
                      TagBox[
                        StyleBox["\<\"\[DownArrow]\"\>",
                          FontColor->RGBColor[0, 0, 1]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          0, 0, 1]]&)], "\<\"\"\>"],
                    Subsuperscript[ c, 
                      RowBox[ {
                        StyleForm[ 
                        "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], 
                      ""],
                    Editable->False],
                  ScriptSizeMultipliers->1,
                  ScriptBaselineShifts->{1, 1}],
                DisplayForm]}]}]}], ")"}]}]], "Output",
  CellLabel->"Out[11]="],

Cell[BoxData[
    TagBox[\(spiny[c[]]\),
      HoldForm]], "Output",
  CellLabel->"Out[12]="],

Cell[BoxData[
    RowBox[{\(1\/2\), " ", 
      RowBox[{"(", 
        RowBox[{
          RowBox[{"\<\"-\"\>", 
            RowBox[{
              TagBox[
                StyleBox[
                  InterpretationBox[
                    SubsuperscriptBox["c", 
                      TagBox[
                        StyleBox["\<\"\[DownArrow]\"\>",
                          FontColor->RGBColor[0, 0, 1]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          0, 0, 1]]&)], "\<\"\[Dagger]\"\>"],
                    Subsuperscript[ c, 
                      RowBox[ {
                        StyleForm[ 
                        "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], 
                      "\[Dagger]"],
                    Editable->False],
                  ScriptSizeMultipliers->1,
                  ScriptBaselineShifts->{1, 1}],
                DisplayForm], 
              StyleBox["\[CenterDot]",
                FontColor->RGBColor[0, 0.392187, 0]], 
              TagBox[
                StyleBox[
                  InterpretationBox[
                    SubsuperscriptBox["c", 
                      TagBox[
                        StyleBox["\<\"\[DownArrow]\"\>",
                          FontColor->RGBColor[0, 0, 1]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          0, 0, 1]]&)], "\<\"\"\>"],
                    Subsuperscript[ c, 
                      RowBox[ {
                        StyleForm[ 
                        "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], 
                      ""],
                    Editable->False],
                  ScriptSizeMultipliers->1,
                  ScriptBaselineShifts->{1, 1}],
                DisplayForm]}]}], "+", 
          RowBox[{
            TagBox[
              StyleBox[
                InterpretationBox[
                  SubsuperscriptBox["c", 
                    TagBox[
                      StyleBox["\<\"\[UpArrow]\"\>",
                        FontColor->RGBColor[1, 0, 0]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        1, 0, 0]]&)], "\<\"\[Dagger]\"\>"],
                  Subsuperscript[ c, 
                    RowBox[ {
                      StyleForm[ 
                      "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                    "\[Dagger]"],
                  Editable->False],
                ScriptSizeMultipliers->1,
                ScriptBaselineShifts->{1, 1}],
              DisplayForm], 
            StyleBox["\[CenterDot]",
              FontColor->RGBColor[0, 0.392187, 0]], 
            TagBox[
              StyleBox[
                InterpretationBox[
                  SubsuperscriptBox["c", 
                    TagBox[
                      StyleBox["\<\"\[UpArrow]\"\>",
                        FontColor->RGBColor[1, 0, 0]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        1, 0, 0]]&)], "\<\"\"\>"],
                  Subsuperscript[ c, 
                    RowBox[ {
                      StyleForm[ 
                      "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], ""],
                  Editable->False],
                ScriptSizeMultipliers->1,
                ScriptBaselineShifts->{1, 1}],
              DisplayForm]}]}], ")"}]}]], "Output",
  CellLabel->"Out[13]="],

Cell[BoxData[
    RowBox[{\(1\/2\), " ", 
      RowBox[{"(", 
        RowBox[{
          RowBox[{"-", 
            TagBox[\(number[c[], 0]\),
              HoldForm]}], "+", 
          TagBox[\(number[c[], 1]\),
            HoldForm]}], ")"}]}]], "Output",
  CellLabel->"Out[14]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(spinx[c[]]\[CenterDot]spiny[d[]]\), "\[IndentingNewLine]", 
    \(SnegSimplify[%]\)}], "Input",
  CellLabel->"In[15]:="],

Cell[BoxData[
    RowBox[{\(1\/4\), " ", 
      RowBox[{"(", 
        RowBox[{
          RowBox[{\(-\[ImaginaryI]\), 
            RowBox[{
              TagBox[
                StyleBox[
                  InterpretationBox[
                    SubsuperscriptBox["c", 
                      TagBox[
                        StyleBox["\<\"\[DownArrow]\"\>",
                          FontColor->RGBColor[0, 0, 1]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          0, 0, 1]]&)], "\<\"\[Dagger]\"\>"],
                    Subsuperscript[ c, 
                      RowBox[ {
                        StyleForm[ 
                        "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], 
                      "\[Dagger]"],
                    Editable->False],
                  ScriptSizeMultipliers->1,
                  ScriptBaselineShifts->{1, 1}],
                DisplayForm], 
              StyleBox["\[CenterDot]",
                FontColor->RGBColor[0, 0.392187, 0]], 
              TagBox[
                StyleBox[
                  InterpretationBox[
                    SubsuperscriptBox["d", 
                      TagBox[
                        StyleBox["\<\"\[DownArrow]\"\>",
                          FontColor->RGBColor[0, 0, 1]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          0, 0, 1]]&)], "\<\"\[Dagger]\"\>"],
                    Subsuperscript[ d, 
                      RowBox[ {
                        StyleForm[ 
                        "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], 
                      "\[Dagger]"],
                    Editable->False],
                  ScriptSizeMultipliers->1,
                  ScriptBaselineShifts->{1, 1}],
                DisplayForm], 
              StyleBox["\[CenterDot]",
                FontColor->RGBColor[0, 0.392187, 0]], 
              TagBox[
                StyleBox[
                  InterpretationBox[
                    SubsuperscriptBox["c", 
                      TagBox[
                        StyleBox["\<\"\[UpArrow]\"\>",
                          FontColor->RGBColor[1, 0, 0]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          1, 0, 0]]&)], "\<\"\"\>"],
                    Subsuperscript[ c, 
                      RowBox[ {
                        StyleForm[ 
                        "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], ""],
                    
                    Editable->False],
                  ScriptSizeMultipliers->1,
                  ScriptBaselineShifts->{1, 1}],
                DisplayForm], 
              StyleBox["\[CenterDot]",
                FontColor->RGBColor[0, 0.392187, 0]], 
              TagBox[
                StyleBox[
                  InterpretationBox[
                    SubsuperscriptBox["d", 
                      TagBox[
                        StyleBox["\<\"\[UpArrow]\"\>",
                          FontColor->RGBColor[1, 0, 0]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          1, 0, 0]]&)], "\<\"\"\>"],
                    Subsuperscript[ d, 
                      RowBox[ {
                        StyleForm[ 
                        "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], ""],
                    
                    Editable->False],
                  ScriptSizeMultipliers->1,
                  ScriptBaselineShifts->{1, 1}],
                DisplayForm]}]}], "+", 
          RowBox[{"\[ImaginaryI]", 
            RowBox[{
              TagBox[
                StyleBox[
                  InterpretationBox[
                    SubsuperscriptBox["c", 
                      TagBox[
                        StyleBox["\<\"\[DownArrow]\"\>",
                          FontColor->RGBColor[0, 0, 1]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          0, 0, 1]]&)], "\<\"\[Dagger]\"\>"],
                    Subsuperscript[ c, 
                      RowBox[ {
                        StyleForm[ 
                        "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], 
                      "\[Dagger]"],
                    Editable->False],
                  ScriptSizeMultipliers->1,
                  ScriptBaselineShifts->{1, 1}],
                DisplayForm], 
              StyleBox["\[CenterDot]",
                FontColor->RGBColor[0, 0.392187, 0]], 
              TagBox[
                StyleBox[
                  InterpretationBox[
                    SubsuperscriptBox["d", 
                      TagBox[
                        StyleBox["\<\"\[UpArrow]\"\>",
                          FontColor->RGBColor[1, 0, 0]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          1, 0, 0]]&)], "\<\"\[Dagger]\"\>"],
                    Subsuperscript[ d, 
                      RowBox[ {
                        StyleForm[ 
                        "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                      "\[Dagger]"],
                    Editable->False],
                  ScriptSizeMultipliers->1,
                  ScriptBaselineShifts->{1, 1}],
                DisplayForm], 
              StyleBox["\[CenterDot]",
                FontColor->RGBColor[0, 0.392187, 0]], 
              TagBox[
                StyleBox[
                  InterpretationBox[
                    SubsuperscriptBox["c", 
                      TagBox[
                        StyleBox["\<\"\[UpArrow]\"\>",
                          FontColor->RGBColor[1, 0, 0]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          1, 0, 0]]&)], "\<\"\"\>"],
                    Subsuperscript[ c, 
                      RowBox[ {
                        StyleForm[ 
                        "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], ""],
                    
                    Editable->False],
                  ScriptSizeMultipliers->1,
                  ScriptBaselineShifts->{1, 1}],
                DisplayForm], 
              StyleBox["\[CenterDot]",
                FontColor->RGBColor[0, 0.392187, 0]], 
              TagBox[
                StyleBox[
                  InterpretationBox[
                    SubsuperscriptBox["d", 
                      TagBox[
                        StyleBox["\<\"\[DownArrow]\"\>",
                          FontColor->RGBColor[0, 0, 1]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          0, 0, 1]]&)], "\<\"\"\>"],
                    Subsuperscript[ d, 
                      RowBox[ {
                        StyleForm[ 
                        "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], 
                      ""],
                    Editable->False],
                  ScriptSizeMultipliers->1,
                  ScriptBaselineShifts->{1, 1}],
                DisplayForm]}]}], "-", 
          RowBox[{"\[ImaginaryI]", 
            RowBox[{
              TagBox[
                StyleBox[
                  InterpretationBox[
                    SubsuperscriptBox["c", 
                      TagBox[
                        StyleBox["\<\"\[UpArrow]\"\>",
                          FontColor->RGBColor[1, 0, 0]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          1, 0, 0]]&)], "\<\"\[Dagger]\"\>"],
                    Subsuperscript[ c, 
                      RowBox[ {
                        StyleForm[ 
                        "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                      "\[Dagger]"],
                    Editable->False],
                  ScriptSizeMultipliers->1,
                  ScriptBaselineShifts->{1, 1}],
                DisplayForm], 
              StyleBox["\[CenterDot]",
                FontColor->RGBColor[0, 0.392187, 0]], 
              TagBox[
                StyleBox[
                  InterpretationBox[
                    SubsuperscriptBox["d", 
                      TagBox[
                        StyleBox["\<\"\[DownArrow]\"\>",
                          FontColor->RGBColor[0, 0, 1]],
                        (StyleForm[ #, FontColor -> RGBColor[ 
                          0, 0, 1]]&)], "\<\"\[Dagger]\"\>"],
                    Subsuperscript[ d, 
                      RowBox[ {
                        StyleForm[ 
                        "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], 
                      "\[Dagger]"],
                    Editable->False],
                  ScriptSizeMultipliers->1,
                  ScriptBaselineShifts->{1, 1}],
                DisplayForm], 
              StyleBox["\[CenterDot]",
                FontColor->RGBColor[0, 0.392187, 0]], 
              TagBox[
                StyleBox[
                  InterpretationBox[
                    SubsuperscriptBox["c", 
                      TagBox[
                        StyleBox["\<\"\[DownArrow]\"\>",
                          FontColor->RGBColor[0, 0, 1]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          0, 0, 1]]&)], "\<\"\"\>"],
                    Subsuperscript[ c, 
                      RowBox[ {
                        StyleForm[ 
                        "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], 
                      ""],
                    Editable->False],
                  ScriptSizeMultipliers->1,
                  ScriptBaselineShifts->{1, 1}],
                DisplayForm], 
              StyleBox["\[CenterDot]",
                FontColor->RGBColor[0, 0.392187, 0]], 
              TagBox[
                StyleBox[
                  InterpretationBox[
                    SubsuperscriptBox["d", 
                      TagBox[
                        StyleBox["\<\"\[UpArrow]\"\>",
                          FontColor->RGBColor[1, 0, 0]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          1, 0, 0]]&)], "\<\"\"\>"],
                    Subsuperscript[ d, 
                      RowBox[ {
                        StyleForm[ 
                        "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], ""],
                    
                    Editable->False],
                  ScriptSizeMultipliers->1,
                  ScriptBaselineShifts->{1, 1}],
                DisplayForm]}]}], "+", 
          RowBox[{"\[ImaginaryI]", 
            RowBox[{
              TagBox[
                StyleBox[
                  InterpretationBox[
                    SubsuperscriptBox["c", 
                      TagBox[
                        StyleBox["\<\"\[UpArrow]\"\>",
                          FontColor->RGBColor[1, 0, 0]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          1, 0, 0]]&)], "\<\"\[Dagger]\"\>"],
                    Subsuperscript[ c, 
                      RowBox[ {
                        StyleForm[ 
                        "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                      "\[Dagger]"],
                    Editable->False],
                  ScriptSizeMultipliers->1,
                  ScriptBaselineShifts->{1, 1}],
                DisplayForm], 
              StyleBox["\[CenterDot]",
                FontColor->RGBColor[0, 0.392187, 0]], 
              TagBox[
                StyleBox[
                  InterpretationBox[
                    SubsuperscriptBox["d", 
                      TagBox[
                        StyleBox["\<\"\[UpArrow]\"\>",
                          FontColor->RGBColor[1, 0, 0]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          1, 0, 0]]&)], "\<\"\[Dagger]\"\>"],
                    Subsuperscript[ d, 
                      RowBox[ {
                        StyleForm[ 
                        "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                      "\[Dagger]"],
                    Editable->False],
                  ScriptSizeMultipliers->1,
                  ScriptBaselineShifts->{1, 1}],
                DisplayForm], 
              StyleBox["\[CenterDot]",
                FontColor->RGBColor[0, 0.392187, 0]], 
              TagBox[
                StyleBox[
                  InterpretationBox[
                    SubsuperscriptBox["c", 
                      TagBox[
                        StyleBox["\<\"\[DownArrow]\"\>",
                          FontColor->RGBColor[0, 0, 1]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          0, 0, 1]]&)], "\<\"\"\>"],
                    Subsuperscript[ c, 
                      RowBox[ {
                        StyleForm[ 
                        "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], 
                      ""],
                    Editable->False],
                  ScriptSizeMultipliers->1,
                  ScriptBaselineShifts->{1, 1}],
                DisplayForm], 
              StyleBox["\[CenterDot]",
                FontColor->RGBColor[0, 0.392187, 0]], 
              TagBox[
                StyleBox[
                  InterpretationBox[
                    SubsuperscriptBox["d", 
                      TagBox[
                        StyleBox["\<\"\[DownArrow]\"\>",
                          FontColor->RGBColor[0, 0, 1]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          0, 0, 1]]&)], "\<\"\"\>"],
                    Subsuperscript[ d, 
                      RowBox[ {
                        StyleForm[ 
                        "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], 
                      ""],
                    Editable->False],
                  ScriptSizeMultipliers->1,
                  ScriptBaselineShifts->{1, 1}],
                DisplayForm]}]}]}], ")"}]}]], "Output",
  CellLabel->"Out[15]="],

Cell[BoxData[
    RowBox[{
      TagBox[\(spinx[c[]]\),
        HoldForm], 
      StyleBox["\[CenterDot]",
        FontColor->RGBColor[0, 0.392187, 0]], 
      TagBox[\(spiny[d[]]\),
        HoldForm]}]], "Output",
  CellLabel->"Out[16]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(spinspin[c[], d[]]\), "\[IndentingNewLine]", 
    \(SnegSimplify[%]\), "\[IndentingNewLine]", 
    \(spinspinxy[c[], d[]]\), "\[IndentingNewLine]", 
    \(SnegSimplify[%] // Expand\), "\[IndentingNewLine]", 
    \(spinspinz[c[], d[]]\), "\n", 
    \(SnegSimplify[%]\)}], "Input",
  CellLabel->"In[17]:="],

Cell[BoxData[
    RowBox[{\(1\/4\), " ", 
      RowBox[{"(", 
        RowBox[{
          RowBox[{"\<\"-\"\>", 
            RowBox[{
              TagBox[
                StyleBox[
                  InterpretationBox[
                    SubsuperscriptBox["c", 
                      TagBox[
                        StyleBox["\<\"\[DownArrow]\"\>",
                          FontColor->RGBColor[0, 0, 1]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          0, 0, 1]]&)], "\<\"\[Dagger]\"\>"],
                    Subsuperscript[ c, 
                      RowBox[ {
                        StyleForm[ 
                        "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], 
                      "\[Dagger]"],
                    Editable->False],
                  ScriptSizeMultipliers->1,
                  ScriptBaselineShifts->{1, 1}],
                DisplayForm], 
              StyleBox["\[CenterDot]",
                FontColor->RGBColor[0, 0.392187, 0]], 
              TagBox[
                StyleBox[
                  InterpretationBox[
                    SubsuperscriptBox["d", 
                      TagBox[
                        StyleBox["\<\"\[DownArrow]\"\>",
                          FontColor->RGBColor[0, 0, 1]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          0, 0, 1]]&)], "\<\"\[Dagger]\"\>"],
                    Subsuperscript[ d, 
                      RowBox[ {
                        StyleForm[ 
                        "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], 
                      "\[Dagger]"],
                    Editable->False],
                  ScriptSizeMultipliers->1,
                  ScriptBaselineShifts->{1, 1}],
                DisplayForm], 
              StyleBox["\[CenterDot]",
                FontColor->RGBColor[0, 0.392187, 0]], 
              TagBox[
                StyleBox[
                  InterpretationBox[
                    SubsuperscriptBox["c", 
                      TagBox[
                        StyleBox["\<\"\[DownArrow]\"\>",
                          FontColor->RGBColor[0, 0, 1]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          0, 0, 1]]&)], "\<\"\"\>"],
                    Subsuperscript[ c, 
                      RowBox[ {
                        StyleForm[ 
                        "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], 
                      ""],
                    Editable->False],
                  ScriptSizeMultipliers->1,
                  ScriptBaselineShifts->{1, 1}],
                DisplayForm], 
              StyleBox["\[CenterDot]",
                FontColor->RGBColor[0, 0.392187, 0]], 
              TagBox[
                StyleBox[
                  InterpretationBox[
                    SubsuperscriptBox["d", 
                      TagBox[
                        StyleBox["\<\"\[DownArrow]\"\>",
                          FontColor->RGBColor[0, 0, 1]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          0, 0, 1]]&)], "\<\"\"\>"],
                    Subsuperscript[ d, 
                      RowBox[ {
                        StyleForm[ 
                        "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], 
                      ""],
                    Editable->False],
                  ScriptSizeMultipliers->1,
                  ScriptBaselineShifts->{1, 1}],
                DisplayForm]}]}], "+", 
          RowBox[{
            TagBox[
              StyleBox[
                InterpretationBox[
                  SubsuperscriptBox["c", 
                    TagBox[
                      StyleBox["\<\"\[DownArrow]\"\>",
                        FontColor->RGBColor[0, 0, 1]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        0, 0, 1]]&)], "\<\"\[Dagger]\"\>"],
                  Subsuperscript[ c, 
                    RowBox[ {
                      StyleForm[ 
                      "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], 
                    "\[Dagger]"],
                  Editable->False],
                ScriptSizeMultipliers->1,
                ScriptBaselineShifts->{1, 1}],
              DisplayForm], 
            StyleBox["\[CenterDot]",
              FontColor->RGBColor[0, 0.392187, 0]], 
            TagBox[
              StyleBox[
                InterpretationBox[
                  SubsuperscriptBox["d", 
                    TagBox[
                      StyleBox["\<\"\[UpArrow]\"\>",
                        FontColor->RGBColor[1, 0, 0]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        1, 0, 0]]&)], "\<\"\[Dagger]\"\>"],
                  Subsuperscript[ d, 
                    RowBox[ {
                      StyleForm[ 
                      "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                    "\[Dagger]"],
                  Editable->False],
                ScriptSizeMultipliers->1,
                ScriptBaselineShifts->{1, 1}],
              DisplayForm], 
            StyleBox["\[CenterDot]",
              FontColor->RGBColor[0, 0.392187, 0]], 
            TagBox[
              StyleBox[
                InterpretationBox[
                  SubsuperscriptBox["c", 
                    TagBox[
                      StyleBox["\<\"\[DownArrow]\"\>",
                        FontColor->RGBColor[0, 0, 1]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        0, 0, 1]]&)], "\<\"\"\>"],
                  Subsuperscript[ c, 
                    RowBox[ {
                      StyleForm[ 
                      "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], ""],
                  
                  Editable->False],
                ScriptSizeMultipliers->1,
                ScriptBaselineShifts->{1, 1}],
              DisplayForm], 
            StyleBox["\[CenterDot]",
              FontColor->RGBColor[0, 0.392187, 0]], 
            TagBox[
              StyleBox[
                InterpretationBox[
                  SubsuperscriptBox["d", 
                    TagBox[
                      StyleBox["\<\"\[UpArrow]\"\>",
                        FontColor->RGBColor[1, 0, 0]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        1, 0, 0]]&)], "\<\"\"\>"],
                  Subsuperscript[ d, 
                    RowBox[ {
                      StyleForm[ 
                      "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], ""],
                  Editable->False],
                ScriptSizeMultipliers->1,
                ScriptBaselineShifts->{1, 1}],
              DisplayForm]}], "-", 
          RowBox[{"2", 
            RowBox[{
              TagBox[
                StyleBox[
                  InterpretationBox[
                    SubsuperscriptBox["c", 
                      TagBox[
                        StyleBox["\<\"\[DownArrow]\"\>",
                          FontColor->RGBColor[0, 0, 1]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          0, 0, 1]]&)], "\<\"\[Dagger]\"\>"],
                    Subsuperscript[ c, 
                      RowBox[ {
                        StyleForm[ 
                        "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], 
                      "\[Dagger]"],
                    Editable->False],
                  ScriptSizeMultipliers->1,
                  ScriptBaselineShifts->{1, 1}],
                DisplayForm], 
              StyleBox["\[CenterDot]",
                FontColor->RGBColor[0, 0.392187, 0]], 
              TagBox[
                StyleBox[
                  InterpretationBox[
                    SubsuperscriptBox["d", 
                      TagBox[
                        StyleBox["\<\"\[UpArrow]\"\>",
                          FontColor->RGBColor[1, 0, 0]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          1, 0, 0]]&)], "\<\"\[Dagger]\"\>"],
                    Subsuperscript[ d, 
                      RowBox[ {
                        StyleForm[ 
                        "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                      "\[Dagger]"],
                    Editable->False],
                  ScriptSizeMultipliers->1,
                  ScriptBaselineShifts->{1, 1}],
                DisplayForm], 
              StyleBox["\[CenterDot]",
                FontColor->RGBColor[0, 0.392187, 0]], 
              TagBox[
                StyleBox[
                  InterpretationBox[
                    SubsuperscriptBox["c", 
                      TagBox[
                        StyleBox["\<\"\[UpArrow]\"\>",
                          FontColor->RGBColor[1, 0, 0]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          1, 0, 0]]&)], "\<\"\"\>"],
                    Subsuperscript[ c, 
                      RowBox[ {
                        StyleForm[ 
                        "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], ""],
                    
                    Editable->False],
                  ScriptSizeMultipliers->1,
                  ScriptBaselineShifts->{1, 1}],
                DisplayForm], 
              StyleBox["\[CenterDot]",
                FontColor->RGBColor[0, 0.392187, 0]], 
              TagBox[
                StyleBox[
                  InterpretationBox[
                    SubsuperscriptBox["d", 
                      TagBox[
                        StyleBox["\<\"\[DownArrow]\"\>",
                          FontColor->RGBColor[0, 0, 1]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          0, 0, 1]]&)], "\<\"\"\>"],
                    Subsuperscript[ d, 
                      RowBox[ {
                        StyleForm[ 
                        "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], 
                      ""],
                    Editable->False],
                  ScriptSizeMultipliers->1,
                  ScriptBaselineShifts->{1, 1}],
                DisplayForm]}]}], "-", 
          RowBox[{"2", 
            RowBox[{
              TagBox[
                StyleBox[
                  InterpretationBox[
                    SubsuperscriptBox["c", 
                      TagBox[
                        StyleBox["\<\"\[UpArrow]\"\>",
                          FontColor->RGBColor[1, 0, 0]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          1, 0, 0]]&)], "\<\"\[Dagger]\"\>"],
                    Subsuperscript[ c, 
                      RowBox[ {
                        StyleForm[ 
                        "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                      "\[Dagger]"],
                    Editable->False],
                  ScriptSizeMultipliers->1,
                  ScriptBaselineShifts->{1, 1}],
                DisplayForm], 
              StyleBox["\[CenterDot]",
                FontColor->RGBColor[0, 0.392187, 0]], 
              TagBox[
                StyleBox[
                  InterpretationBox[
                    SubsuperscriptBox["d", 
                      TagBox[
                        StyleBox["\<\"\[DownArrow]\"\>",
                          FontColor->RGBColor[0, 0, 1]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          0, 0, 1]]&)], "\<\"\[Dagger]\"\>"],
                    Subsuperscript[ d, 
                      RowBox[ {
                        StyleForm[ 
                        "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], 
                      "\[Dagger]"],
                    Editable->False],
                  ScriptSizeMultipliers->1,
                  ScriptBaselineShifts->{1, 1}],
                DisplayForm], 
              StyleBox["\[CenterDot]",
                FontColor->RGBColor[0, 0.392187, 0]], 
              TagBox[
                StyleBox[
                  InterpretationBox[
                    SubsuperscriptBox["c", 
                      TagBox[
                        StyleBox["\<\"\[DownArrow]\"\>",
                          FontColor->RGBColor[0, 0, 1]],
                        (StyleForm[ #, FontColor -> RGBColor[ 
                          0, 0, 1]]&)], "\<\"\"\>"],
                    Subsuperscript[ c, 
                      RowBox[ {
                        StyleForm[ 
                        "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], 
                      ""],
                    Editable->False],
                  ScriptSizeMultipliers->1,
                  ScriptBaselineShifts->{1, 1}],
                DisplayForm], 
              StyleBox["\[CenterDot]",
                FontColor->RGBColor[0, 0.392187, 0]], 
              TagBox[
                StyleBox[
                  InterpretationBox[
                    SubsuperscriptBox["d", 
                      TagBox[
                        StyleBox["\<\"\[UpArrow]\"\>",
                          FontColor->RGBColor[1, 0, 0]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          1, 0, 0]]&)], "\<\"\"\>"],
                    Subsuperscript[ d, 
                      RowBox[ {
                        StyleForm[ 
                        "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], ""],
                    
                    Editable->False],
                  ScriptSizeMultipliers->1,
                  ScriptBaselineShifts->{1, 1}],
                DisplayForm]}]}], "+", 
          RowBox[{
            TagBox[
              StyleBox[
                InterpretationBox[
                  SubsuperscriptBox["c", 
                    TagBox[
                      StyleBox["\<\"\[UpArrow]\"\>",
                        FontColor->RGBColor[1, 0, 0]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        1, 0, 0]]&)], "\<\"\[Dagger]\"\>"],
                  Subsuperscript[ c, 
                    RowBox[ {
                      StyleForm[ 
                      "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                    "\[Dagger]"],
                  Editable->False],
                ScriptSizeMultipliers->1,
                ScriptBaselineShifts->{1, 1}],
              DisplayForm], 
            StyleBox["\[CenterDot]",
              FontColor->RGBColor[0, 0.392187, 0]], 
            TagBox[
              StyleBox[
                InterpretationBox[
                  SubsuperscriptBox["d", 
                    TagBox[
                      StyleBox["\<\"\[DownArrow]\"\>",
                        FontColor->RGBColor[0, 0, 1]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        0, 0, 1]]&)], "\<\"\[Dagger]\"\>"],
                  Subsuperscript[ d, 
                    RowBox[ {
                      StyleForm[ 
                      "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], 
                    "\[Dagger]"],
                  Editable->False],
                ScriptSizeMultipliers->1,
                ScriptBaselineShifts->{1, 1}],
              DisplayForm], 
            StyleBox["\[CenterDot]",
              FontColor->RGBColor[0, 0.392187, 0]], 
            TagBox[
              StyleBox[
                InterpretationBox[
                  SubsuperscriptBox["c", 
                    TagBox[
                      StyleBox["\<\"\[UpArrow]\"\>",
                        FontColor->RGBColor[1, 0, 0]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        1, 0, 0]]&)], "\<\"\"\>"],
                  Subsuperscript[ c, 
                    RowBox[ {
                      StyleForm[ 
                      "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], ""],
                  Editable->False],
                ScriptSizeMultipliers->1,
                ScriptBaselineShifts->{1, 1}],
              DisplayForm], 
            StyleBox["\[CenterDot]",
              FontColor->RGBColor[0, 0.392187, 0]], 
            TagBox[
              StyleBox[
                InterpretationBox[
                  SubsuperscriptBox["d", 
                    TagBox[
                      StyleBox["\<\"\[DownArrow]\"\>",
                        FontColor->RGBColor[0, 0, 1]],
                      (StyleForm[ #, FontColor -> RGBColor[ 
                        0, 0, 1]]&)], "\<\"\"\>"],
                  Subsuperscript[ d, 
                    RowBox[ {
                      StyleForm[ 
                      "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], ""],
                  
                  Editable->False],
                ScriptSizeMultipliers->1,
                ScriptBaselineShifts->{1, 1}],
              DisplayForm]}], "-", 
          RowBox[{
            TagBox[
              StyleBox[
                InterpretationBox[
                  SubsuperscriptBox["c", 
                    TagBox[
                      StyleBox["\<\"\[UpArrow]\"\>",
                        FontColor->RGBColor[1, 0, 0]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        1, 0, 0]]&)], "\<\"\[Dagger]\"\>"],
                  Subsuperscript[ c, 
                    RowBox[ {
                      StyleForm[ 
                      "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                    "\[Dagger]"],
                  Editable->False],
                ScriptSizeMultipliers->1,
                ScriptBaselineShifts->{1, 1}],
              DisplayForm], 
            StyleBox["\[CenterDot]",
              FontColor->RGBColor[0, 0.392187, 0]], 
            TagBox[
              StyleBox[
                InterpretationBox[
                  SubsuperscriptBox["d", 
                    TagBox[
                      StyleBox["\<\"\[UpArrow]\"\>",
                        FontColor->RGBColor[1, 0, 0]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        1, 0, 0]]&)], "\<\"\[Dagger]\"\>"],
                  Subsuperscript[ d, 
                    RowBox[ {
                      StyleForm[ 
                      "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                    "\[Dagger]"],
                  Editable->False],
                ScriptSizeMultipliers->1,
                ScriptBaselineShifts->{1, 1}],
              DisplayForm], 
            StyleBox["\[CenterDot]",
              FontColor->RGBColor[0, 0.392187, 0]], 
            TagBox[
              StyleBox[
                InterpretationBox[
                  SubsuperscriptBox["c", 
                    TagBox[
                      StyleBox["\<\"\[UpArrow]\"\>",
                        FontColor->RGBColor[1, 0, 0]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        1, 0, 0]]&)], "\<\"\"\>"],
                  Subsuperscript[ c, 
                    RowBox[ {
                      StyleForm[ 
                      "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], ""],
                  Editable->False],
                ScriptSizeMultipliers->1,
                ScriptBaselineShifts->{1, 1}],
              DisplayForm], 
            StyleBox["\[CenterDot]",
              FontColor->RGBColor[0, 0.392187, 0]], 
            TagBox[
              StyleBox[
                InterpretationBox[
                  SubsuperscriptBox["d", 
                    TagBox[
                      StyleBox["\<\"\[UpArrow]\"\>",
                        FontColor->RGBColor[1, 0, 0]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        1, 0, 0]]&)], "\<\"\"\>"],
                  Subsuperscript[ d, 
                    RowBox[ {
                      StyleForm[ 
                      "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], ""],
                  Editable->False],
                ScriptSizeMultipliers->1,
                ScriptBaselineShifts->{1, 1}],
              DisplayForm]}]}], ")"}]}]], "Output",
  CellLabel->"Out[17]="],

Cell[BoxData[
    TagBox[\(spinspin[c[], d[]]\),
      HoldForm]], "Output",
  CellLabel->"Out[18]="],

Cell[BoxData[
    RowBox[{\(1\/2\), " ", 
      RowBox[{"(", 
        RowBox[{
          RowBox[{"\<\"-\"\>", 
            RowBox[{
              TagBox[
                StyleBox[
                  InterpretationBox[
                    SubsuperscriptBox["c", 
                      TagBox[
                        StyleBox["\<\"\[DownArrow]\"\>",
                          FontColor->RGBColor[0, 0, 1]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          0, 0, 1]]&)], "\<\"\[Dagger]\"\>"],
                    Subsuperscript[ c, 
                      RowBox[ {
                        StyleForm[ 
                        "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], 
                      "\[Dagger]"],
                    Editable->False],
                  ScriptSizeMultipliers->1,
                  ScriptBaselineShifts->{1, 1}],
                DisplayForm], 
              StyleBox["\[CenterDot]",
                FontColor->RGBColor[0, 0.392187, 0]], 
              TagBox[
                StyleBox[
                  InterpretationBox[
                    SubsuperscriptBox["d", 
                      TagBox[
                        StyleBox["\<\"\[UpArrow]\"\>",
                          FontColor->RGBColor[1, 0, 0]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          1, 0, 0]]&)], "\<\"\[Dagger]\"\>"],
                    Subsuperscript[ d, 
                      RowBox[ {
                        StyleForm[ 
                        "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                      "\[Dagger]"],
                    Editable->False],
                  ScriptSizeMultipliers->1,
                  ScriptBaselineShifts->{1, 1}],
                DisplayForm], 
              StyleBox["\[CenterDot]",
                FontColor->RGBColor[0, 0.392187, 0]], 
              TagBox[
                StyleBox[
                  InterpretationBox[
                    SubsuperscriptBox["c", 
                      TagBox[
                        StyleBox["\<\"\[UpArrow]\"\>",
                          FontColor->RGBColor[1, 0, 0]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          1, 0, 0]]&)], "\<\"\"\>"],
                    Subsuperscript[ c, 
                      RowBox[ {
                        StyleForm[ 
                        "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], ""],
                    
                    Editable->False],
                  ScriptSizeMultipliers->1,
                  ScriptBaselineShifts->{1, 1}],
                DisplayForm], 
              StyleBox["\[CenterDot]",
                FontColor->RGBColor[0, 0.392187, 0]], 
              TagBox[
                StyleBox[
                  InterpretationBox[
                    SubsuperscriptBox["d", 
                      TagBox[
                        StyleBox["\<\"\[DownArrow]\"\>",
                          FontColor->RGBColor[0, 0, 1]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          0, 0, 1]]&)], "\<\"\"\>"],
                    Subsuperscript[ d, 
                      RowBox[ {
                        StyleForm[ 
                        "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], 
                      ""],
                    Editable->False],
                  ScriptSizeMultipliers->1,
                  ScriptBaselineShifts->{1, 1}],
                DisplayForm]}]}], "-", 
          RowBox[{
            TagBox[
              StyleBox[
                InterpretationBox[
                  SubsuperscriptBox["c", 
                    TagBox[
                      StyleBox["\<\"\[UpArrow]\"\>",
                        FontColor->RGBColor[1, 0, 0]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        1, 0, 0]]&)], "\<\"\[Dagger]\"\>"],
                  Subsuperscript[ c, 
                    RowBox[ {
                      StyleForm[ 
                      "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                    "\[Dagger]"],
                  Editable->False],
                ScriptSizeMultipliers->1,
                ScriptBaselineShifts->{1, 1}],
              DisplayForm], 
            StyleBox["\[CenterDot]",
              FontColor->RGBColor[0, 0.392187, 0]], 
            TagBox[
              StyleBox[
                InterpretationBox[
                  SubsuperscriptBox["d", 
                    TagBox[
                      StyleBox["\<\"\[DownArrow]\"\>",
                        FontColor->RGBColor[0, 0, 1]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        0, 0, 1]]&)], "\<\"\[Dagger]\"\>"],
                  Subsuperscript[ d, 
                    RowBox[ {
                      StyleForm[ 
                      "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], 
                    "\[Dagger]"],
                  Editable->False],
                ScriptSizeMultipliers->1,
                ScriptBaselineShifts->{1, 1}],
              DisplayForm], 
            StyleBox["\[CenterDot]",
              FontColor->RGBColor[0, 0.392187, 0]], 
            TagBox[
              StyleBox[
                InterpretationBox[
                  SubsuperscriptBox["c", 
                    TagBox[
                      StyleBox["\<\"\[DownArrow]\"\>",
                        FontColor->RGBColor[0, 0, 1]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        0, 0, 1]]&)], "\<\"\"\>"],
                  Subsuperscript[ c, 
                    RowBox[ {
                      StyleForm[ 
                      "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], ""],
                  
                  Editable->False],
                ScriptSizeMultipliers->1,
                ScriptBaselineShifts->{1, 1}],
              DisplayForm], 
            StyleBox["\[CenterDot]",
              FontColor->RGBColor[0, 0.392187, 0]], 
            TagBox[
              StyleBox[
                InterpretationBox[
                  SubsuperscriptBox["d", 
                    TagBox[
                      StyleBox["\<\"\[UpArrow]\"\>",
                        FontColor->RGBColor[1, 0, 0]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        1, 0, 0]]&)], "\<\"\"\>"],
                  Subsuperscript[ d, 
                    RowBox[ {
                      StyleForm[ 
                      "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], ""],
                  Editable->False],
                ScriptSizeMultipliers->1,
                ScriptBaselineShifts->{1, 1}],
              DisplayForm]}]}], ")"}]}]], "Output",
  CellLabel->"Out[19]="],

Cell[BoxData[
    RowBox[{
      RowBox[{
        TagBox[\(spinx[c[]]\),
          HoldForm], 
        StyleBox["\[CenterDot]",
          FontColor->RGBColor[0, 0.392187, 0]], 
        TagBox[\(spinx[d[]]\),
          HoldForm]}], "+", 
      RowBox[{
        TagBox[\(spiny[c[]]\),
          HoldForm], 
        StyleBox["\[CenterDot]",
          FontColor->RGBColor[0, 0.392187, 0]], 
        TagBox[\(spiny[d[]]\),
          HoldForm]}]}]], "Output",
  CellLabel->"Out[20]="],

Cell[BoxData[
    RowBox[{\(1\/4\), " ", 
      RowBox[{"(", 
        RowBox[{
          RowBox[{"\<\"-\"\>", 
            RowBox[{
              TagBox[
                StyleBox[
                  InterpretationBox[
                    SubsuperscriptBox["c", 
                      TagBox[
                        StyleBox["\<\"\[DownArrow]\"\>",
                          FontColor->RGBColor[0, 0, 1]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          0, 0, 1]]&)], "\<\"\[Dagger]\"\>"],
                    Subsuperscript[ c, 
                      RowBox[ {
                        StyleForm[ 
                        "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], 
                      "\[Dagger]"],
                    Editable->False],
                  ScriptSizeMultipliers->1,
                  ScriptBaselineShifts->{1, 1}],
                DisplayForm], 
              StyleBox["\[CenterDot]",
                FontColor->RGBColor[0, 0.392187, 0]], 
              TagBox[
                StyleBox[
                  InterpretationBox[
                    SubsuperscriptBox["d", 
                      TagBox[
                        StyleBox["\<\"\[DownArrow]\"\>",
                          FontColor->RGBColor[0, 0, 1]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          0, 0, 1]]&)], "\<\"\[Dagger]\"\>"],
                    Subsuperscript[ d, 
                      RowBox[ {
                        StyleForm[ 
                        "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], 
                      "\[Dagger]"],
                    Editable->False],
                  ScriptSizeMultipliers->1,
                  ScriptBaselineShifts->{1, 1}],
                DisplayForm], 
              StyleBox["\[CenterDot]",
                FontColor->RGBColor[0, 0.392187, 0]], 
              TagBox[
                StyleBox[
                  InterpretationBox[
                    SubsuperscriptBox["c", 
                      TagBox[
                        StyleBox["\<\"\[DownArrow]\"\>",
                          FontColor->RGBColor[0, 0, 1]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          0, 0, 1]]&)], "\<\"\"\>"],
                    Subsuperscript[ c, 
                      RowBox[ {
                        StyleForm[ 
                        "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], 
                      ""],
                    Editable->False],
                  ScriptSizeMultipliers->1,
                  ScriptBaselineShifts->{1, 1}],
                DisplayForm], 
              StyleBox["\[CenterDot]",
                FontColor->RGBColor[0, 0.392187, 0]], 
              TagBox[
                StyleBox[
                  InterpretationBox[
                    SubsuperscriptBox["d", 
                      TagBox[
                        StyleBox["\<\"\[DownArrow]\"\>",
                          FontColor->RGBColor[0, 0, 1]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          0, 0, 1]]&)], "\<\"\"\>"],
                    Subsuperscript[ d, 
                      RowBox[ {
                        StyleForm[ 
                        "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], 
                      ""],
                    Editable->False],
                  ScriptSizeMultipliers->1,
                  ScriptBaselineShifts->{1, 1}],
                DisplayForm]}]}], "+", 
          RowBox[{
            TagBox[
              StyleBox[
                InterpretationBox[
                  SubsuperscriptBox["c", 
                    TagBox[
                      StyleBox["\<\"\[DownArrow]\"\>",
                        FontColor->RGBColor[0, 0, 1]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        0, 0, 1]]&)], "\<\"\[Dagger]\"\>"],
                  Subsuperscript[ c, 
                    RowBox[ {
                      StyleForm[ 
                      "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], 
                    "\[Dagger]"],
                  Editable->False],
                ScriptSizeMultipliers->1,
                ScriptBaselineShifts->{1, 1}],
              DisplayForm], 
            StyleBox["\[CenterDot]",
              FontColor->RGBColor[0, 0.392187, 0]], 
            TagBox[
              StyleBox[
                InterpretationBox[
                  SubsuperscriptBox["d", 
                    TagBox[
                      StyleBox["\<\"\[UpArrow]\"\>",
                        FontColor->RGBColor[1, 0, 0]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        1, 0, 0]]&)], "\<\"\[Dagger]\"\>"],
                  Subsuperscript[ d, 
                    RowBox[ {
                      StyleForm[ 
                      "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                    "\[Dagger]"],
                  Editable->False],
                ScriptSizeMultipliers->1,
                ScriptBaselineShifts->{1, 1}],
              DisplayForm], 
            StyleBox["\[CenterDot]",
              FontColor->RGBColor[0, 0.392187, 0]], 
            TagBox[
              StyleBox[
                InterpretationBox[
                  SubsuperscriptBox["c", 
                    TagBox[
                      StyleBox["\<\"\[DownArrow]\"\>",
                        FontColor->RGBColor[0, 0, 1]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        0, 0, 1]]&)], "\<\"\"\>"],
                  Subsuperscript[ c, 
                    RowBox[ {
                      StyleForm[ 
                      "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], ""],
                  
                  Editable->False],
                ScriptSizeMultipliers->1,
                ScriptBaselineShifts->{1, 1}],
              DisplayForm], 
            StyleBox["\[CenterDot]",
              FontColor->RGBColor[0, 0.392187, 0]], 
            TagBox[
              StyleBox[
                InterpretationBox[
                  SubsuperscriptBox["d", 
                    TagBox[
                      StyleBox["\<\"\[UpArrow]\"\>",
                        FontColor->RGBColor[1, 0, 0]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        1, 0, 0]]&)], "\<\"\"\>"],
                  Subsuperscript[ d, 
                    RowBox[ {
                      StyleForm[ 
                      "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], ""],
                  Editable->False],
                ScriptSizeMultipliers->1,
                ScriptBaselineShifts->{1, 1}],
              DisplayForm]}], "+", 
          RowBox[{
            TagBox[
              StyleBox[
                InterpretationBox[
                  SubsuperscriptBox["c", 
                    TagBox[
                      StyleBox["\<\"\[UpArrow]\"\>",
                        FontColor->RGBColor[1, 0, 0]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        1, 0, 0]]&)], "\<\"\[Dagger]\"\>"],
                  Subsuperscript[ c, 
                    RowBox[ {
                      StyleForm[ 
                      "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                    "\[Dagger]"],
                  Editable->False],
                ScriptSizeMultipliers->1,
                ScriptBaselineShifts->{1, 1}],
              DisplayForm], 
            StyleBox["\[CenterDot]",
              FontColor->RGBColor[0, 0.392187, 0]], 
            TagBox[
              StyleBox[
                InterpretationBox[
                  SubsuperscriptBox["d", 
                    TagBox[
                      StyleBox["\<\"\[DownArrow]\"\>",
                        FontColor->RGBColor[0, 0, 1]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        0, 0, 1]]&)], "\<\"\[Dagger]\"\>"],
                  Subsuperscript[ d, 
                    RowBox[ {
                      StyleForm[ 
                      "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], 
                    "\[Dagger]"],
                  Editable->False],
                ScriptSizeMultipliers->1,
                ScriptBaselineShifts->{1, 1}],
              DisplayForm], 
            StyleBox["\[CenterDot]",
              FontColor->RGBColor[0, 0.392187, 0]], 
            TagBox[
              StyleBox[
                InterpretationBox[
                  SubsuperscriptBox["c", 
                    TagBox[
                      StyleBox["\<\"\[UpArrow]\"\>",
                        FontColor->RGBColor[1, 0, 0]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        1, 0, 0]]&)], "\<\"\"\>"],
                  Subsuperscript[ c, 
                    RowBox[ {
                      StyleForm[ 
                      "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], ""],
                  Editable->False],
                ScriptSizeMultipliers->1,
                ScriptBaselineShifts->{1, 1}],
              DisplayForm], 
            StyleBox["\[CenterDot]",
              FontColor->RGBColor[0, 0.392187, 0]], 
            TagBox[
              StyleBox[
                InterpretationBox[
                  SubsuperscriptBox["d", 
                    TagBox[
                      StyleBox["\<\"\[DownArrow]\"\>",
                        FontColor->RGBColor[0, 0, 1]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        0, 0, 1]]&)], "\<\"\"\>"],
                  Subsuperscript[ d, 
                    RowBox[ {
                      StyleForm[ 
                      "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], ""],
                  
                  Editable->False],
                ScriptSizeMultipliers->1,
                ScriptBaselineShifts->{1, 1}],
              DisplayForm]}], "-", 
          RowBox[{
            TagBox[
              StyleBox[
                InterpretationBox[
                  SubsuperscriptBox["c", 
                    TagBox[
                      StyleBox["\<\"\[UpArrow]\"\>",
                        FontColor->RGBColor[1, 0, 0]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        1, 0, 0]]&)], "\<\"\[Dagger]\"\>"],
                  Subsuperscript[ c, 
                    RowBox[ {
                      StyleForm[ 
                      "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                    "\[Dagger]"],
                  Editable->False],
                ScriptSizeMultipliers->1,
                ScriptBaselineShifts->{1, 1}],
              DisplayForm], 
            StyleBox["\[CenterDot]",
              FontColor->RGBColor[0, 0.392187, 0]], 
            TagBox[
              StyleBox[
                InterpretationBox[
                  SubsuperscriptBox["d", 
                    TagBox[
                      StyleBox["\<\"\[UpArrow]\"\>",
                        FontColor->RGBColor[1, 0, 0]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        1, 0, 0]]&)], "\<\"\[Dagger]\"\>"],
                  Subsuperscript[ d, 
                    RowBox[ {
                      StyleForm[ 
                      "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                    "\[Dagger]"],
                  Editable->False],
                ScriptSizeMultipliers->1,
                ScriptBaselineShifts->{1, 1}],
              DisplayForm], 
            StyleBox["\[CenterDot]",
              FontColor->RGBColor[0, 0.392187, 0]], 
            TagBox[
              StyleBox[
                InterpretationBox[
                  SubsuperscriptBox["c", 
                    TagBox[
                      StyleBox["\<\"\[UpArrow]\"\>",
                        FontColor->RGBColor[1, 0, 0]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        1, 0, 0]]&)], "\<\"\"\>"],
                  Subsuperscript[ c, 
                    RowBox[ {
                      StyleForm[ 
                      "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], ""],
                  Editable->False],
                ScriptSizeMultipliers->1,
                ScriptBaselineShifts->{1, 1}],
              DisplayForm], 
            StyleBox["\[CenterDot]",
              FontColor->RGBColor[0, 0.392187, 0]], 
            TagBox[
              StyleBox[
                InterpretationBox[
                  SubsuperscriptBox["d", 
                    TagBox[
                      StyleBox["\<\"\[UpArrow]\"\>",
                        FontColor->RGBColor[1, 0, 0]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        1, 0, 0]]&)], "\<\"\"\>"],
                  Subsuperscript[ d, 
                    RowBox[ {
                      StyleForm[ 
                      "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], ""],
                  Editable->False],
                ScriptSizeMultipliers->1,
                ScriptBaselineShifts->{1, 1}],
              DisplayForm]}]}], ")"}]}]], "Output",
  CellLabel->"Out[21]="],

Cell[BoxData[
    RowBox[{
      TagBox[\(spinz[c[]]\),
        HoldForm], 
      StyleBox["\[CenterDot]",
        FontColor->RGBColor[0, 0.392187, 0]], 
      TagBox[\(spinz[d[]]\),
        HoldForm]}]], "Output",
  CellLabel->"Out[22]="]
}, Open  ]],

Cell["Required factorizations are performed automatically", "ExampleText"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(2\ number[c[]]\), "\[IndentingNewLine]", 
    \(SnegSimplify[%]\), "\[IndentingNewLine]", 
    \(\(-2\)/3\ number[c[]] // Expand\), "\n", 
    \(SnegSimplify[%]\)}], "Input",
  CellLabel->"In[23]:="],

Cell[BoxData[
    RowBox[{"2", " ", 
      RowBox[{"(", 
        RowBox[{
          RowBox[{
            TagBox[
              StyleBox[
                InterpretationBox[
                  SubsuperscriptBox["c", 
                    TagBox[
                      StyleBox["\<\"\[DownArrow]\"\>",
                        FontColor->RGBColor[0, 0, 1]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        0, 0, 1]]&)], "\<\"\[Dagger]\"\>"],
                  Subsuperscript[ c, 
                    RowBox[ {
                      StyleForm[ 
                      "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], 
                    "\[Dagger]"],
                  Editable->False],
                ScriptSizeMultipliers->1,
                ScriptBaselineShifts->{1, 1}],
              DisplayForm], 
            StyleBox["\[CenterDot]",
              FontColor->RGBColor[0, 0.392187, 0]], 
            TagBox[
              StyleBox[
                InterpretationBox[
                  SubsuperscriptBox["c", 
                    TagBox[
                      StyleBox["\<\"\[DownArrow]\"\>",
                        FontColor->RGBColor[0, 0, 1]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        0, 0, 1]]&)], "\<\"\"\>"],
                  Subsuperscript[ c, 
                    RowBox[ {
                      StyleForm[ 
                      "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], ""],
                  
                  Editable->False],
                ScriptSizeMultipliers->1,
                ScriptBaselineShifts->{1, 1}],
              DisplayForm]}], "+", 
          RowBox[{
            TagBox[
              StyleBox[
                InterpretationBox[
                  SubsuperscriptBox["c", 
                    TagBox[
                      StyleBox["\<\"\[UpArrow]\"\>",
                        FontColor->RGBColor[1, 0, 0]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        1, 0, 0]]&)], "\<\"\[Dagger]\"\>"],
                  Subsuperscript[ c, 
                    RowBox[ {
                      StyleForm[ 
                      "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                    "\[Dagger]"],
                  Editable->False],
                ScriptSizeMultipliers->1,
                ScriptBaselineShifts->{1, 1}],
              DisplayForm], 
            StyleBox["\[CenterDot]",
              FontColor->RGBColor[0, 0.392187, 0]], 
            TagBox[
              StyleBox[
                InterpretationBox[
                  SubsuperscriptBox["c", 
                    TagBox[
                      StyleBox["\<\"\[UpArrow]\"\>",
                        FontColor->RGBColor[1, 0, 0]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        1, 0, 0]]&)], "\<\"\"\>"],
                  Subsuperscript[ c, 
                    RowBox[ {
                      StyleForm[ 
                      "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], ""],
                  Editable->False],
                ScriptSizeMultipliers->1,
                ScriptBaselineShifts->{1, 1}],
              DisplayForm]}]}], ")"}]}]], "Output",
  CellLabel->"Out[23]="],

Cell[BoxData[
    RowBox[{"2", " ", 
      TagBox[\(number[c[]]\),
        HoldForm]}]], "Output",
  CellLabel->"Out[24]="],

Cell[BoxData[
    RowBox[{
      RowBox[{\(-\(2\/3\)\), 
        RowBox[{
          TagBox[
            StyleBox[
              InterpretationBox[
                SubsuperscriptBox["c", 
                  TagBox[
                    StyleBox["\<\"\[DownArrow]\"\>",
                      FontColor->RGBColor[0, 0, 1]],
                    (
                    StyleForm[ #, FontColor -> RGBColor[ 
                      0, 0, 1]]&)], "\<\"\[Dagger]\"\>"],
                Subsuperscript[ c, 
                  RowBox[ {
                    StyleForm[ 
                    "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], 
                  "\[Dagger]"],
                Editable->False],
              ScriptSizeMultipliers->1,
              ScriptBaselineShifts->{1, 1}],
            DisplayForm], 
          StyleBox["\[CenterDot]",
            FontColor->RGBColor[0, 0.392187, 0]], 
          TagBox[
            StyleBox[
              InterpretationBox[
                SubsuperscriptBox["c", 
                  TagBox[
                    StyleBox["\<\"\[DownArrow]\"\>",
                      FontColor->RGBColor[0, 0, 1]],
                    (
                    StyleForm[ #, FontColor -> RGBColor[ 
                      0, 0, 1]]&)], "\<\"\"\>"],
                Subsuperscript[ c, 
                  RowBox[ {
                    StyleForm[ 
                    "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], ""],
                Editable->False],
              ScriptSizeMultipliers->1,
              ScriptBaselineShifts->{1, 1}],
            DisplayForm]}]}], "-", 
      RowBox[{\(2\/3\), 
        RowBox[{
          TagBox[
            StyleBox[
              InterpretationBox[
                SubsuperscriptBox["c", 
                  TagBox[
                    StyleBox["\<\"\[UpArrow]\"\>",
                      FontColor->RGBColor[1, 0, 0]],
                    (
                    StyleForm[ #, FontColor -> RGBColor[ 
                      1, 0, 0]]&)], "\<\"\[Dagger]\"\>"],
                Subsuperscript[ c, 
                  RowBox[ {
                    StyleForm[ 
                    "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                  "\[Dagger]"],
                Editable->False],
              ScriptSizeMultipliers->1,
              ScriptBaselineShifts->{1, 1}],
            DisplayForm], 
          StyleBox["\[CenterDot]",
            FontColor->RGBColor[0, 0.392187, 0]], 
          TagBox[
            StyleBox[
              InterpretationBox[
                SubsuperscriptBox["c", 
                  TagBox[
                    StyleBox["\<\"\[UpArrow]\"\>",
                      FontColor->RGBColor[1, 0, 0]],
                    (
                    StyleForm[ #, FontColor -> RGBColor[ 
                      1, 0, 0]]&)], "\<\"\"\>"],
                Subsuperscript[ c, 
                  RowBox[ {
                    StyleForm[ 
                    "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], ""],
                Editable->False],
              ScriptSizeMultipliers->1,
              ScriptBaselineShifts->{1, 1}],
            DisplayForm]}]}]}]], "Output",
  CellLabel->"Out[25]="],

Cell[BoxData[
    RowBox[{\(-\(2\/3\)\), " ", 
      TagBox[\(number[c[]]\),
        HoldForm]}]], "Output",
  CellLabel->"Out[26]="]
}, Open  ]],

Cell["Three-site Hubbard Hamiltonian", "ExampleText"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(n = 3;\)\), "\n", 
    \(H = hamiltonian[Hubbard, c[], n, U, t, \[Epsilon]]\), "\n", 
    \(SnegSimplify[H]\)}], "Input",
  CellLabel->"In[27]:="],

Cell[BoxData[
    RowBox[{
      RowBox[{"\[Epsilon]", " ", 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              TagBox[
                StyleBox[
                  InterpretationBox[
                    SubsuperscriptBox["c", 
                      RowBox[{"1", 
                        TagBox[
                          StyleBox["\<\"\[DownArrow]\"\>",
                            FontColor->RGBColor[0, 0, 1]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                    Subsuperscript[ c, 
                      RowBox[ {1, 
                        StyleForm[ 
                        "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], 
                      "\[Dagger]"],
                    Editable->False],
                  ScriptSizeMultipliers->1,
                  ScriptBaselineShifts->{1, 1}],
                DisplayForm], 
              StyleBox["\[CenterDot]",
                FontColor->RGBColor[0, 0.392187, 0]], 
              TagBox[
                StyleBox[
                  InterpretationBox[
                    SubsuperscriptBox["c", 
                      RowBox[{"1", 
                        TagBox[
                          StyleBox["\<\"\[DownArrow]\"\>",
                            FontColor->RGBColor[0, 0, 1]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            0, 0, 1]]&)]}], "\<\"\"\>"],
                    Subsuperscript[ c, 
                      RowBox[ {1, 
                        StyleForm[ 
                        "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], 
                      ""],
                    Editable->False],
                  ScriptSizeMultipliers->1,
                  ScriptBaselineShifts->{1, 1}],
                DisplayForm]}], "+", 
            RowBox[{
              TagBox[
                StyleBox[
                  InterpretationBox[
                    SubsuperscriptBox["c", 
                      RowBox[{"1", 
                        TagBox[
                          StyleBox["\<\"\[UpArrow]\"\>",
                            FontColor->RGBColor[1, 0, 0]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                    Subsuperscript[ c, 
                      RowBox[ {1, 
                        StyleForm[ 
                        "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                      "\[Dagger]"],
                    Editable->False],
                  ScriptSizeMultipliers->1,
                  ScriptBaselineShifts->{1, 1}],
                DisplayForm], 
              StyleBox["\[CenterDot]",
                FontColor->RGBColor[0, 0.392187, 0]], 
              TagBox[
                StyleBox[
                  InterpretationBox[
                    SubsuperscriptBox["c", 
                      RowBox[{"1", 
                        TagBox[
                          StyleBox["\<\"\[UpArrow]\"\>",
                            FontColor->RGBColor[1, 0, 0]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            1, 0, 0]]&)]}], "\<\"\"\>"],
                    Subsuperscript[ c, 
                      RowBox[ {1, 
                        StyleForm[ 
                        "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], ""],
                    
                    Editable->False],
                  ScriptSizeMultipliers->1,
                  ScriptBaselineShifts->{1, 1}],
                DisplayForm]}]}], ")"}]}], "+", 
      RowBox[{"\[Epsilon]", " ", 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              TagBox[
                StyleBox[
                  InterpretationBox[
                    SubsuperscriptBox["c", 
                      RowBox[{"2", 
                        TagBox[
                          StyleBox["\<\"\[DownArrow]\"\>",
                            FontColor->RGBColor[0, 0, 1]],
                          (StyleForm[ #, FontColor -> RGBColor[ 
                            0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                    Subsuperscript[ c, 
                      RowBox[ {2, 
                        StyleForm[ 
                        "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], 
                      "\[Dagger]"],
                    Editable->False],
                  ScriptSizeMultipliers->1,
                  ScriptBaselineShifts->{1, 1}],
                DisplayForm], 
              StyleBox["\[CenterDot]",
                FontColor->RGBColor[0, 0.392187, 0]], 
              TagBox[
                StyleBox[
                  InterpretationBox[
                    SubsuperscriptBox["c", 
                      RowBox[{"2", 
                        TagBox[
                          StyleBox["\<\"\[DownArrow]\"\>",
                            FontColor->RGBColor[0, 0, 1]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            0, 0, 1]]&)]}], "\<\"\"\>"],
                    Subsuperscript[ c, 
                      RowBox[ {2, 
                        StyleForm[ 
                        "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], 
                      ""],
                    Editable->False],
                  ScriptSizeMultipliers->1,
                  ScriptBaselineShifts->{1, 1}],
                DisplayForm]}], "+", 
            RowBox[{
              TagBox[
                StyleBox[
                  InterpretationBox[
                    SubsuperscriptBox["c", 
                      RowBox[{"2", 
                        TagBox[
                          StyleBox["\<\"\[UpArrow]\"\>",
                            FontColor->RGBColor[1, 0, 0]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                    Subsuperscript[ c, 
                      RowBox[ {2, 
                        StyleForm[ 
                        "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                      "\[Dagger]"],
                    Editable->False],
                  ScriptSizeMultipliers->1,
                  ScriptBaselineShifts->{1, 1}],
                DisplayForm], 
              StyleBox["\[CenterDot]",
                FontColor->RGBColor[0, 0.392187, 0]], 
              TagBox[
                StyleBox[
                  InterpretationBox[
                    SubsuperscriptBox["c", 
                      RowBox[{"2", 
                        TagBox[
                          StyleBox["\<\"\[UpArrow]\"\>",
                            FontColor->RGBColor[1, 0, 0]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            1, 0, 0]]&)]}], "\<\"\"\>"],
                    Subsuperscript[ c, 
                      RowBox[ {2, 
                        StyleForm[ 
                        "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], ""],
                    
                    Editable->False],
                  ScriptSizeMultipliers->1,
                  ScriptBaselineShifts->{1, 1}],
                DisplayForm]}]}], ")"}]}], "+", 
      RowBox[{"t", " ", 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              TagBox[
                StyleBox[
                  InterpretationBox[
                    SubsuperscriptBox["c", 
                      RowBox[{"1", 
                        TagBox[
                          StyleBox["\<\"\[DownArrow]\"\>",
                            FontColor->RGBColor[0, 0, 1]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                    Subsuperscript[ c, 
                      RowBox[ {1, 
                        StyleForm[ 
                        "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], 
                      "\[Dagger]"],
                    Editable->False],
                  ScriptSizeMultipliers->1,
                  ScriptBaselineShifts->{1, 1}],
                DisplayForm], 
              StyleBox["\[CenterDot]",
                FontColor->RGBColor[0, 0.392187, 0]], 
              TagBox[
                StyleBox[
                  InterpretationBox[
                    SubsuperscriptBox["c", 
                      RowBox[{"2", 
                        TagBox[
                          StyleBox["\<\"\[DownArrow]\"\>",
                            FontColor->RGBColor[0, 0, 1]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            0, 0, 1]]&)]}], "\<\"\"\>"],
                    Subsuperscript[ c, 
                      RowBox[ {2, 
                        StyleForm[ 
                        "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], 
                      ""],
                    Editable->False],
                  ScriptSizeMultipliers->1,
                  ScriptBaselineShifts->{1, 1}],
                DisplayForm]}], "+", 
            RowBox[{
              TagBox[
                StyleBox[
                  InterpretationBox[
                    SubsuperscriptBox["c", 
                      RowBox[{"1", 
                        TagBox[
                          StyleBox["\<\"\[UpArrow]\"\>",
                            FontColor->RGBColor[1, 0, 0]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                    Subsuperscript[ c, 
                      RowBox[ {1, 
                        StyleForm[ 
                        "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                      "\[Dagger]"],
                    Editable->False],
                  ScriptSizeMultipliers->1,
                  ScriptBaselineShifts->{1, 1}],
                DisplayForm], 
              StyleBox["\[CenterDot]",
                FontColor->RGBColor[0, 0.392187, 0]], 
              TagBox[
                StyleBox[
                  InterpretationBox[
                    SubsuperscriptBox["c", 
                      RowBox[{"2", 
                        TagBox[
                          StyleBox["\<\"\[UpArrow]\"\>",
                            FontColor->RGBColor[1, 0, 0]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            1, 0, 0]]&)]}], "\<\"\"\>"],
                    Subsuperscript[ c, 
                      RowBox[ {2, 
                        StyleForm[ 
                        "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], ""],
                    
                    Editable->False],
                  ScriptSizeMultipliers->1,
                  ScriptBaselineShifts->{1, 1}],
                DisplayForm]}], "+", 
            RowBox[{
              TagBox[
                StyleBox[
                  InterpretationBox[
                    SubsuperscriptBox["c", 
                      RowBox[{"2", 
                        TagBox[
                          StyleBox["\<\"\[DownArrow]\"\>",
                            FontColor->RGBColor[0, 0, 1]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                    Subsuperscript[ c, 
                      RowBox[ {2, 
                        StyleForm[ 
                        "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], 
                      "\[Dagger]"],
                    Editable->False],
                  ScriptSizeMultipliers->1,
                  ScriptBaselineShifts->{1, 1}],
                DisplayForm], 
              StyleBox["\[CenterDot]",
                FontColor->RGBColor[0, 0.392187, 0]], 
              TagBox[
                StyleBox[
                  InterpretationBox[
                    SubsuperscriptBox["c", 
                      RowBox[{"1", 
                        TagBox[
                          StyleBox["\<\"\[DownArrow]\"\>",
                            FontColor->RGBColor[0, 0, 1]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            0, 0, 1]]&)]}], "\<\"\"\>"],
                    Subsuperscript[ c, 
                      RowBox[ {1, 
                        StyleForm[ 
                        "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], 
                      ""],
                    Editable->False],
                  ScriptSizeMultipliers->1,
                  ScriptBaselineShifts->{1, 1}],
                DisplayForm]}], "+", 
            RowBox[{
              TagBox[
                StyleBox[
                  InterpretationBox[
                    SubsuperscriptBox["c", 
                      RowBox[{"2", 
                        TagBox[
                          StyleBox["\<\"\[DownArrow]\"\>",
                            FontColor->RGBColor[0, 0, 1]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                    Subsuperscript[ c, 
                      RowBox[ {2, 
                        StyleForm[ 
                        "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], 
                      "\[Dagger]"],
                    Editable->False],
                  ScriptSizeMultipliers->1,
                  ScriptBaselineShifts->{1, 1}],
                DisplayForm], 
              StyleBox["\[CenterDot]",
                FontColor->RGBColor[0, 0.392187, 0]], 
              TagBox[
                StyleBox[
                  InterpretationBox[
                    SubsuperscriptBox["c", 
                      RowBox[{"3", 
                        TagBox[
                          StyleBox["\<\"\[DownArrow]\"\>",
                            FontColor->RGBColor[0, 0, 1]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            0, 0, 1]]&)]}], "\<\"\"\>"],
                    Subsuperscript[ c, 
                      RowBox[ {3, 
                        StyleForm[ 
                        "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], 
                      ""],
                    Editable->False],
                  ScriptSizeMultipliers->1,
                  ScriptBaselineShifts->{1, 1}],
                DisplayForm]}], "+", 
            RowBox[{
              TagBox[
                StyleBox[
                  InterpretationBox[
                    SubsuperscriptBox["c", 
                      RowBox[{"2", 
                        TagBox[
                          StyleBox["\<\"\[UpArrow]\"\>",
                            FontColor->RGBColor[1, 0, 0]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                    Subsuperscript[ c, 
                      RowBox[ {2, 
                        StyleForm[ 
                        "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                      "\[Dagger]"],
                    Editable->False],
                  ScriptSizeMultipliers->1,
                  ScriptBaselineShifts->{1, 1}],
                DisplayForm], 
              StyleBox["\[CenterDot]",
                FontColor->RGBColor[0, 0.392187, 0]], 
              TagBox[
                StyleBox[
                  InterpretationBox[
                    SubsuperscriptBox["c", 
                      RowBox[{"1", 
                        TagBox[
                          StyleBox["\<\"\[UpArrow]\"\>",
                            FontColor->RGBColor[1, 0, 0]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            1, 0, 0]]&)]}], "\<\"\"\>"],
                    Subsuperscript[ c, 
                      RowBox[ {1, 
                        StyleForm[ 
                        "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], ""],
                    
                    Editable->False],
                  ScriptSizeMultipliers->1,
                  ScriptBaselineShifts->{1, 1}],
                DisplayForm]}], "+", 
            RowBox[{
              TagBox[
                StyleBox[
                  InterpretationBox[
                    SubsuperscriptBox["c", 
                      RowBox[{"2", 
                        TagBox[
                          StyleBox["\<\"\[UpArrow]\"\>",
                            FontColor->RGBColor[1, 0, 0]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                    Subsuperscript[ c, 
                      RowBox[ {2, 
                        StyleForm[ 
                        "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                      "\[Dagger]"],
                    Editable->False],
                  ScriptSizeMultipliers->1,
                  ScriptBaselineShifts->{1, 1}],
                DisplayForm], 
              StyleBox["\[CenterDot]",
                FontColor->RGBColor[0, 0.392187, 0]], 
              TagBox[
                StyleBox[
                  InterpretationBox[
                    SubsuperscriptBox["c", 
                      RowBox[{"3", 
                        TagBox[
                          StyleBox["\<\"\[UpArrow]\"\>",
                            FontColor->RGBColor[1, 0, 0]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            1, 0, 0]]&)]}], "\<\"\"\>"],
                    Subsuperscript[ c, 
                      RowBox[ {3, 
                        StyleForm[ 
                        "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], ""],
                    
                    Editable->False],
                  ScriptSizeMultipliers->1,
                  ScriptBaselineShifts->{1, 1}],
                DisplayForm]}], "+", 
            RowBox[{
              TagBox[
                StyleBox[
                  InterpretationBox[
                    SubsuperscriptBox["c", 
                      RowBox[{"3", 
                        TagBox[
                          StyleBox["\<\"\[DownArrow]\"\>",
                            FontColor->RGBColor[0, 0, 1]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                    Subsuperscript[ c, 
                      RowBox[ {3, 
                        StyleForm[ 
                        "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], 
                      "\[Dagger]"],
                    Editable->False],
                  ScriptSizeMultipliers->1,
                  ScriptBaselineShifts->{1, 1}],
                DisplayForm], 
              StyleBox["\[CenterDot]",
                FontColor->RGBColor[0, 0.392187, 0]], 
              TagBox[
                StyleBox[
                  InterpretationBox[
                    SubsuperscriptBox["c", 
                      RowBox[{"2", 
                        TagBox[
                          StyleBox["\<\"\[DownArrow]\"\>",
                            FontColor->RGBColor[0, 0, 1]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            0, 0, 1]]&)]}], "\<\"\"\>"],
                    Subsuperscript[ c, 
                      RowBox[ {2, 
                        StyleForm[ 
                        "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], 
                      ""],
                    Editable->False],
                  ScriptSizeMultipliers->1,
                  ScriptBaselineShifts->{1, 1}],
                DisplayForm]}], "+", 
            RowBox[{
              TagBox[
                StyleBox[
                  InterpretationBox[
                    SubsuperscriptBox["c", 
                      RowBox[{"3", 
                        TagBox[
                          StyleBox["\<\"\[UpArrow]\"\>",
                            FontColor->RGBColor[1, 0, 0]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                    Subsuperscript[ c, 
                      RowBox[ {3, 
                        StyleForm[ 
                        "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                      "\[Dagger]"],
                    Editable->False],
                  ScriptSizeMultipliers->1,
                  ScriptBaselineShifts->{1, 1}],
                DisplayForm], 
              StyleBox["\[CenterDot]",
                FontColor->RGBColor[0, 0.392187, 0]], 
              TagBox[
                StyleBox[
                  InterpretationBox[
                    SubsuperscriptBox["c", 
                      RowBox[{"2", 
                        TagBox[
                          StyleBox["\<\"\[UpArrow]\"\>",
                            FontColor->RGBColor[1, 0, 0]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            1, 0, 0]]&)]}], "\<\"\"\>"],
                    Subsuperscript[ c, 
                      RowBox[ {2, 
                        StyleForm[ 
                        "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], ""],
                    
                    Editable->False],
                  ScriptSizeMultipliers->1,
                  ScriptBaselineShifts->{1, 1}],
                DisplayForm]}]}], ")"}]}], "+", 
      RowBox[{"\[Epsilon]", " ", 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              TagBox[
                StyleBox[
                  InterpretationBox[
                    SubsuperscriptBox["c", 
                      RowBox[{"3", 
                        TagBox[
                          StyleBox["\<\"\[DownArrow]\"\>",
                            FontColor->RGBColor[0, 0, 1]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                    Subsuperscript[ c, 
                      RowBox[ {3, 
                        StyleForm[ 
                        "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], 
                      "\[Dagger]"],
                    Editable->False],
                  ScriptSizeMultipliers->1,
                  ScriptBaselineShifts->{1, 1}],
                DisplayForm], 
              StyleBox["\[CenterDot]",
                FontColor->RGBColor[0, 0.392187, 0]], 
              TagBox[
                StyleBox[
                  InterpretationBox[
                    SubsuperscriptBox["c", 
                      RowBox[{"3", 
                        TagBox[
                          StyleBox["\<\"\[DownArrow]\"\>",
                            FontColor->RGBColor[0, 0, 1]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            0, 0, 1]]&)]}], "\<\"\"\>"],
                    Subsuperscript[ c, 
                      RowBox[ {3, 
                        StyleForm[ 
                        "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], 
                      ""],
                    Editable->False],
                  ScriptSizeMultipliers->1,
                  ScriptBaselineShifts->{1, 1}],
                DisplayForm]}], "+", 
            RowBox[{
              TagBox[
                StyleBox[
                  InterpretationBox[
                    SubsuperscriptBox["c", 
                      RowBox[{"3", 
                        TagBox[
                          StyleBox["\<\"\[UpArrow]\"\>",
                            FontColor->RGBColor[1, 0, 0]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                    Subsuperscript[ c, 
                      RowBox[ {3, 
                        StyleForm[ 
                        "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                      "\[Dagger]"],
                    Editable->False],
                  ScriptSizeMultipliers->1,
                  ScriptBaselineShifts->{1, 1}],
                DisplayForm], 
              StyleBox["\[CenterDot]",
                FontColor->RGBColor[0, 0.392187, 0]], 
              TagBox[
                StyleBox[
                  InterpretationBox[
                    SubsuperscriptBox["c", 
                      RowBox[{"3", 
                        TagBox[
                          StyleBox["\<\"\[UpArrow]\"\>",
                            FontColor->RGBColor[1, 0, 0]],
                          (StyleForm[ #, FontColor -> RGBColor[ 
                            1, 0, 0]]&)]}], "\<\"\"\>"],
                    Subsuperscript[ c, 
                      RowBox[ {3, 
                        StyleForm[ 
                        "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], ""],
                    
                    Editable->False],
                  ScriptSizeMultipliers->1,
                  ScriptBaselineShifts->{1, 1}],
                DisplayForm]}]}], ")"}]}], "-", 
      RowBox[{"U", 
        RowBox[{
          TagBox[
            StyleBox[
              InterpretationBox[
                SubsuperscriptBox["c", 
                  RowBox[{"1", 
                    TagBox[
                      StyleBox["\<\"\[DownArrow]\"\>",
                        FontColor->RGBColor[0, 0, 1]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                Subsuperscript[ c, 
                  RowBox[ {1, 
                    StyleForm[ 
                    "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], 
                  "\[Dagger]"],
                Editable->False],
              ScriptSizeMultipliers->1,
              ScriptBaselineShifts->{1, 1}],
            DisplayForm], 
          StyleBox["\[CenterDot]",
            FontColor->RGBColor[0, 0.392187, 0]], 
          TagBox[
            StyleBox[
              InterpretationBox[
                SubsuperscriptBox["c", 
                  RowBox[{"1", 
                    TagBox[
                      StyleBox["\<\"\[UpArrow]\"\>",
                        FontColor->RGBColor[1, 0, 0]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                Subsuperscript[ c, 
                  RowBox[ {1, 
                    StyleForm[ 
                    "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                  "\[Dagger]"],
                Editable->False],
              ScriptSizeMultipliers->1,
              ScriptBaselineShifts->{1, 1}],
            DisplayForm], 
          StyleBox["\[CenterDot]",
            FontColor->RGBColor[0, 0.392187, 0]], 
          TagBox[
            StyleBox[
              InterpretationBox[
                SubsuperscriptBox["c", 
                  RowBox[{"1", 
                    TagBox[
                      StyleBox["\<\"\[DownArrow]\"\>",
                        FontColor->RGBColor[0, 0, 1]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        0, 0, 1]]&)]}], "\<\"\"\>"],
                Subsuperscript[ c, 
                  RowBox[ {1, 
                    StyleForm[ 
                    "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], ""],
                Editable->False],
              ScriptSizeMultipliers->1,
              ScriptBaselineShifts->{1, 1}],
            DisplayForm], 
          StyleBox["\[CenterDot]",
            FontColor->RGBColor[0, 0.392187, 0]], 
          TagBox[
            StyleBox[
              InterpretationBox[
                SubsuperscriptBox["c", 
                  RowBox[{"1", 
                    TagBox[
                      StyleBox["\<\"\[UpArrow]\"\>",
                        FontColor->RGBColor[1, 0, 0]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        1, 0, 0]]&)]}], "\<\"\"\>"],
                Subsuperscript[ c, 
                  RowBox[ {1, 
                    StyleForm[ 
                    "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], ""],
                Editable->False],
              ScriptSizeMultipliers->1,
              ScriptBaselineShifts->{1, 1}],
            DisplayForm]}]}], "-", 
      RowBox[{"U", 
        RowBox[{
          TagBox[
            StyleBox[
              InterpretationBox[
                SubsuperscriptBox["c", 
                  RowBox[{"2", 
                    TagBox[
                      StyleBox["\<\"\[DownArrow]\"\>",
                        FontColor->RGBColor[0, 0, 1]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                Subsuperscript[ c, 
                  RowBox[ {2, 
                    StyleForm[ 
                    "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], 
                  "\[Dagger]"],
                Editable->False],
              ScriptSizeMultipliers->1,
              ScriptBaselineShifts->{1, 1}],
            DisplayForm], 
          StyleBox["\[CenterDot]",
            FontColor->RGBColor[0, 0.392187, 0]], 
          TagBox[
            StyleBox[
              InterpretationBox[
                SubsuperscriptBox["c", 
                  RowBox[{"2", 
                    TagBox[
                      StyleBox["\<\"\[UpArrow]\"\>",
                        FontColor->RGBColor[1, 0, 0]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                Subsuperscript[ c, 
                  RowBox[ {2, 
                    StyleForm[ 
                    "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                  "\[Dagger]"],
                Editable->False],
              ScriptSizeMultipliers->1,
              ScriptBaselineShifts->{1, 1}],
            DisplayForm], 
          StyleBox["\[CenterDot]",
            FontColor->RGBColor[0, 0.392187, 0]], 
          TagBox[
            StyleBox[
              InterpretationBox[
                SubsuperscriptBox["c", 
                  RowBox[{"2", 
                    TagBox[
                      StyleBox["\<\"\[DownArrow]\"\>",
                        FontColor->RGBColor[0, 0, 1]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        0, 0, 1]]&)]}], "\<\"\"\>"],
                Subsuperscript[ c, 
                  RowBox[ {2, 
                    StyleForm[ 
                    "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], ""],
                Editable->False],
              ScriptSizeMultipliers->1,
              ScriptBaselineShifts->{1, 1}],
            DisplayForm], 
          StyleBox["\[CenterDot]",
            FontColor->RGBColor[0, 0.392187, 0]], 
          TagBox[
            StyleBox[
              InterpretationBox[
                SubsuperscriptBox["c", 
                  RowBox[{"2", 
                    TagBox[
                      StyleBox["\<\"\[UpArrow]\"\>",
                        FontColor->RGBColor[1, 0, 0]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        1, 0, 0]]&)]}], "\<\"\"\>"],
                Subsuperscript[ c, 
                  RowBox[ {2, 
                    StyleForm[ 
                    "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], ""],
                Editable->False],
              ScriptSizeMultipliers->1,
              ScriptBaselineShifts->{1, 1}],
            DisplayForm]}]}], "-", 
      RowBox[{"U", 
        RowBox[{
          TagBox[
            StyleBox[
              InterpretationBox[
                SubsuperscriptBox["c", 
                  RowBox[{"3", 
                    TagBox[
                      StyleBox["\<\"\[DownArrow]\"\>",
                        FontColor->RGBColor[0, 0, 1]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                Subsuperscript[ c, 
                  RowBox[ {3, 
                    StyleForm[ 
                    "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], 
                  "\[Dagger]"],
                Editable->False],
              ScriptSizeMultipliers->1,
              ScriptBaselineShifts->{1, 1}],
            DisplayForm], 
          StyleBox["\[CenterDot]",
            FontColor->RGBColor[0, 0.392187, 0]], 
          TagBox[
            StyleBox[
              InterpretationBox[
                SubsuperscriptBox["c", 
                  RowBox[{"3", 
                    TagBox[
                      StyleBox["\<\"\[UpArrow]\"\>",
                        FontColor->RGBColor[1, 0, 0]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                Subsuperscript[ c, 
                  RowBox[ {3, 
                    StyleForm[ 
                    "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                  "\[Dagger]"],
                Editable->False],
              ScriptSizeMultipliers->1,
              ScriptBaselineShifts->{1, 1}],
            DisplayForm], 
          StyleBox["\[CenterDot]",
            FontColor->RGBColor[0, 0.392187, 0]], 
          TagBox[
            StyleBox[
              InterpretationBox[
                SubsuperscriptBox["c", 
                  RowBox[{"3", 
                    TagBox[
                      StyleBox["\<\"\[DownArrow]\"\>",
                        FontColor->RGBColor[0, 0, 1]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        0, 0, 1]]&)]}], "\<\"\"\>"],
                Subsuperscript[ c, 
                  RowBox[ {3, 
                    StyleForm[ 
                    "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], ""],
                Editable->False],
              ScriptSizeMultipliers->1,
              ScriptBaselineShifts->{1, 1}],
            DisplayForm], 
          StyleBox["\[CenterDot]",
            FontColor->RGBColor[0, 0.392187, 0]], 
          TagBox[
            StyleBox[
              InterpretationBox[
                SubsuperscriptBox["c", 
                  RowBox[{"3", 
                    TagBox[
                      StyleBox["\<\"\[UpArrow]\"\>",
                        FontColor->RGBColor[1, 0, 0]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        1, 0, 0]]&)]}], "\<\"\"\>"],
                Subsuperscript[ c, 
                  RowBox[ {3, 
                    StyleForm[ 
                    "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], ""],
                Editable->False],
              ScriptSizeMultipliers->1,
              ScriptBaselineShifts->{1, 1}],
            DisplayForm]}]}]}]], "Output",
  CellLabel->"Out[28]="],

Cell[BoxData[
    RowBox[{
      RowBox[{"t", " ", 
        RowBox[{"(", 
          RowBox[{
            TagBox[
              RowBox[{"hop", "[", 
                RowBox[{
                  TagBox[
                    StyleBox[
                      InterpretationBox[\(c\^\*"\<\"\"\>"\),
                        Superscript[ c, ""],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm], ",", 
                  TagBox[\(c[2]\),
                    DisplayForm]}], "]"}],
              HoldForm], "+", 
            TagBox[
              RowBox[{"hop", "[", 
                RowBox[{
                  TagBox[\(c[2]\),
                    DisplayForm], ",", 
                  TagBox[\(c[3]\),
                    DisplayForm]}], "]"}],
              HoldForm]}], ")"}]}], "+", 
      RowBox[{"U", " ", 
        TagBox[
          RowBox[{"hubbard", "[", 
            TagBox[
              StyleBox[
                InterpretationBox[\(c\^\*"\<\"\"\>"\),
                  Superscript[ c, ""],
                  Editable->False],
                ScriptSizeMultipliers->1,
                ScriptBaselineShifts->{1, 1}],
              DisplayForm], "]"}],
          HoldForm]}], "+", 
      RowBox[{"U", " ", 
        TagBox[
          RowBox[{"hubbard", "[", 
            TagBox[\(c[2]\),
              DisplayForm], "]"}],
          HoldForm]}], "+", 
      RowBox[{"U", " ", 
        TagBox[
          RowBox[{"hubbard", "[", 
            TagBox[\(c[3]\),
              DisplayForm], "]"}],
          HoldForm]}], "+", 
      RowBox[{"\[Epsilon]", " ", 
        TagBox[
          RowBox[{"number", "[", 
            TagBox[
              StyleBox[
                InterpretationBox[\(c\^\*"\<\"\"\>"\),
                  Superscript[ c, ""],
                  Editable->False],
                ScriptSizeMultipliers->1,
                ScriptBaselineShifts->{1, 1}],
              DisplayForm], "]"}],
          HoldForm]}], "+", 
      RowBox[{"\[Epsilon]", " ", 
        TagBox[
          RowBox[{"number", "[", 
            TagBox[\(c[2]\),
              DisplayForm], "]"}],
          HoldForm]}], "+", 
      RowBox[{"\[Epsilon]", " ", 
        TagBox[
          RowBox[{"number", "[", 
            TagBox[\(c[3]\),
              DisplayForm], "]"}],
          HoldForm]}]}]], "Output",
  CellLabel->"Out[29]="]
}, Open  ]]
}, Closed]]
}, Open  ]]
},
FrontEndVersion->"5.1 for X",
ScreenRectangle->{{0, 2880}, {0, 1200}},
WindowSize->{520, 600},
WindowMargins->{{Automatic, 285}, {216, Automatic}},
ShowSelection->True,
StyleDefinitions -> "HelpBrowser.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 34, 0, 38, "ObjectName"],
Cell[1813, 55, 221, 7, 48, "Usage"],
Cell[2037, 64, 171, 5, 40, "Notes"],
Cell[2211, 71, 265, 11, 24, "Notes"],

Cell[CellGroupData[{
Cell[2501, 86, 42, 0, 38, "ExampleSection"],
Cell[2546, 88, 151, 6, 34, "ExampleText"],

Cell[CellGroupData[{
Cell[2722, 98, 142, 3, 42, "Input"],
Cell[2867, 103, 103, 2, 21, "Print"]
}, Open  ]],

Cell[CellGroupData[{
Cell[3007, 110, 119, 3, 42, "Input"],
Cell[3129, 115, 2934, 81, 33, "Output"],
Cell[6066, 198, 93, 3, 25, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[6196, 206, 120, 3, 42, "Input"],
Cell[6319, 211, 3007, 82, 33, "Output"],
Cell[9329, 295, 94, 3, 25, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[9460, 303, 121, 3, 42, "Input"],
Cell[9584, 308, 5811, 160, 33, "Output"],
Cell[15398, 470, 95, 3, 25, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[15530, 478, 270, 7, 106, "Input"],
Cell[15803, 487, 3355, 85, 42, "Output"],
Cell[19161, 574, 93, 3, 25, "Output"],
Cell[19257, 579, 3617, 88, 42, "Output"],
Cell[22877, 669, 93, 3, 25, "Output"],
Cell[22973, 674, 3474, 86, 42, "Output"],
Cell[26450, 762, 281, 9, 42, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[26768, 776, 141, 3, 42, "Input"],
Cell[26912, 781, 14201, 339, 68, "Output"],
Cell[41116, 1122, 239, 8, 25, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[41392, 1135, 325, 7, 106, "Input"],
Cell[41720, 1144, 20507, 499, 68, "Output"],
Cell[62230, 1645, 101, 3, 25, "Output"],
Cell[62334, 1650, 6942, 170, 42, "Output"],
Cell[69279, 1822, 478, 16, 25, "Output"],
Cell[69760, 1840, 13527, 333, 68, "Output"],
Cell[83290, 2175, 239, 8, 25, "Output"]
}, Open  ]],
Cell[83544, 2186, 74, 0, 34, "ExampleText"],

Cell[CellGroupData[{
Cell[83643, 2190, 220, 5, 74, "Input"],
Cell[83866, 2197, 3351, 85, 33, "Output"],
Cell[87220, 2284, 123, 4, 25, "Output"],
Cell[87346, 2290, 3175, 84, 42, "Output"],
Cell[90524, 2376, 133, 4, 42, "Output"]
}, Open  ]],
Cell[90672, 2383, 53, 0, 34, "ExampleText"],

Cell[CellGroupData[{
Cell[90750, 2387, 169, 4, 58, "Input"],
Cell[90922, 2393, 35791, 872, 133, "Output"],
Cell[126716, 3267, 2439, 75, 74, "Output"]
}, Open  ]]
}, Closed]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

