(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.1'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     47567,       1123]*)
(*NotebookOutlinePosition[     48610,       1157]*)
(*  CellTagsIndexPosition[     48484,       1150]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["makeallmatricesbzvc", "ObjectName"],

Cell[TextData[{
  "\[FilledSmallSquare] ",
  StyleBox["makeallmatricesbzvc[", "MR"],
  StyleBox["op", "TI"],
  StyleBox[",", "MR"],
  StyleBox["bz", "TI"],
  StyleBox["]", "MR"],
  " computes the matrix representation of the operator ",
  StyleBox["op", "IT"],
  " in the basis ",
  StyleBox["bz", "TI"],
  " (occupation number representation). \n\[FilledSmallSquare] ",
  StyleBox["makeallmatricesbzop[", "MR"],
  StyleBox["op", "TI"],
  StyleBox[",", "MR"],
  StyleBox["bz", "TI"],
  StyleBox["]", "MR"],
  " computes the matrix representation of the operator ",
  StyleBox["op", "IT"],
  " in the basis ",
  StyleBox["bz", "TI"],
  " (creation operator representation). "
}], "Usage",
  CellTags->{"makeallmatricesbzvc", "makeallmatricesbzop"}],

Cell["\<\
\[FilledSmallSquare] All pairs of invariant subspaces are \
considered. \
\>", "Notes"],

Cell["\<\
\[FilledSmallSquare] NOTE: Only the pairs of subspaces which give \
non-zero matrix elements are returned.\
\>", "Notes"],

Cell[TextData[{
  "\[FilledSmallSquare] See also:  ",
  ButtonBox["makematricesbzop",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["makematricesbzvc",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["matrixrepresentationvc",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes"],

Cell[CellGroupData[{

Cell["Further examples", "ExampleSection"],

Cell[TextData[{
  "Load sneg, let ",
  StyleBox["c", "TI"],
  " be a fermionic operator "
}], "ExampleText"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(<< sneg`sneg`;\)\), "\[IndentingNewLine]", 
    \(\(snegfermionoperators[c];\)\)}], "Input",
  CellLabel->"In[1]:="],

Cell[BoxData[
    \("sneg 1.168 Copyright (C) 2007 Rok Zitko"\)], "Print",
  CellLabel->"From In[1]:="]
}, Open  ]],

Cell["Two-site Hubbard model", "ExampleText"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(snegrealconstants[t, U];\)\), "\[IndentingNewLine]", 
    \(H = 
      t\ hop[c[1], c[2]] + 
        U\ Plus\  @@ \ \(hubbard /@ {c[1], c[2]}\)\)}], "Input",
  CellLabel->"In[3]:="],

Cell[BoxData[
    RowBox[{
      RowBox[{"t", " ", 
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              TagBox[
                StyleBox[
                  InterpretationBox[
                    SubsuperscriptBox["c", 
                      RowBox[{"1", 
                        TagBox[
                          StyleBox["\<\"\[DownArrow]\"\>",
                            FontColor->RGBColor[0, 0, 1]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                    Subsuperscript[ c, 
                      RowBox[ {1, 
                        StyleForm[ 
                        "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], 
                      "\[Dagger]"],
                    Editable->False],
                  ScriptSizeMultipliers->1,
                  ScriptBaselineShifts->{1, 1}],
                DisplayForm], 
              StyleBox["\[CenterDot]",
                FontColor->RGBColor[0, 0.392187, 0]], 
              TagBox[
                StyleBox[
                  InterpretationBox[
                    SubsuperscriptBox["c", 
                      RowBox[{"2", 
                        TagBox[
                          StyleBox["\<\"\[DownArrow]\"\>",
                            FontColor->RGBColor[0, 0, 1]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            0, 0, 1]]&)]}], "\<\"\"\>"],
                    Subsuperscript[ c, 
                      RowBox[ {2, 
                        StyleForm[ 
                        "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], 
                      ""],
                    Editable->False],
                  ScriptSizeMultipliers->1,
                  ScriptBaselineShifts->{1, 1}],
                DisplayForm]}], "+", 
            RowBox[{
              TagBox[
                StyleBox[
                  InterpretationBox[
                    SubsuperscriptBox["c", 
                      RowBox[{"1", 
                        TagBox[
                          StyleBox["\<\"\[UpArrow]\"\>",
                            FontColor->RGBColor[1, 0, 0]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                    Subsuperscript[ c, 
                      RowBox[ {1, 
                        StyleForm[ 
                        "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                      "\[Dagger]"],
                    Editable->False],
                  ScriptSizeMultipliers->1,
                  ScriptBaselineShifts->{1, 1}],
                DisplayForm], 
              StyleBox["\[CenterDot]",
                FontColor->RGBColor[0, 0.392187, 0]], 
              TagBox[
                StyleBox[
                  InterpretationBox[
                    SubsuperscriptBox["c", 
                      RowBox[{"2", 
                        TagBox[
                          StyleBox["\<\"\[UpArrow]\"\>",
                            FontColor->RGBColor[1, 0, 0]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            1, 0, 0]]&)]}], "\<\"\"\>"],
                    Subsuperscript[ c, 
                      RowBox[ {2, 
                        StyleForm[ 
                        "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], ""],
                    
                    Editable->False],
                  ScriptSizeMultipliers->1,
                  ScriptBaselineShifts->{1, 1}],
                DisplayForm]}], "+", 
            RowBox[{
              TagBox[
                StyleBox[
                  InterpretationBox[
                    SubsuperscriptBox["c", 
                      RowBox[{"2", 
                        TagBox[
                          StyleBox["\<\"\[DownArrow]\"\>",
                            FontColor->RGBColor[0, 0, 1]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                    Subsuperscript[ c, 
                      RowBox[ {2, 
                        StyleForm[ 
                        "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], 
                      "\[Dagger]"],
                    Editable->False],
                  ScriptSizeMultipliers->1,
                  ScriptBaselineShifts->{1, 1}],
                DisplayForm], 
              StyleBox["\[CenterDot]",
                FontColor->RGBColor[0, 0.392187, 0]], 
              TagBox[
                StyleBox[
                  InterpretationBox[
                    SubsuperscriptBox["c", 
                      RowBox[{"1", 
                        TagBox[
                          StyleBox["\<\"\[DownArrow]\"\>",
                            FontColor->RGBColor[0, 0, 1]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            0, 0, 1]]&)]}], "\<\"\"\>"],
                    Subsuperscript[ c, 
                      RowBox[ {1, 
                        StyleForm[ 
                        "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], 
                      ""],
                    Editable->False],
                  ScriptSizeMultipliers->1,
                  ScriptBaselineShifts->{1, 1}],
                DisplayForm]}], "+", 
            RowBox[{
              TagBox[
                StyleBox[
                  InterpretationBox[
                    SubsuperscriptBox["c", 
                      RowBox[{"2", 
                        TagBox[
                          StyleBox["\<\"\[UpArrow]\"\>",
                            FontColor->RGBColor[1, 0, 0]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                    Subsuperscript[ c, 
                      RowBox[ {2, 
                        StyleForm[ 
                        "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                      "\[Dagger]"],
                    Editable->False],
                  ScriptSizeMultipliers->1,
                  ScriptBaselineShifts->{1, 1}],
                DisplayForm], 
              StyleBox["\[CenterDot]",
                FontColor->RGBColor[0, 0.392187, 0]], 
              TagBox[
                StyleBox[
                  InterpretationBox[
                    SubsuperscriptBox["c", 
                      RowBox[{"1", 
                        TagBox[
                          StyleBox["\<\"\[UpArrow]\"\>",
                            FontColor->RGBColor[1, 0, 0]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            1, 0, 0]]&)]}], "\<\"\"\>"],
                    Subsuperscript[ c, 
                      RowBox[ {1, 
                        StyleForm[ 
                        "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], ""],
                    
                    Editable->False],
                  ScriptSizeMultipliers->1,
                  ScriptBaselineShifts->{1, 1}],
                DisplayForm]}]}], ")"}]}], "+", 
      RowBox[{"U", " ", 
        RowBox[{"(", 
          RowBox[{
            RowBox[{"\<\"-\"\>", 
              RowBox[{
                TagBox[
                  StyleBox[
                    InterpretationBox[
                      SubsuperscriptBox["c", 
                        RowBox[{"1", 
                          TagBox[
                            StyleBox["\<\"\[DownArrow]\"\>",
                              FontColor->RGBColor[0, 0, 1]],
                            (
                            StyleForm[ #, FontColor -> RGBColor[ 
                              0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                      Subsuperscript[ c, 
                        RowBox[ {1, 
                          StyleForm[ 
                          "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], 
                        "\[Dagger]"],
                      Editable->False],
                    ScriptSizeMultipliers->1,
                    ScriptBaselineShifts->{1, 1}],
                  DisplayForm], 
                StyleBox["\[CenterDot]",
                  FontColor->RGBColor[0, 0.392187, 0]], 
                TagBox[
                  StyleBox[
                    InterpretationBox[
                      SubsuperscriptBox["c", 
                        RowBox[{"1", 
                          TagBox[
                            StyleBox["\<\"\[UpArrow]\"\>",
                              FontColor->RGBColor[1, 0, 0]],
                            (
                            StyleForm[ #, FontColor -> RGBColor[ 
                              1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                      Subsuperscript[ c, 
                        RowBox[ {1, 
                          StyleForm[ 
                          "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                        "\[Dagger]"],
                      Editable->False],
                    ScriptSizeMultipliers->1,
                    ScriptBaselineShifts->{1, 1}],
                  DisplayForm], 
                StyleBox["\[CenterDot]",
                  FontColor->RGBColor[0, 0.392187, 0]], 
                TagBox[
                  StyleBox[
                    InterpretationBox[
                      SubsuperscriptBox["c", 
                        RowBox[{"1", 
                          TagBox[
                            StyleBox["\<\"\[DownArrow]\"\>",
                              FontColor->RGBColor[0, 0, 1]],
                            (
                            StyleForm[ #, FontColor -> RGBColor[ 
                              0, 0, 1]]&)]}], "\<\"\"\>"],
                      Subsuperscript[ c, 
                        RowBox[ {1, 
                          StyleForm[ 
                          "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], 
                        ""],
                      Editable->False],
                    ScriptSizeMultipliers->1,
                    ScriptBaselineShifts->{1, 1}],
                  DisplayForm], 
                StyleBox["\[CenterDot]",
                  FontColor->RGBColor[0, 0.392187, 0]], 
                TagBox[
                  StyleBox[
                    InterpretationBox[
                      SubsuperscriptBox["c", 
                        RowBox[{"1", 
                          TagBox[
                            StyleBox["\<\"\[UpArrow]\"\>",
                              FontColor->RGBColor[1, 0, 0]],
                            (
                            StyleForm[ #, FontColor -> RGBColor[ 
                              1, 0, 0]]&)]}], "\<\"\"\>"],
                      Subsuperscript[ c, 
                        RowBox[ {1, 
                          StyleForm[ 
                          "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                        ""],
                      Editable->False],
                    ScriptSizeMultipliers->1,
                    ScriptBaselineShifts->{1, 1}],
                  DisplayForm]}]}], "-", 
            RowBox[{
              TagBox[
                StyleBox[
                  InterpretationBox[
                    SubsuperscriptBox["c", 
                      RowBox[{"2", 
                        TagBox[
                          StyleBox["\<\"\[DownArrow]\"\>",
                            FontColor->RGBColor[0, 0, 1]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                    Subsuperscript[ c, 
                      RowBox[ {2, 
                        StyleForm[ 
                        "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], 
                      "\[Dagger]"],
                    Editable->False],
                  ScriptSizeMultipliers->1,
                  ScriptBaselineShifts->{1, 1}],
                DisplayForm], 
              StyleBox["\[CenterDot]",
                FontColor->RGBColor[0, 0.392187, 0]], 
              TagBox[
                StyleBox[
                  InterpretationBox[
                    SubsuperscriptBox["c", 
                      RowBox[{"2", 
                        TagBox[
                          StyleBox["\<\"\[UpArrow]\"\>",
                            FontColor->RGBColor[1, 0, 0]],
                          (StyleForm[ #, FontColor -> RGBColor[ 
                            1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                    Subsuperscript[ c, 
                      RowBox[ {2, 
                        StyleForm[ 
                        "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                      "\[Dagger]"],
                    Editable->False],
                  ScriptSizeMultipliers->1,
                  ScriptBaselineShifts->{1, 1}],
                DisplayForm], 
              StyleBox["\[CenterDot]",
                FontColor->RGBColor[0, 0.392187, 0]], 
              TagBox[
                StyleBox[
                  InterpretationBox[
                    SubsuperscriptBox["c", 
                      RowBox[{"2", 
                        TagBox[
                          StyleBox["\<\"\[DownArrow]\"\>",
                            FontColor->RGBColor[0, 0, 1]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            0, 0, 1]]&)]}], "\<\"\"\>"],
                    Subsuperscript[ c, 
                      RowBox[ {2, 
                        StyleForm[ 
                        "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], 
                      ""],
                    Editable->False],
                  ScriptSizeMultipliers->1,
                  ScriptBaselineShifts->{1, 1}],
                DisplayForm], 
              StyleBox["\[CenterDot]",
                FontColor->RGBColor[0, 0.392187, 0]], 
              TagBox[
                StyleBox[
                  InterpretationBox[
                    SubsuperscriptBox["c", 
                      RowBox[{"2", 
                        TagBox[
                          StyleBox["\<\"\[UpArrow]\"\>",
                            FontColor->RGBColor[1, 0, 0]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            1, 0, 0]]&)]}], "\<\"\"\>"],
                    Subsuperscript[ c, 
                      RowBox[ {2, 
                        StyleForm[ 
                        "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], ""],
                    
                    Editable->False],
                  ScriptSizeMultipliers->1,
                  ScriptBaselineShifts->{1, 1}],
                DisplayForm]}]}], ")"}]}]}]], "Output",
  CellLabel->"Out[4]="]
}, Open  ]],

Cell["\<\
Generate the basis states and produce Hamiltonian matrices in \
invariant subspaces. Hamiltonian operator is by definition diagonal with \
respect to the invariant subspaces!\
\>", "ExampleText"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(bz = qsbasis[{c[1], c[2]}];\)\), "\[IndentingNewLine]", 
    \(MatrixForm[bz]\), "\[IndentingNewLine]", 
    \(\(ham = makeallmatricesbzop[H, bz];\)\), "\[IndentingNewLine]", 
    \(MatrixForm\ @\ 
      Map[{First[#], MatrixForm\ @\ Last[#]} &\ , ham]\)}], "Input",
  CellLabel->"In[5]:="],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {\({\(-2\), 0}\), \({1}\)},
            {\({\(-1\), 1\/2}\), 
              RowBox[{"{", 
                RowBox[{
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["c", 
                          RowBox[{"2", 
                            TagBox[
                              StyleBox["\<\"\[UpArrow]\"\>",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                        Subsuperscript[ c, 
                          RowBox[ {2, 
                            StyleForm[ 
                            "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                          "\[Dagger]"],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm], ",", 
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["c", 
                          RowBox[{"1", 
                            TagBox[
                              StyleBox["\<\"\[UpArrow]\"\>",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                        Subsuperscript[ c, 
                          RowBox[ {1, 
                            StyleForm[ 
                            "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                          "\[Dagger]"],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm]}], "}"}]},
            {\({0, 0}\), 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    TagBox[
                      StyleBox[
                        InterpretationBox[
                          SubsuperscriptBox["c", 
                            RowBox[{"2", 
                              TagBox[
                                StyleBox["\<\"\[DownArrow]\"\>",
                                  FontColor->RGBColor[0, 0, 1]],
                                (
                                StyleForm[ #, FontColor -> RGBColor[ 
                                  0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                          Subsuperscript[ c, 
                            RowBox[ {2, 
                              StyleForm[ 
                              "\[DownArrow]", FontColor -> RGBColor[ 
                                0, 0, 1]]}], "\[Dagger]"],
                          Editable->False],
                        ScriptSizeMultipliers->1,
                        ScriptBaselineShifts->{1, 1}],
                      DisplayForm], 
                    StyleBox["\[CenterDot]",
                      FontColor->RGBColor[0, 0.392187, 0]], 
                    TagBox[
                      StyleBox[
                        InterpretationBox[
                          SubsuperscriptBox["c", 
                            RowBox[{"2", 
                              TagBox[
                                StyleBox["\<\"\[UpArrow]\"\>",
                                  FontColor->RGBColor[1, 0, 0]],
                                (
                                StyleForm[ #, FontColor -> RGBColor[ 
                                  1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                          Subsuperscript[ c, 
                            RowBox[ {2, 
                              StyleForm[ 
                              "\[UpArrow]", FontColor -> RGBColor[ 
                                1, 0, 0]]}], "\[Dagger]"],
                          Editable->False],
                        ScriptSizeMultipliers->1,
                        ScriptBaselineShifts->{1, 1}],
                      DisplayForm]}], ",", 
                  FractionBox[
                    RowBox[{
                      RowBox[{
                        TagBox[
                          StyleBox[
                            InterpretationBox[
                              SubsuperscriptBox["c", 
                                RowBox[{"1", 
                                  TagBox[
                                    StyleBox["\<\"\[DownArrow]\"\>",
                                      FontColor->RGBColor[0, 0, 1]],
                                    (
                                    StyleForm[ #, FontColor -> RGBColor[ 
                                      0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                              Subsuperscript[ c, 
                                RowBox[ {1, 
                                  StyleForm[ 
                                  "\[DownArrow]", FontColor -> RGBColor[ 
                                    0, 0, 1]]}], "\[Dagger]"],
                              Editable->False],
                            ScriptSizeMultipliers->1,
                            ScriptBaselineShifts->{1, 1}],
                          DisplayForm], 
                        StyleBox["\[CenterDot]",
                          FontColor->RGBColor[0, 0.392187, 0]], 
                        TagBox[
                          StyleBox[
                            InterpretationBox[
                              SubsuperscriptBox["c", 
                                RowBox[{"2", 
                                  TagBox[
                                    StyleBox["\<\"\[UpArrow]\"\>",
                                      FontColor->RGBColor[1, 0, 0]],
                                    (
                                    StyleForm[ #, FontColor -> RGBColor[ 
                                      1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                              Subsuperscript[ c, 
                                RowBox[ {2, 
                                  StyleForm[ 
                                  "\[UpArrow]", FontColor -> RGBColor[ 
                                    1, 0, 0]]}], "\[Dagger]"],
                              Editable->False],
                            ScriptSizeMultipliers->1,
                            ScriptBaselineShifts->{1, 1}],
                          DisplayForm]}], "-", 
                      RowBox[{
                        TagBox[
                          StyleBox[
                            InterpretationBox[
                              SubsuperscriptBox["c", 
                                RowBox[{"1", 
                                  TagBox[
                                    StyleBox["\<\"\[UpArrow]\"\>",
                                      FontColor->RGBColor[1, 0, 0]],
                                    (
                                    StyleForm[ #, FontColor -> RGBColor[ 
                                      1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                              Subsuperscript[ c, 
                                RowBox[ {1, 
                                  StyleForm[ 
                                  "\[UpArrow]", FontColor -> RGBColor[ 
                                    1, 0, 0]]}], "\[Dagger]"],
                              Editable->False],
                            ScriptSizeMultipliers->1,
                            ScriptBaselineShifts->{1, 1}],
                          DisplayForm], 
                        StyleBox["\[CenterDot]",
                          FontColor->RGBColor[0, 0.392187, 0]], 
                        TagBox[
                          StyleBox[
                            InterpretationBox[
                              SubsuperscriptBox["c", 
                                RowBox[{"2", 
                                  TagBox[
                                    StyleBox["\<\"\[DownArrow]\"\>",
                                      FontColor->RGBColor[0, 0, 1]],
                                    (
                                    StyleForm[ #, FontColor -> RGBColor[ 
                                      0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                              Subsuperscript[ c, 
                                RowBox[ {2, 
                                  StyleForm[ 
                                  "\[DownArrow]", FontColor -> RGBColor[ 
                                    0, 0, 1]]}], "\[Dagger]"],
                              Editable->False],
                            ScriptSizeMultipliers->1,
                            ScriptBaselineShifts->{1, 1}],
                          DisplayForm]}]}], \(\@2\)], ",", 
                  RowBox[{
                    TagBox[
                      StyleBox[
                        InterpretationBox[
                          SubsuperscriptBox["c", 
                            RowBox[{"1", 
                              TagBox[
                                StyleBox["\<\"\[DownArrow]\"\>",
                                  FontColor->RGBColor[0, 0, 1]],
                                (
                                StyleForm[ #, FontColor -> RGBColor[ 
                                  0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                          Subsuperscript[ c, 
                            RowBox[ {1, 
                              StyleForm[ 
                              "\[DownArrow]", FontColor -> RGBColor[ 
                                0, 0, 1]]}], "\[Dagger]"],
                          Editable->False],
                        ScriptSizeMultipliers->1,
                        ScriptBaselineShifts->{1, 1}],
                      DisplayForm], 
                    StyleBox["\[CenterDot]",
                      FontColor->RGBColor[0, 0.392187, 0]], 
                    TagBox[
                      StyleBox[
                        InterpretationBox[
                          SubsuperscriptBox["c", 
                            RowBox[{"1", 
                              TagBox[
                                StyleBox["\<\"\[UpArrow]\"\>",
                                  FontColor->RGBColor[1, 0, 0]],
                                (
                                StyleForm[ #, FontColor -> RGBColor[ 
                                  1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                          Subsuperscript[ c, 
                            RowBox[ {1, 
                              StyleForm[ 
                              "\[UpArrow]", FontColor -> RGBColor[ 
                                1, 0, 0]]}], "\[Dagger]"],
                          Editable->False],
                        ScriptSizeMultipliers->1,
                        ScriptBaselineShifts->{1, 1}],
                      DisplayForm]}]}], "}"}]},
            {\({0, 1}\), 
              RowBox[{"{", 
                RowBox[{"\<\"-\"\>", 
                  RowBox[{
                    TagBox[
                      StyleBox[
                        InterpretationBox[
                          SubsuperscriptBox["c", 
                            RowBox[{"1", 
                              TagBox[
                                StyleBox["\<\"\[UpArrow]\"\>",
                                  FontColor->RGBColor[1, 0, 0]],
                                (
                                StyleForm[ #, FontColor -> RGBColor[ 
                                  1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                          Subsuperscript[ c, 
                            RowBox[ {1, 
                              StyleForm[ 
                              "\[UpArrow]", FontColor -> RGBColor[ 
                                1, 0, 0]]}], "\[Dagger]"],
                          Editable->False],
                        ScriptSizeMultipliers->1,
                        ScriptBaselineShifts->{1, 1}],
                      DisplayForm], 
                    StyleBox["\[CenterDot]",
                      FontColor->RGBColor[0, 0.392187, 0]], 
                    TagBox[
                      StyleBox[
                        InterpretationBox[
                          SubsuperscriptBox["c", 
                            RowBox[{"2", 
                              TagBox[
                                StyleBox["\<\"\[UpArrow]\"\>",
                                  FontColor->RGBColor[1, 0, 0]],
                                (
                                StyleForm[ #, FontColor -> RGBColor[ 
                                  1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                          Subsuperscript[ c, 
                            RowBox[ {2, 
                              StyleForm[ 
                              "\[UpArrow]", FontColor -> RGBColor[ 
                                1, 0, 0]]}], "\[Dagger]"],
                          Editable->False],
                        ScriptSizeMultipliers->1,
                        ScriptBaselineShifts->{1, 1}],
                      DisplayForm]}]}], "}"}]},
            {\({1, 1\/2}\), 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    TagBox[
                      StyleBox[
                        InterpretationBox[
                          SubsuperscriptBox["c", 
                            RowBox[{"1", 
                              TagBox[
                                StyleBox["\<\"\[UpArrow]\"\>",
                                  FontColor->RGBColor[1, 0, 0]],
                                (
                                StyleForm[ #, FontColor -> RGBColor[ 
                                  1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                          Subsuperscript[ c, 
                            RowBox[ {1, 
                              StyleForm[ 
                              "\[UpArrow]", FontColor -> RGBColor[ 
                                1, 0, 0]]}], "\[Dagger]"],
                          Editable->False],
                        ScriptSizeMultipliers->1,
                        ScriptBaselineShifts->{1, 1}],
                      DisplayForm], 
                    StyleBox["\[CenterDot]",
                      FontColor->RGBColor[0, 0.392187, 0]], 
                    TagBox[
                      StyleBox[
                        InterpretationBox[
                          SubsuperscriptBox["c", 
                            RowBox[{"2", 
                              TagBox[
                                StyleBox["\<\"\[DownArrow]\"\>",
                                  FontColor->RGBColor[0, 0, 1]],
                                (
                                StyleForm[ #, FontColor -> RGBColor[ 
                                  0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                          Subsuperscript[ c, 
                            RowBox[ {2, 
                              StyleForm[ 
                              "\[DownArrow]", FontColor -> RGBColor[ 
                                0, 0, 1]]}], "\[Dagger]"],
                          Editable->False],
                        ScriptSizeMultipliers->1,
                        ScriptBaselineShifts->{1, 1}],
                      DisplayForm], 
                    StyleBox["\[CenterDot]",
                      FontColor->RGBColor[0, 0.392187, 0]], 
                    TagBox[
                      StyleBox[
                        InterpretationBox[
                          SubsuperscriptBox["c", 
                            RowBox[{"2", 
                              TagBox[
                                StyleBox["\<\"\[UpArrow]\"\>",
                                  FontColor->RGBColor[1, 0, 0]],
                                (
                                StyleForm[ #, FontColor -> RGBColor[ 
                                  1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                          Subsuperscript[ c, 
                            RowBox[ {2, 
                              StyleForm[ 
                              "\[UpArrow]", FontColor -> RGBColor[ 
                                1, 0, 0]]}], "\[Dagger]"],
                          Editable->False],
                        ScriptSizeMultipliers->1,
                        ScriptBaselineShifts->{1, 1}],
                      DisplayForm]}], ",", 
                  RowBox[{
                    TagBox[
                      StyleBox[
                        InterpretationBox[
                          SubsuperscriptBox["c", 
                            RowBox[{"1", 
                              TagBox[
                                StyleBox["\<\"\[DownArrow]\"\>",
                                  FontColor->RGBColor[0, 0, 1]],
                                (
                                StyleForm[ #, FontColor -> RGBColor[ 
                                  0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                          Subsuperscript[ c, 
                            RowBox[ {1, 
                              StyleForm[ 
                              "\[DownArrow]", FontColor -> RGBColor[ 
                                0, 0, 1]]}], "\[Dagger]"],
                          Editable->False],
                        ScriptSizeMultipliers->1,
                        ScriptBaselineShifts->{1, 1}],
                      DisplayForm], 
                    StyleBox["\[CenterDot]",
                      FontColor->RGBColor[0, 0.392187, 0]], 
                    TagBox[
                      StyleBox[
                        InterpretationBox[
                          SubsuperscriptBox["c", 
                            RowBox[{"1", 
                              TagBox[
                                StyleBox["\<\"\[UpArrow]\"\>",
                                  FontColor->RGBColor[1, 0, 0]],
                                (
                                StyleForm[ #, FontColor -> RGBColor[ 
                                  1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                          Subsuperscript[ c, 
                            RowBox[ {1, 
                              StyleForm[ 
                              "\[UpArrow]", FontColor -> RGBColor[ 
                                1, 0, 0]]}], "\[Dagger]"],
                          Editable->False],
                        ScriptSizeMultipliers->1,
                        ScriptBaselineShifts->{1, 1}],
                      DisplayForm], 
                    StyleBox["\[CenterDot]",
                      FontColor->RGBColor[0, 0.392187, 0]], 
                    TagBox[
                      StyleBox[
                        InterpretationBox[
                          SubsuperscriptBox["c", 
                            RowBox[{"2", 
                              TagBox[
                                StyleBox["\<\"\[UpArrow]\"\>",
                                  FontColor->RGBColor[1, 0, 0]],
                                (
                                StyleForm[ #, FontColor -> RGBColor[ 
                                  1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                          Subsuperscript[ c, 
                            RowBox[ {2, 
                              StyleForm[ 
                              "\[UpArrow]", FontColor -> RGBColor[ 
                                1, 0, 0]]}], "\[Dagger]"],
                          Editable->False],
                        ScriptSizeMultipliers->1,
                        ScriptBaselineShifts->{1, 1}],
                      DisplayForm]}]}], "}"}]},
            {\({2, 0}\), 
              RowBox[{"{", 
                RowBox[{
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["c", 
                          RowBox[{"1", 
                            TagBox[
                              StyleBox["\<\"\[DownArrow]\"\>",
                                FontColor->RGBColor[0, 0, 1]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                        Subsuperscript[ c, 
                          RowBox[ {1, 
                            StyleForm[ 
                            "\[DownArrow]", FontColor -> RGBColor[ 
                              0, 0, 1]]}], "\[Dagger]"],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm], 
                  StyleBox["\[CenterDot]",
                    FontColor->RGBColor[0, 0.392187, 0]], 
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["c", 
                          RowBox[{"1", 
                            TagBox[
                              StyleBox["\<\"\[UpArrow]\"\>",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                        Subsuperscript[ c, 
                          RowBox[ {1, 
                            StyleForm[ 
                            "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                          "\[Dagger]"],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm], 
                  StyleBox["\[CenterDot]",
                    FontColor->RGBColor[0, 0.392187, 0]], 
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["c", 
                          RowBox[{"2", 
                            TagBox[
                              StyleBox["\<\"\[DownArrow]\"\>",
                                FontColor->RGBColor[0, 0, 1]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                        Subsuperscript[ c, 
                          RowBox[ {2, 
                            StyleForm[ 
                            "\[DownArrow]", FontColor -> RGBColor[ 
                              0, 0, 1]]}], "\[Dagger]"],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm], 
                  StyleBox["\[CenterDot]",
                    FontColor->RGBColor[0, 0.392187, 0]], 
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["c", 
                          RowBox[{"2", 
                            TagBox[
                              StyleBox["\<\"\[UpArrow]\"\>",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                        Subsuperscript[ c, 
                          RowBox[ {2, 
                            StyleForm[ 
                            "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                          "\[Dagger]"],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm]}], "}"}]}
            },
          RowSpacings->1,
          ColumnSpacings->1,
          ColumnAlignments->{Left}], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Output",
  CellLabel->"Out[6]//MatrixForm="],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {\({{\(-1\), 1\/2}, {\(-1\), 1\/2}}\), 
              TagBox[
                RowBox[{"(", "\[NoBreak]", GridBox[{
                      {"0", "t"},
                      {"t", "0"}
                      },
                    RowSpacings->1,
                    ColumnSpacings->1,
                    ColumnAlignments->{Left}], "\[NoBreak]", ")"}],
                Function[ BoxForm`e$, 
                  MatrixForm[ BoxForm`e$]]]},
            {\({{0, 0}, {0, 0}}\), 
              TagBox[
                RowBox[{"(", "\[NoBreak]", GridBox[{
                      {"U", \(\@2\ t\), "0"},
                      {\(\@2\ t\), "0", \(\@2\ t\)},
                      {"0", \(\@2\ t\), "U"}
                      },
                    RowSpacings->1,
                    ColumnSpacings->1,
                    ColumnAlignments->{Left}], "\[NoBreak]", ")"}],
                Function[ BoxForm`e$, 
                  MatrixForm[ BoxForm`e$]]]},
            {\({{1, 1\/2}, {1, 1\/2}}\), 
              TagBox[
                RowBox[{"(", "\[NoBreak]", GridBox[{
                      {"U", \(-t\)},
                      {\(-t\), "U"}
                      },
                    RowSpacings->1,
                    ColumnSpacings->1,
                    ColumnAlignments->{Left}], "\[NoBreak]", ")"}],
                Function[ BoxForm`e$, 
                  MatrixForm[ BoxForm`e$]]]},
            {\({{2, 0}, {2, 0}}\), 
              TagBox[
                RowBox[{"(", "\[NoBreak]", GridBox[{
                      {\(2\ U\)}
                      },
                    RowSpacings->1,
                    ColumnSpacings->1,
                    ColumnAlignments->{Left}], "\[NoBreak]", ")"}],
                Function[ BoxForm`e$, 
                  MatrixForm[ BoxForm`e$]]]}
            },
          RowSpacings->1,
          ColumnSpacings->1,
          ColumnAlignments->{Left}], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Output",
  CellLabel->"Out[8]//MatrixForm="]
}, Open  ]],

Cell["Matrix elements of the creation operator", "ExampleText"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(ham = 
        makeallmatricesbzop[c[CR, 1, DO], bz];\)\), "\[IndentingNewLine]", 
    \(MatrixForm\ @\ 
      Map[{First[#], MatrixForm\ @\ Last[#]} &\ , ham]\)}], "Input",
  CellLabel->"In[9]:="],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {\({{0, 0}, {\(-1\), 1\/2}}\), 
              TagBox[
                RowBox[{"(", "\[NoBreak]", GridBox[{
                      {"0", "0"},
                      {\(1\/\@2\), "0"},
                      {"0", "1"}
                      },
                    RowSpacings->1,
                    ColumnSpacings->1,
                    ColumnAlignments->{Left}], "\[NoBreak]", ")"}],
                Function[ BoxForm`e$, 
                  MatrixForm[ BoxForm`e$]]]},
            {\({{1, 1\/2}, {0, 1}}\), 
              TagBox[
                RowBox[{"(", "\[NoBreak]", GridBox[{
                      {"0"},
                      {\(-1\)}
                      },
                    RowSpacings->1,
                    ColumnSpacings->1,
                    ColumnAlignments->{Left}], "\[NoBreak]", ")"}],
                Function[ BoxForm`e$, 
                  MatrixForm[ BoxForm`e$]]]},
            {\({{2, 0}, {1, 1\/2}}\), 
              TagBox[
                RowBox[{"(", "\[NoBreak]", GridBox[{
                      {"1", "0"}
                      },
                    RowSpacings->1,
                    ColumnSpacings->1,
                    ColumnAlignments->{Left}], "\[NoBreak]", ")"}],
                Function[ BoxForm`e$, 
                  MatrixForm[ BoxForm`e$]]]}
            },
          RowSpacings->1,
          ColumnSpacings->1,
          ColumnAlignments->{Left}], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Output",
  CellLabel->"Out[10]//MatrixForm="]
}, Open  ]]
}, Closed]]
}, Open  ]]
},
FrontEndVersion->"5.1 for X",
ScreenRectangle->{{0, 2880}, {0, 1200}},
WindowSize->{520, 599},
WindowMargins->{{Automatic, 386}, {Automatic, 256}},
ShowSelection->True,
StyleDefinitions -> "HelpBrowser.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "makeallmatricesbzvc"->{
    Cell[1820, 55, 747, 23, 86, "Usage",
      CellTags->{"makeallmatricesbzvc", "makeallmatricesbzop"}]},
  "makeallmatricesbzop"->{
    Cell[1820, 55, 747, 23, 86, "Usage",
      CellTags->{"makeallmatricesbzvc", "makeallmatricesbzop"}]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"makeallmatricesbzvc", 48218, 1140},
  {"makeallmatricesbzop", 48352, 1143}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 41, 0, 38, "ObjectName"],
Cell[1820, 55, 747, 23, 86, "Usage",
  CellTags->{"makeallmatricesbzvc", "makeallmatricesbzop"}],
Cell[2570, 80, 97, 3, 24, "Notes"],
Cell[2670, 85, 131, 3, 40, "Notes"],
Cell[2804, 90, 286, 11, 40, "Notes"],

Cell[CellGroupData[{
Cell[3115, 105, 42, 0, 38, "ExampleSection"],
Cell[3160, 107, 108, 4, 34, "ExampleText"],

Cell[CellGroupData[{
Cell[3293, 115, 139, 3, 42, "Input"],
Cell[3435, 120, 103, 2, 21, "Print"]
}, Open  ]],
Cell[3553, 125, 45, 0, 34, "ExampleText"],

Cell[CellGroupData[{
Cell[3623, 129, 204, 5, 42, "Input"],
Cell[3830, 136, 15064, 354, 58, "Output"]
}, Open  ]],
Cell[18909, 493, 205, 4, 66, "ExampleText"],

Cell[CellGroupData[{
Cell[19139, 501, 313, 6, 74, "Input"],
Cell[19455, 509, 24028, 498, 184, "Output"],
Cell[43486, 1009, 2101, 53, 176, "Output"]
}, Open  ]],
Cell[45602, 1065, 63, 0, 34, "ExampleText"],

Cell[CellGroupData[{
Cell[45690, 1069, 220, 5, 42, "Input"],
Cell[45913, 1076, 1614, 42, 150, "Output"]
}, Open  ]]
}, Closed]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

