(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.1'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    105259,       2489]*)
(*NotebookOutlinePosition[    105950,       2513]*)
(*  CellTagsIndexPosition[    105906,       2509]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["pow", "ObjectName"],

Cell[TextData[{
  "\[FilledSmallSquare] ",
  StyleBox["pow[", "MR"],
  StyleBox["expr", "TI"],
  StyleBox[", ", "MR"],
  StyleBox["i", "TI"],
  StyleBox["]", "MR"],
  " raises the expression ",
  StyleBox["expr", "IT"],
  " to the ",
  StyleBox["i", "IT"],
  "-th power using the non-commutative multiplication ",
  StyleBox["nc", "MR"],
  "."
}], "Usage"],

Cell[TextData[{
  "\[FilledSmallSquare] pow is defined only for nonnegative integers ",
  StyleBox["i", "IT"],
  "."
}], "Notes"],

Cell[TextData[{
  "\[FilledSmallSquare] Function ",
  ButtonBox["Power",
    ButtonStyle->"RefGuideLink"],
  " is best avoided, although a rule is defined for ",
  StyleBox["Power[", "MR"],
  StyleBox["expr", "IT"],
  StyleBox[",", "MR"],
  StyleBox["i", "IT"],
  StyleBox["]", "MR"],
  " expressions where ",
  StyleBox["expr", "IT"],
  " is an operator expression."
}], "Notes"],

Cell[TextData[{
  "\[FilledSmallSquare] See also: ",
  ButtonBox["snegSeries",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["superkomutator",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["superantikomutator",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes"],

Cell[CellGroupData[{

Cell["Further examples", "ExampleSection"],

Cell[TextData[{
  "Load sneg and declare ",
  StyleBox["c", "TI"],
  " to be a fermionic operator"
}], "ExampleText"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(<< sneg`sneg`;\)\), "\[IndentingNewLine]", 
    \(\(snegfermionoperators[c];\)\)}], "Input",
  CellLabel->"In[1]:="],

Cell[BoxData[
    \("sneg 1.168 Copyright (C) 2007 Rok Zitko"\)], "Print",
  CellLabel->"From In[1]:="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(op = number[c[]]\), "\[IndentingNewLine]", 
    \(Table[{i, pow[op, i]}, {i, 0, 5}] // TableForm\)}], "Input",
  CellLabel->"In[3]:="],

Cell[BoxData[
    RowBox[{
      RowBox[{
        TagBox[
          StyleBox[
            InterpretationBox[
              SubsuperscriptBox["c", 
                TagBox[
                  StyleBox["\<\"\[DownArrow]\"\>",
                    FontColor->RGBColor[0, 0, 1]],
                  (
                  StyleForm[ #, FontColor -> RGBColor[ 
                    0, 0, 1]]&)], "\<\"\[Dagger]\"\>"],
              Subsuperscript[ c, 
                RowBox[ {
                  StyleForm[ 
                  "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], 
                "\[Dagger]"],
              Editable->False],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm], 
        StyleBox["\[CenterDot]",
          FontColor->RGBColor[0, 0.392187, 0]], 
        TagBox[
          StyleBox[
            InterpretationBox[
              SubsuperscriptBox["c", 
                TagBox[
                  StyleBox["\<\"\[DownArrow]\"\>",
                    FontColor->RGBColor[0, 0, 1]],
                  (
                  StyleForm[ #, FontColor -> RGBColor[ 
                    0, 0, 1]]&)], "\<\"\"\>"],
              Subsuperscript[ c, 
                RowBox[ {
                  StyleForm[ 
                  "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], ""],
              Editable->False],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm]}], "+", 
      RowBox[{
        TagBox[
          StyleBox[
            InterpretationBox[
              SubsuperscriptBox["c", 
                TagBox[
                  StyleBox["\<\"\[UpArrow]\"\>",
                    FontColor->RGBColor[1, 0, 0]],
                  (
                  StyleForm[ #, FontColor -> RGBColor[ 
                    1, 0, 0]]&)], "\<\"\[Dagger]\"\>"],
              Subsuperscript[ c, 
                RowBox[ {
                  StyleForm[ "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}],
                 "\[Dagger]"],
              Editable->False],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm], 
        StyleBox["\[CenterDot]",
          FontColor->RGBColor[0, 0.392187, 0]], 
        TagBox[
          StyleBox[
            InterpretationBox[
              SubsuperscriptBox["c", 
                TagBox[
                  StyleBox["\<\"\[UpArrow]\"\>",
                    FontColor->RGBColor[1, 0, 0]],
                  (
                  StyleForm[ #, FontColor -> RGBColor[ 
                    1, 0, 0]]&)], "\<\"\"\>"],
              Subsuperscript[ c, 
                RowBox[ {
                  StyleForm[ "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}],
                 ""],
              Editable->False],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm]}]}]], "Output",
  CellLabel->"Out[3]="],

Cell[BoxData[
    TagBox[GridBox[{
          {"0", "1"},
          {"1", 
            RowBox[{
              RowBox[{
                TagBox[
                  StyleBox[
                    InterpretationBox[
                      SubsuperscriptBox["c", 
                        TagBox[
                          StyleBox["\<\"\[DownArrow]\"\>",
                            FontColor->RGBColor[0, 0, 1]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            0, 0, 1]]&)], "\<\"\[Dagger]\"\>"],
                      Subsuperscript[ c, 
                        RowBox[ {
                          StyleForm[ 
                          "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], 
                        "\[Dagger]"],
                      Editable->False],
                    ScriptSizeMultipliers->1,
                    ScriptBaselineShifts->{1, 1}],
                  DisplayForm], 
                StyleBox["\[CenterDot]",
                  FontColor->RGBColor[0, 0.392187, 0]], 
                TagBox[
                  StyleBox[
                    InterpretationBox[
                      SubsuperscriptBox["c", 
                        TagBox[
                          StyleBox["\<\"\[DownArrow]\"\>",
                            FontColor->RGBColor[0, 0, 1]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            0, 0, 1]]&)], "\<\"\"\>"],
                      Subsuperscript[ c, 
                        RowBox[ {
                          StyleForm[ 
                          "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], 
                        ""],
                      Editable->False],
                    ScriptSizeMultipliers->1,
                    ScriptBaselineShifts->{1, 1}],
                  DisplayForm]}], "+", 
              RowBox[{
                TagBox[
                  StyleBox[
                    InterpretationBox[
                      SubsuperscriptBox["c", 
                        TagBox[
                          StyleBox["\<\"\[UpArrow]\"\>",
                            FontColor->RGBColor[1, 0, 0]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            1, 0, 0]]&)], "\<\"\[Dagger]\"\>"],
                      Subsuperscript[ c, 
                        RowBox[ {
                          StyleForm[ 
                          "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                        "\[Dagger]"],
                      Editable->False],
                    ScriptSizeMultipliers->1,
                    ScriptBaselineShifts->{1, 1}],
                  DisplayForm], 
                StyleBox["\[CenterDot]",
                  FontColor->RGBColor[0, 0.392187, 0]], 
                TagBox[
                  StyleBox[
                    InterpretationBox[
                      SubsuperscriptBox["c", 
                        TagBox[
                          StyleBox["\<\"\[UpArrow]\"\>",
                            FontColor->RGBColor[1, 0, 0]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            1, 0, 0]]&)], "\<\"\"\>"],
                      Subsuperscript[ c, 
                        RowBox[ {
                          StyleForm[ 
                          "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                        ""],
                      Editable->False],
                    ScriptSizeMultipliers->1,
                    ScriptBaselineShifts->{1, 1}],
                  DisplayForm]}]}]},
          {"2", 
            RowBox[{
              RowBox[{
                TagBox[
                  StyleBox[
                    InterpretationBox[
                      SubsuperscriptBox["c", 
                        TagBox[
                          StyleBox["\<\"\[DownArrow]\"\>",
                            FontColor->RGBColor[0, 0, 1]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            0, 0, 1]]&)], "\<\"\[Dagger]\"\>"],
                      Subsuperscript[ c, 
                        RowBox[ {
                          StyleForm[ 
                          "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], 
                        "\[Dagger]"],
                      Editable->False],
                    ScriptSizeMultipliers->1,
                    ScriptBaselineShifts->{1, 1}],
                  DisplayForm], 
                StyleBox["\[CenterDot]",
                  FontColor->RGBColor[0, 0.392187, 0]], 
                TagBox[
                  StyleBox[
                    InterpretationBox[
                      SubsuperscriptBox["c", 
                        TagBox[
                          StyleBox["\<\"\[DownArrow]\"\>",
                            FontColor->RGBColor[0, 0, 1]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            0, 0, 1]]&)], "\<\"\"\>"],
                      Subsuperscript[ c, 
                        RowBox[ {
                          StyleForm[ 
                          "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], 
                        ""],
                      Editable->False],
                    ScriptSizeMultipliers->1,
                    ScriptBaselineShifts->{1, 1}],
                  DisplayForm]}], "+", 
              RowBox[{
                TagBox[
                  StyleBox[
                    InterpretationBox[
                      SubsuperscriptBox["c", 
                        TagBox[
                          StyleBox["\<\"\[UpArrow]\"\>",
                            FontColor->RGBColor[1, 0, 0]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            1, 0, 0]]&)], "\<\"\[Dagger]\"\>"],
                      Subsuperscript[ c, 
                        RowBox[ {
                          StyleForm[ 
                          "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                        "\[Dagger]"],
                      Editable->False],
                    ScriptSizeMultipliers->1,
                    ScriptBaselineShifts->{1, 1}],
                  DisplayForm], 
                StyleBox["\[CenterDot]",
                  FontColor->RGBColor[0, 0.392187, 0]], 
                TagBox[
                  StyleBox[
                    InterpretationBox[
                      SubsuperscriptBox["c", 
                        TagBox[
                          StyleBox["\<\"\[UpArrow]\"\>",
                            FontColor->RGBColor[1, 0, 0]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            1, 0, 0]]&)], "\<\"\"\>"],
                      Subsuperscript[ c, 
                        RowBox[ {
                          StyleForm[ 
                          "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                        ""],
                      Editable->False],
                    ScriptSizeMultipliers->1,
                    ScriptBaselineShifts->{1, 1}],
                  DisplayForm]}], "-", 
              RowBox[{"2", 
                RowBox[{
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["c", 
                          TagBox[
                            StyleBox["\<\"\[DownArrow]\"\>",
                              FontColor->RGBColor[0, 0, 1]],
                            (
                            StyleForm[ #, FontColor -> RGBColor[ 
                              0, 0, 1]]&)], "\<\"\[Dagger]\"\>"],
                        Subsuperscript[ c, 
                          RowBox[ {
                            StyleForm[ 
                            "\[DownArrow]", FontColor -> RGBColor[ 
                              0, 0, 1]]}], "\[Dagger]"],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm], 
                  StyleBox["\[CenterDot]",
                    FontColor->RGBColor[0, 0.392187, 0]], 
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["c", 
                          TagBox[
                            StyleBox["\<\"\[UpArrow]\"\>",
                              FontColor->RGBColor[1, 0, 0]],
                            (
                            StyleForm[ #, FontColor -> RGBColor[ 
                              1, 0, 0]]&)], "\<\"\[Dagger]\"\>"],
                        Subsuperscript[ c, 
                          RowBox[ {
                            StyleForm[ 
                            "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                          "\[Dagger]"],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm], 
                  StyleBox["\[CenterDot]",
                    FontColor->RGBColor[0, 0.392187, 0]], 
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["c", 
                          TagBox[
                            StyleBox["\<\"\[DownArrow]\"\>",
                              FontColor->RGBColor[0, 0, 1]],
                            (
                            StyleForm[ #, FontColor -> RGBColor[ 
                              0, 0, 1]]&)], "\<\"\"\>"],
                        Subsuperscript[ c, 
                          RowBox[ {
                            StyleForm[ 
                            "\[DownArrow]", FontColor -> RGBColor[ 
                              0, 0, 1]]}], ""],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm], 
                  StyleBox["\[CenterDot]",
                    FontColor->RGBColor[0, 0.392187, 0]], 
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["c", 
                          TagBox[
                            StyleBox["\<\"\[UpArrow]\"\>",
                              FontColor->RGBColor[1, 0, 0]],
                            (
                            StyleForm[ #, FontColor -> RGBColor[ 
                              1, 0, 0]]&)], "\<\"\"\>"],
                        Subsuperscript[ c, 
                          RowBox[ {
                            StyleForm[ 
                            "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                          ""],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm]}]}]}]},
          {"3", 
            RowBox[{
              RowBox[{
                TagBox[
                  StyleBox[
                    InterpretationBox[
                      SubsuperscriptBox["c", 
                        TagBox[
                          StyleBox["\<\"\[DownArrow]\"\>",
                            FontColor->RGBColor[0, 0, 1]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            0, 0, 1]]&)], "\<\"\[Dagger]\"\>"],
                      Subsuperscript[ c, 
                        RowBox[ {
                          StyleForm[ 
                          "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], 
                        "\[Dagger]"],
                      Editable->False],
                    ScriptSizeMultipliers->1,
                    ScriptBaselineShifts->{1, 1}],
                  DisplayForm], 
                StyleBox["\[CenterDot]",
                  FontColor->RGBColor[0, 0.392187, 0]], 
                TagBox[
                  StyleBox[
                    InterpretationBox[
                      SubsuperscriptBox["c", 
                        TagBox[
                          StyleBox["\<\"\[DownArrow]\"\>",
                            FontColor->RGBColor[0, 0, 1]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            0, 0, 1]]&)], "\<\"\"\>"],
                      Subsuperscript[ c, 
                        RowBox[ {
                          StyleForm[ 
                          "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], 
                        ""],
                      Editable->False],
                    ScriptSizeMultipliers->1,
                    ScriptBaselineShifts->{1, 1}],
                  DisplayForm]}], "+", 
              RowBox[{
                TagBox[
                  StyleBox[
                    InterpretationBox[
                      SubsuperscriptBox["c", 
                        TagBox[
                          StyleBox["\<\"\[UpArrow]\"\>",
                            FontColor->RGBColor[1, 0, 0]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            1, 0, 0]]&)], "\<\"\[Dagger]\"\>"],
                      Subsuperscript[ c, 
                        RowBox[ {
                          StyleForm[ 
                          "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                        "\[Dagger]"],
                      Editable->False],
                    ScriptSizeMultipliers->1,
                    ScriptBaselineShifts->{1, 1}],
                  DisplayForm], 
                StyleBox["\[CenterDot]",
                  FontColor->RGBColor[0, 0.392187, 0]], 
                TagBox[
                  StyleBox[
                    InterpretationBox[
                      SubsuperscriptBox["c", 
                        TagBox[
                          StyleBox["\<\"\[UpArrow]\"\>",
                            FontColor->RGBColor[1, 0, 0]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            1, 0, 0]]&)], "\<\"\"\>"],
                      Subsuperscript[ c, 
                        RowBox[ {
                          StyleForm[ 
                          "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                        ""],
                      Editable->False],
                    ScriptSizeMultipliers->1,
                    ScriptBaselineShifts->{1, 1}],
                  DisplayForm]}], "-", 
              RowBox[{"6", 
                RowBox[{
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["c", 
                          TagBox[
                            StyleBox["\<\"\[DownArrow]\"\>",
                              FontColor->RGBColor[0, 0, 1]],
                            (
                            StyleForm[ #, FontColor -> RGBColor[ 
                              0, 0, 1]]&)], "\<\"\[Dagger]\"\>"],
                        Subsuperscript[ c, 
                          RowBox[ {
                            StyleForm[ 
                            "\[DownArrow]", FontColor -> RGBColor[ 
                              0, 0, 1]]}], "\[Dagger]"],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm], 
                  StyleBox["\[CenterDot]",
                    FontColor->RGBColor[0, 0.392187, 0]], 
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["c", 
                          TagBox[
                            StyleBox["\<\"\[UpArrow]\"\>",
                              FontColor->RGBColor[1, 0, 0]],
                            (
                            StyleForm[ #, FontColor -> RGBColor[ 
                              1, 0, 0]]&)], "\<\"\[Dagger]\"\>"],
                        Subsuperscript[ c, 
                          RowBox[ {
                            StyleForm[ 
                            "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                          "\[Dagger]"],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm], 
                  StyleBox["\[CenterDot]",
                    FontColor->RGBColor[0, 0.392187, 0]], 
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["c", 
                          TagBox[
                            StyleBox["\<\"\[DownArrow]\"\>",
                              FontColor->RGBColor[0, 0, 1]],
                            (
                            StyleForm[ #, FontColor -> RGBColor[ 
                              0, 0, 1]]&)], "\<\"\"\>"],
                        Subsuperscript[ c, 
                          RowBox[ {
                            StyleForm[ 
                            "\[DownArrow]", FontColor -> RGBColor[ 
                              0, 0, 1]]}], ""],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm], 
                  StyleBox["\[CenterDot]",
                    FontColor->RGBColor[0, 0.392187, 0]], 
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["c", 
                          TagBox[
                            StyleBox["\<\"\[UpArrow]\"\>",
                              FontColor->RGBColor[1, 0, 0]],
                            (
                            StyleForm[ #, FontColor -> RGBColor[ 
                              1, 0, 0]]&)], "\<\"\"\>"],
                        Subsuperscript[ c, 
                          RowBox[ {
                            StyleForm[ 
                            "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                          ""],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm]}]}]}]},
          {"4", 
            RowBox[{
              RowBox[{
                TagBox[
                  StyleBox[
                    InterpretationBox[
                      SubsuperscriptBox["c", 
                        TagBox[
                          StyleBox["\<\"\[DownArrow]\"\>",
                            FontColor->RGBColor[0, 0, 1]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            0, 0, 1]]&)], "\<\"\[Dagger]\"\>"],
                      Subsuperscript[ c, 
                        RowBox[ {
                          StyleForm[ 
                          "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], 
                        "\[Dagger]"],
                      Editable->False],
                    ScriptSizeMultipliers->1,
                    ScriptBaselineShifts->{1, 1}],
                  DisplayForm], 
                StyleBox["\[CenterDot]",
                  FontColor->RGBColor[0, 0.392187, 0]], 
                TagBox[
                  StyleBox[
                    InterpretationBox[
                      SubsuperscriptBox["c", 
                        TagBox[
                          StyleBox["\<\"\[DownArrow]\"\>",
                            FontColor->RGBColor[0, 0, 1]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            0, 0, 1]]&)], "\<\"\"\>"],
                      Subsuperscript[ c, 
                        RowBox[ {
                          StyleForm[ 
                          "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], 
                        ""],
                      Editable->False],
                    ScriptSizeMultipliers->1,
                    ScriptBaselineShifts->{1, 1}],
                  DisplayForm]}], "+", 
              RowBox[{
                TagBox[
                  StyleBox[
                    InterpretationBox[
                      SubsuperscriptBox["c", 
                        TagBox[
                          StyleBox["\<\"\[UpArrow]\"\>",
                            FontColor->RGBColor[1, 0, 0]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            1, 0, 0]]&)], "\<\"\[Dagger]\"\>"],
                      Subsuperscript[ c, 
                        RowBox[ {
                          StyleForm[ 
                          "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                        "\[Dagger]"],
                      Editable->False],
                    ScriptSizeMultipliers->1,
                    ScriptBaselineShifts->{1, 1}],
                  DisplayForm], 
                StyleBox["\[CenterDot]",
                  FontColor->RGBColor[0, 0.392187, 0]], 
                TagBox[
                  StyleBox[
                    InterpretationBox[
                      SubsuperscriptBox["c", 
                        TagBox[
                          StyleBox["\<\"\[UpArrow]\"\>",
                            FontColor->RGBColor[1, 0, 0]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            1, 0, 0]]&)], "\<\"\"\>"],
                      Subsuperscript[ c, 
                        RowBox[ {
                          StyleForm[ 
                          "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                        ""],
                      Editable->False],
                    ScriptSizeMultipliers->1,
                    ScriptBaselineShifts->{1, 1}],
                  DisplayForm]}], "-", 
              RowBox[{"14", 
                RowBox[{
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["c", 
                          TagBox[
                            StyleBox["\<\"\[DownArrow]\"\>",
                              FontColor->RGBColor[0, 0, 1]],
                            (
                            StyleForm[ #, FontColor -> RGBColor[ 
                              0, 0, 1]]&)], "\<\"\[Dagger]\"\>"],
                        Subsuperscript[ c, 
                          RowBox[ {
                            StyleForm[ 
                            "\[DownArrow]", FontColor -> RGBColor[ 
                              0, 0, 1]]}], "\[Dagger]"],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm], 
                  StyleBox["\[CenterDot]",
                    FontColor->RGBColor[0, 0.392187, 0]], 
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["c", 
                          TagBox[
                            StyleBox["\<\"\[UpArrow]\"\>",
                              FontColor->RGBColor[1, 0, 0]],
                            (
                            StyleForm[ #, FontColor -> RGBColor[ 
                              1, 0, 0]]&)], "\<\"\[Dagger]\"\>"],
                        Subsuperscript[ c, 
                          RowBox[ {
                            StyleForm[ 
                            "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                          "\[Dagger]"],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm], 
                  StyleBox["\[CenterDot]",
                    FontColor->RGBColor[0, 0.392187, 0]], 
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["c", 
                          TagBox[
                            StyleBox["\<\"\[DownArrow]\"\>",
                              FontColor->RGBColor[0, 0, 1]],
                            (
                            StyleForm[ #, FontColor -> RGBColor[ 
                              0, 0, 1]]&)], "\<\"\"\>"],
                        Subsuperscript[ c, 
                          RowBox[ {
                            StyleForm[ 
                            "\[DownArrow]", FontColor -> RGBColor[ 
                              0, 0, 1]]}], ""],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm], 
                  StyleBox["\[CenterDot]",
                    FontColor->RGBColor[0, 0.392187, 0]], 
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["c", 
                          TagBox[
                            StyleBox["\<\"\[UpArrow]\"\>",
                              FontColor->RGBColor[1, 0, 0]],
                            (StyleForm[ #, FontColor -> RGBColor[ 
                              1, 0, 0]]&)], "\<\"\"\>"],
                        Subsuperscript[ c, 
                          RowBox[ {
                            StyleForm[ 
                            "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                          ""],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm]}]}]}]},
          {"5", 
            RowBox[{
              RowBox[{
                TagBox[
                  StyleBox[
                    InterpretationBox[
                      SubsuperscriptBox["c", 
                        TagBox[
                          StyleBox["\<\"\[DownArrow]\"\>",
                            FontColor->RGBColor[0, 0, 1]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            0, 0, 1]]&)], "\<\"\[Dagger]\"\>"],
                      Subsuperscript[ c, 
                        RowBox[ {
                          StyleForm[ 
                          "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], 
                        "\[Dagger]"],
                      Editable->False],
                    ScriptSizeMultipliers->1,
                    ScriptBaselineShifts->{1, 1}],
                  DisplayForm], 
                StyleBox["\[CenterDot]",
                  FontColor->RGBColor[0, 0.392187, 0]], 
                TagBox[
                  StyleBox[
                    InterpretationBox[
                      SubsuperscriptBox["c", 
                        TagBox[
                          StyleBox["\<\"\[DownArrow]\"\>",
                            FontColor->RGBColor[0, 0, 1]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            0, 0, 1]]&)], "\<\"\"\>"],
                      Subsuperscript[ c, 
                        RowBox[ {
                          StyleForm[ 
                          "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], 
                        ""],
                      Editable->False],
                    ScriptSizeMultipliers->1,
                    ScriptBaselineShifts->{1, 1}],
                  DisplayForm]}], "+", 
              RowBox[{
                TagBox[
                  StyleBox[
                    InterpretationBox[
                      SubsuperscriptBox["c", 
                        TagBox[
                          StyleBox["\<\"\[UpArrow]\"\>",
                            FontColor->RGBColor[1, 0, 0]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            1, 0, 0]]&)], "\<\"\[Dagger]\"\>"],
                      Subsuperscript[ c, 
                        RowBox[ {
                          StyleForm[ 
                          "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                        "\[Dagger]"],
                      Editable->False],
                    ScriptSizeMultipliers->1,
                    ScriptBaselineShifts->{1, 1}],
                  DisplayForm], 
                StyleBox["\[CenterDot]",
                  FontColor->RGBColor[0, 0.392187, 0]], 
                TagBox[
                  StyleBox[
                    InterpretationBox[
                      SubsuperscriptBox["c", 
                        TagBox[
                          StyleBox["\<\"\[UpArrow]\"\>",
                            FontColor->RGBColor[1, 0, 0]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            1, 0, 0]]&)], "\<\"\"\>"],
                      Subsuperscript[ c, 
                        RowBox[ {
                          StyleForm[ 
                          "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                        ""],
                      Editable->False],
                    ScriptSizeMultipliers->1,
                    ScriptBaselineShifts->{1, 1}],
                  DisplayForm]}], "-", 
              RowBox[{"30", 
                RowBox[{
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["c", 
                          TagBox[
                            StyleBox["\<\"\[DownArrow]\"\>",
                              FontColor->RGBColor[0, 0, 1]],
                            (
                            StyleForm[ #, FontColor -> RGBColor[ 
                              0, 0, 1]]&)], "\<\"\[Dagger]\"\>"],
                        Subsuperscript[ c, 
                          RowBox[ {
                            StyleForm[ 
                            "\[DownArrow]", FontColor -> RGBColor[ 
                              0, 0, 1]]}], "\[Dagger]"],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm], 
                  StyleBox["\[CenterDot]",
                    FontColor->RGBColor[0, 0.392187, 0]], 
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["c", 
                          TagBox[
                            StyleBox["\<\"\[UpArrow]\"\>",
                              FontColor->RGBColor[1, 0, 0]],
                            (
                            StyleForm[ #, FontColor -> RGBColor[ 
                              1, 0, 0]]&)], "\<\"\[Dagger]\"\>"],
                        Subsuperscript[ c, 
                          RowBox[ {
                            StyleForm[ 
                            "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                          "\[Dagger]"],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm], 
                  StyleBox["\[CenterDot]",
                    FontColor->RGBColor[0, 0.392187, 0]], 
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["c", 
                          TagBox[
                            StyleBox["\<\"\[DownArrow]\"\>",
                              FontColor->RGBColor[0, 0, 1]],
                            (
                            StyleForm[ #, FontColor -> RGBColor[ 
                              0, 0, 1]]&)], "\<\"\"\>"],
                        Subsuperscript[ c, 
                          RowBox[ {
                            StyleForm[ 
                            "\[DownArrow]", FontColor -> RGBColor[ 
                              0, 0, 1]]}], ""],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm], 
                  StyleBox["\[CenterDot]",
                    FontColor->RGBColor[0, 0.392187, 0]], 
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["c", 
                          TagBox[
                            StyleBox["\<\"\[UpArrow]\"\>",
                              FontColor->RGBColor[1, 0, 0]],
                            (
                            StyleForm[ #, FontColor -> RGBColor[ 
                              1, 0, 0]]&)], "\<\"\"\>"],
                        Subsuperscript[ c, 
                          RowBox[ {
                            StyleForm[ 
                            "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                          ""],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm]}]}]}]}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      Function[ BoxForm`e$, 
        TableForm[ BoxForm`e$]]]], "Output",
  CellLabel->"Out[4]//TableForm="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(op = number[c[], UP]\), "\[IndentingNewLine]", 
    \(Table[{i, pow[op, i]}, {i, 0, 5}] // TableForm\)}], "Input",
  CellLabel->"In[5]:="],

Cell[BoxData[
    RowBox[{
      TagBox[
        StyleBox[
          InterpretationBox[
            SubsuperscriptBox["c", 
              TagBox[
                StyleBox["\<\"\[UpArrow]\"\>",
                  FontColor->RGBColor[1, 0, 0]],
                (
                StyleForm[ #, FontColor -> RGBColor[ 
                  1, 0, 0]]&)], "\<\"\[Dagger]\"\>"],
            Subsuperscript[ c, 
              RowBox[ {
                StyleForm[ "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
              "\[Dagger]"],
            Editable->False],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
        DisplayForm], 
      StyleBox["\[CenterDot]",
        FontColor->RGBColor[0, 0.392187, 0]], 
      TagBox[
        StyleBox[
          InterpretationBox[
            SubsuperscriptBox["c", 
              TagBox[
                StyleBox["\<\"\[UpArrow]\"\>",
                  FontColor->RGBColor[1, 0, 0]],
                (
                StyleForm[ #, FontColor -> RGBColor[ 
                  1, 0, 0]]&)], "\<\"\"\>"],
            Subsuperscript[ c, 
              RowBox[ {
                StyleForm[ "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
              ""],
            Editable->False],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
        DisplayForm]}]], "Output",
  CellLabel->"Out[5]="],

Cell[BoxData[
    TagBox[GridBox[{
          {"0", "1"},
          {"1", 
            RowBox[{
              TagBox[
                StyleBox[
                  InterpretationBox[
                    SubsuperscriptBox["c", 
                      TagBox[
                        StyleBox["\<\"\[UpArrow]\"\>",
                          FontColor->RGBColor[1, 0, 0]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          1, 0, 0]]&)], "\<\"\[Dagger]\"\>"],
                    Subsuperscript[ c, 
                      RowBox[ {
                        StyleForm[ 
                        "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                      "\[Dagger]"],
                    Editable->False],
                  ScriptSizeMultipliers->1,
                  ScriptBaselineShifts->{1, 1}],
                DisplayForm], 
              StyleBox["\[CenterDot]",
                FontColor->RGBColor[0, 0.392187, 0]], 
              TagBox[
                StyleBox[
                  InterpretationBox[
                    SubsuperscriptBox["c", 
                      TagBox[
                        StyleBox["\<\"\[UpArrow]\"\>",
                          FontColor->RGBColor[1, 0, 0]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          1, 0, 0]]&)], "\<\"\"\>"],
                    Subsuperscript[ c, 
                      RowBox[ {
                        StyleForm[ 
                        "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], ""],
                    
                    Editable->False],
                  ScriptSizeMultipliers->1,
                  ScriptBaselineShifts->{1, 1}],
                DisplayForm]}]},
          {"2", 
            RowBox[{
              TagBox[
                StyleBox[
                  InterpretationBox[
                    SubsuperscriptBox["c", 
                      TagBox[
                        StyleBox["\<\"\[UpArrow]\"\>",
                          FontColor->RGBColor[1, 0, 0]],
                        (StyleForm[ #, FontColor -> RGBColor[ 
                          1, 0, 0]]&)], "\<\"\[Dagger]\"\>"],
                    Subsuperscript[ c, 
                      RowBox[ {
                        StyleForm[ 
                        "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                      "\[Dagger]"],
                    Editable->False],
                  ScriptSizeMultipliers->1,
                  ScriptBaselineShifts->{1, 1}],
                DisplayForm], 
              StyleBox["\[CenterDot]",
                FontColor->RGBColor[0, 0.392187, 0]], 
              TagBox[
                StyleBox[
                  InterpretationBox[
                    SubsuperscriptBox["c", 
                      TagBox[
                        StyleBox["\<\"\[UpArrow]\"\>",
                          FontColor->RGBColor[1, 0, 0]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          1, 0, 0]]&)], "\<\"\"\>"],
                    Subsuperscript[ c, 
                      RowBox[ {
                        StyleForm[ 
                        "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], ""],
                    
                    Editable->False],
                  ScriptSizeMultipliers->1,
                  ScriptBaselineShifts->{1, 1}],
                DisplayForm]}]},
          {"3", 
            RowBox[{
              TagBox[
                StyleBox[
                  InterpretationBox[
                    SubsuperscriptBox["c", 
                      TagBox[
                        StyleBox["\<\"\[UpArrow]\"\>",
                          FontColor->RGBColor[1, 0, 0]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          1, 0, 0]]&)], "\<\"\[Dagger]\"\>"],
                    Subsuperscript[ c, 
                      RowBox[ {
                        StyleForm[ 
                        "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                      "\[Dagger]"],
                    Editable->False],
                  ScriptSizeMultipliers->1,
                  ScriptBaselineShifts->{1, 1}],
                DisplayForm], 
              StyleBox["\[CenterDot]",
                FontColor->RGBColor[0, 0.392187, 0]], 
              TagBox[
                StyleBox[
                  InterpretationBox[
                    SubsuperscriptBox["c", 
                      TagBox[
                        StyleBox["\<\"\[UpArrow]\"\>",
                          FontColor->RGBColor[1, 0, 0]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          1, 0, 0]]&)], "\<\"\"\>"],
                    Subsuperscript[ c, 
                      RowBox[ {
                        StyleForm[ 
                        "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], ""],
                    
                    Editable->False],
                  ScriptSizeMultipliers->1,
                  ScriptBaselineShifts->{1, 1}],
                DisplayForm]}]},
          {"4", 
            RowBox[{
              TagBox[
                StyleBox[
                  InterpretationBox[
                    SubsuperscriptBox["c", 
                      TagBox[
                        StyleBox["\<\"\[UpArrow]\"\>",
                          FontColor->RGBColor[1, 0, 0]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          1, 0, 0]]&)], "\<\"\[Dagger]\"\>"],
                    Subsuperscript[ c, 
                      RowBox[ {
                        StyleForm[ 
                        "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                      "\[Dagger]"],
                    Editable->False],
                  ScriptSizeMultipliers->1,
                  ScriptBaselineShifts->{1, 1}],
                DisplayForm], 
              StyleBox["\[CenterDot]",
                FontColor->RGBColor[0, 0.392187, 0]], 
              TagBox[
                StyleBox[
                  InterpretationBox[
                    SubsuperscriptBox["c", 
                      TagBox[
                        StyleBox["\<\"\[UpArrow]\"\>",
                          FontColor->RGBColor[1, 0, 0]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          1, 0, 0]]&)], "\<\"\"\>"],
                    Subsuperscript[ c, 
                      RowBox[ {
                        StyleForm[ 
                        "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], ""],
                    
                    Editable->False],
                  ScriptSizeMultipliers->1,
                  ScriptBaselineShifts->{1, 1}],
                DisplayForm]}]},
          {"5", 
            RowBox[{
              TagBox[
                StyleBox[
                  InterpretationBox[
                    SubsuperscriptBox["c", 
                      TagBox[
                        StyleBox["\<\"\[UpArrow]\"\>",
                          FontColor->RGBColor[1, 0, 0]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          1, 0, 0]]&)], "\<\"\[Dagger]\"\>"],
                    Subsuperscript[ c, 
                      RowBox[ {
                        StyleForm[ 
                        "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                      "\[Dagger]"],
                    Editable->False],
                  ScriptSizeMultipliers->1,
                  ScriptBaselineShifts->{1, 1}],
                DisplayForm], 
              StyleBox["\[CenterDot]",
                FontColor->RGBColor[0, 0.392187, 0]], 
              TagBox[
                StyleBox[
                  InterpretationBox[
                    SubsuperscriptBox["c", 
                      TagBox[
                        StyleBox["\<\"\[UpArrow]\"\>",
                          FontColor->RGBColor[1, 0, 0]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          1, 0, 0]]&)], "\<\"\"\>"],
                    Subsuperscript[ c, 
                      RowBox[ {
                        StyleForm[ 
                        "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], ""],
                    
                    Editable->False],
                  ScriptSizeMultipliers->1,
                  ScriptBaselineShifts->{1, 1}],
                DisplayForm]}]}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      Function[ BoxForm`e$, 
        TableForm[ BoxForm`e$]]]], "Output",
  CellLabel->"Out[6]//TableForm="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(op = hubbard[c[]]\), "\[IndentingNewLine]", 
    \(Table[{i, pow[op, i]}, {i, 0, 5}] // TableForm\)}], "Input",
  CellLabel->"In[7]:="],

Cell[BoxData[
    RowBox[{"\<\"-\"\>", 
      RowBox[{
        TagBox[
          StyleBox[
            InterpretationBox[
              SubsuperscriptBox["c", 
                TagBox[
                  StyleBox["\<\"\[DownArrow]\"\>",
                    FontColor->RGBColor[0, 0, 1]],
                  (
                  StyleForm[ #, FontColor -> RGBColor[ 
                    0, 0, 1]]&)], "\<\"\[Dagger]\"\>"],
              Subsuperscript[ c, 
                RowBox[ {
                  StyleForm[ 
                  "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], 
                "\[Dagger]"],
              Editable->False],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm], 
        StyleBox["\[CenterDot]",
          FontColor->RGBColor[0, 0.392187, 0]], 
        TagBox[
          StyleBox[
            InterpretationBox[
              SubsuperscriptBox["c", 
                TagBox[
                  StyleBox["\<\"\[UpArrow]\"\>",
                    FontColor->RGBColor[1, 0, 0]],
                  (
                  StyleForm[ #, FontColor -> RGBColor[ 
                    1, 0, 0]]&)], "\<\"\[Dagger]\"\>"],
              Subsuperscript[ c, 
                RowBox[ {
                  StyleForm[ "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}],
                 "\[Dagger]"],
              Editable->False],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm], 
        StyleBox["\[CenterDot]",
          FontColor->RGBColor[0, 0.392187, 0]], 
        TagBox[
          StyleBox[
            InterpretationBox[
              SubsuperscriptBox["c", 
                TagBox[
                  StyleBox["\<\"\[DownArrow]\"\>",
                    FontColor->RGBColor[0, 0, 1]],
                  (
                  StyleForm[ #, FontColor -> RGBColor[ 
                    0, 0, 1]]&)], "\<\"\"\>"],
              Subsuperscript[ c, 
                RowBox[ {
                  StyleForm[ 
                  "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], ""],
              Editable->False],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm], 
        StyleBox["\[CenterDot]",
          FontColor->RGBColor[0, 0.392187, 0]], 
        TagBox[
          StyleBox[
            InterpretationBox[
              SubsuperscriptBox["c", 
                TagBox[
                  StyleBox["\<\"\[UpArrow]\"\>",
                    FontColor->RGBColor[1, 0, 0]],
                  (
                  StyleForm[ #, FontColor -> RGBColor[ 
                    1, 0, 0]]&)], "\<\"\"\>"],
              Subsuperscript[ c, 
                RowBox[ {
                  StyleForm[ "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}],
                 ""],
              Editable->False],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
          DisplayForm]}]}]], "Output",
  CellLabel->"Out[7]="],

Cell[BoxData[
    TagBox[GridBox[{
          {"0", "1"},
          {"1", 
            RowBox[{"\<\"-\"\>", 
              RowBox[{
                TagBox[
                  StyleBox[
                    InterpretationBox[
                      SubsuperscriptBox["c", 
                        TagBox[
                          StyleBox["\<\"\[DownArrow]\"\>",
                            FontColor->RGBColor[0, 0, 1]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            0, 0, 1]]&)], "\<\"\[Dagger]\"\>"],
                      Subsuperscript[ c, 
                        RowBox[ {
                          StyleForm[ 
                          "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], 
                        "\[Dagger]"],
                      Editable->False],
                    ScriptSizeMultipliers->1,
                    ScriptBaselineShifts->{1, 1}],
                  DisplayForm], 
                StyleBox["\[CenterDot]",
                  FontColor->RGBColor[0, 0.392187, 0]], 
                TagBox[
                  StyleBox[
                    InterpretationBox[
                      SubsuperscriptBox["c", 
                        TagBox[
                          StyleBox["\<\"\[UpArrow]\"\>",
                            FontColor->RGBColor[1, 0, 0]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            1, 0, 0]]&)], "\<\"\[Dagger]\"\>"],
                      Subsuperscript[ c, 
                        RowBox[ {
                          StyleForm[ 
                          "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                        "\[Dagger]"],
                      Editable->False],
                    ScriptSizeMultipliers->1,
                    ScriptBaselineShifts->{1, 1}],
                  DisplayForm], 
                StyleBox["\[CenterDot]",
                  FontColor->RGBColor[0, 0.392187, 0]], 
                TagBox[
                  StyleBox[
                    InterpretationBox[
                      SubsuperscriptBox["c", 
                        TagBox[
                          StyleBox["\<\"\[DownArrow]\"\>",
                            FontColor->RGBColor[0, 0, 1]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            0, 0, 1]]&)], "\<\"\"\>"],
                      Subsuperscript[ c, 
                        RowBox[ {
                          StyleForm[ 
                          "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], 
                        ""],
                      Editable->False],
                    ScriptSizeMultipliers->1,
                    ScriptBaselineShifts->{1, 1}],
                  DisplayForm], 
                StyleBox["\[CenterDot]",
                  FontColor->RGBColor[0, 0.392187, 0]], 
                TagBox[
                  StyleBox[
                    InterpretationBox[
                      SubsuperscriptBox["c", 
                        TagBox[
                          StyleBox["\<\"\[UpArrow]\"\>",
                            FontColor->RGBColor[1, 0, 0]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            1, 0, 0]]&)], "\<\"\"\>"],
                      Subsuperscript[ c, 
                        RowBox[ {
                          StyleForm[ 
                          "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                        ""],
                      Editable->False],
                    ScriptSizeMultipliers->1,
                    ScriptBaselineShifts->{1, 1}],
                  DisplayForm]}]}]},
          {"2", 
            RowBox[{"\<\"-\"\>", 
              RowBox[{
                TagBox[
                  StyleBox[
                    InterpretationBox[
                      SubsuperscriptBox["c", 
                        TagBox[
                          StyleBox["\<\"\[DownArrow]\"\>",
                            FontColor->RGBColor[0, 0, 1]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            0, 0, 1]]&)], "\<\"\[Dagger]\"\>"],
                      Subsuperscript[ c, 
                        RowBox[ {
                          StyleForm[ 
                          "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], 
                        "\[Dagger]"],
                      Editable->False],
                    ScriptSizeMultipliers->1,
                    ScriptBaselineShifts->{1, 1}],
                  DisplayForm], 
                StyleBox["\[CenterDot]",
                  FontColor->RGBColor[0, 0.392187, 0]], 
                TagBox[
                  StyleBox[
                    InterpretationBox[
                      SubsuperscriptBox["c", 
                        TagBox[
                          StyleBox["\<\"\[UpArrow]\"\>",
                            FontColor->RGBColor[1, 0, 0]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            1, 0, 0]]&)], "\<\"\[Dagger]\"\>"],
                      Subsuperscript[ c, 
                        RowBox[ {
                          StyleForm[ 
                          "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                        "\[Dagger]"],
                      Editable->False],
                    ScriptSizeMultipliers->1,
                    ScriptBaselineShifts->{1, 1}],
                  DisplayForm], 
                StyleBox["\[CenterDot]",
                  FontColor->RGBColor[0, 0.392187, 0]], 
                TagBox[
                  StyleBox[
                    InterpretationBox[
                      SubsuperscriptBox["c", 
                        TagBox[
                          StyleBox["\<\"\[DownArrow]\"\>",
                            FontColor->RGBColor[0, 0, 1]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            0, 0, 1]]&)], "\<\"\"\>"],
                      Subsuperscript[ c, 
                        RowBox[ {
                          StyleForm[ 
                          "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], 
                        ""],
                      Editable->False],
                    ScriptSizeMultipliers->1,
                    ScriptBaselineShifts->{1, 1}],
                  DisplayForm], 
                StyleBox["\[CenterDot]",
                  FontColor->RGBColor[0, 0.392187, 0]], 
                TagBox[
                  StyleBox[
                    InterpretationBox[
                      SubsuperscriptBox["c", 
                        TagBox[
                          StyleBox["\<\"\[UpArrow]\"\>",
                            FontColor->RGBColor[1, 0, 0]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            1, 0, 0]]&)], "\<\"\"\>"],
                      Subsuperscript[ c, 
                        RowBox[ {
                          StyleForm[ 
                          "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                        ""],
                      Editable->False],
                    ScriptSizeMultipliers->1,
                    ScriptBaselineShifts->{1, 1}],
                  DisplayForm]}]}]},
          {"3", 
            RowBox[{"\<\"-\"\>", 
              RowBox[{
                TagBox[
                  StyleBox[
                    InterpretationBox[
                      SubsuperscriptBox["c", 
                        TagBox[
                          StyleBox["\<\"\[DownArrow]\"\>",
                            FontColor->RGBColor[0, 0, 1]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            0, 0, 1]]&)], "\<\"\[Dagger]\"\>"],
                      Subsuperscript[ c, 
                        RowBox[ {
                          StyleForm[ 
                          "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], 
                        "\[Dagger]"],
                      Editable->False],
                    ScriptSizeMultipliers->1,
                    ScriptBaselineShifts->{1, 1}],
                  DisplayForm], 
                StyleBox["\[CenterDot]",
                  FontColor->RGBColor[0, 0.392187, 0]], 
                TagBox[
                  StyleBox[
                    InterpretationBox[
                      SubsuperscriptBox["c", 
                        TagBox[
                          StyleBox["\<\"\[UpArrow]\"\>",
                            FontColor->RGBColor[1, 0, 0]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            1, 0, 0]]&)], "\<\"\[Dagger]\"\>"],
                      Subsuperscript[ c, 
                        RowBox[ {
                          StyleForm[ 
                          "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                        "\[Dagger]"],
                      Editable->False],
                    ScriptSizeMultipliers->1,
                    ScriptBaselineShifts->{1, 1}],
                  DisplayForm], 
                StyleBox["\[CenterDot]",
                  FontColor->RGBColor[0, 0.392187, 0]], 
                TagBox[
                  StyleBox[
                    InterpretationBox[
                      SubsuperscriptBox["c", 
                        TagBox[
                          StyleBox["\<\"\[DownArrow]\"\>",
                            FontColor->RGBColor[0, 0, 1]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            0, 0, 1]]&)], "\<\"\"\>"],
                      Subsuperscript[ c, 
                        RowBox[ {
                          StyleForm[ 
                          "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], 
                        ""],
                      Editable->False],
                    ScriptSizeMultipliers->1,
                    ScriptBaselineShifts->{1, 1}],
                  DisplayForm], 
                StyleBox["\[CenterDot]",
                  FontColor->RGBColor[0, 0.392187, 0]], 
                TagBox[
                  StyleBox[
                    InterpretationBox[
                      SubsuperscriptBox["c", 
                        TagBox[
                          StyleBox["\<\"\[UpArrow]\"\>",
                            FontColor->RGBColor[1, 0, 0]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            1, 0, 0]]&)], "\<\"\"\>"],
                      Subsuperscript[ c, 
                        RowBox[ {
                          StyleForm[ 
                          "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                        ""],
                      Editable->False],
                    ScriptSizeMultipliers->1,
                    ScriptBaselineShifts->{1, 1}],
                  DisplayForm]}]}]},
          {"4", 
            RowBox[{"\<\"-\"\>", 
              RowBox[{
                TagBox[
                  StyleBox[
                    InterpretationBox[
                      SubsuperscriptBox["c", 
                        TagBox[
                          StyleBox["\<\"\[DownArrow]\"\>",
                            FontColor->RGBColor[0, 0, 1]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            0, 0, 1]]&)], "\<\"\[Dagger]\"\>"],
                      Subsuperscript[ c, 
                        RowBox[ {
                          StyleForm[ 
                          "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], 
                        "\[Dagger]"],
                      Editable->False],
                    ScriptSizeMultipliers->1,
                    ScriptBaselineShifts->{1, 1}],
                  DisplayForm], 
                StyleBox["\[CenterDot]",
                  FontColor->RGBColor[0, 0.392187, 0]], 
                TagBox[
                  StyleBox[
                    InterpretationBox[
                      SubsuperscriptBox["c", 
                        TagBox[
                          StyleBox["\<\"\[UpArrow]\"\>",
                            FontColor->RGBColor[1, 0, 0]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            1, 0, 0]]&)], "\<\"\[Dagger]\"\>"],
                      Subsuperscript[ c, 
                        RowBox[ {
                          StyleForm[ 
                          "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                        "\[Dagger]"],
                      Editable->False],
                    ScriptSizeMultipliers->1,
                    ScriptBaselineShifts->{1, 1}],
                  DisplayForm], 
                StyleBox["\[CenterDot]",
                  FontColor->RGBColor[0, 0.392187, 0]], 
                TagBox[
                  StyleBox[
                    InterpretationBox[
                      SubsuperscriptBox["c", 
                        TagBox[
                          StyleBox["\<\"\[DownArrow]\"\>",
                            FontColor->RGBColor[0, 0, 1]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            0, 0, 1]]&)], "\<\"\"\>"],
                      Subsuperscript[ c, 
                        RowBox[ {
                          StyleForm[ 
                          "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], 
                        ""],
                      Editable->False],
                    ScriptSizeMultipliers->1,
                    ScriptBaselineShifts->{1, 1}],
                  DisplayForm], 
                StyleBox["\[CenterDot]",
                  FontColor->RGBColor[0, 0.392187, 0]], 
                TagBox[
                  StyleBox[
                    InterpretationBox[
                      SubsuperscriptBox["c", 
                        TagBox[
                          StyleBox["\<\"\[UpArrow]\"\>",
                            FontColor->RGBColor[1, 0, 0]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            1, 0, 0]]&)], "\<\"\"\>"],
                      Subsuperscript[ c, 
                        RowBox[ {
                          StyleForm[ 
                          "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                        ""],
                      Editable->False],
                    ScriptSizeMultipliers->1,
                    ScriptBaselineShifts->{1, 1}],
                  DisplayForm]}]}]},
          {"5", 
            RowBox[{"\<\"-\"\>", 
              RowBox[{
                TagBox[
                  StyleBox[
                    InterpretationBox[
                      SubsuperscriptBox["c", 
                        TagBox[
                          StyleBox["\<\"\[DownArrow]\"\>",
                            FontColor->RGBColor[0, 0, 1]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            0, 0, 1]]&)], "\<\"\[Dagger]\"\>"],
                      Subsuperscript[ c, 
                        RowBox[ {
                          StyleForm[ 
                          "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], 
                        "\[Dagger]"],
                      Editable->False],
                    ScriptSizeMultipliers->1,
                    ScriptBaselineShifts->{1, 1}],
                  DisplayForm], 
                StyleBox["\[CenterDot]",
                  FontColor->RGBColor[0, 0.392187, 0]], 
                TagBox[
                  StyleBox[
                    InterpretationBox[
                      SubsuperscriptBox["c", 
                        TagBox[
                          StyleBox["\<\"\[UpArrow]\"\>",
                            FontColor->RGBColor[1, 0, 0]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            1, 0, 0]]&)], "\<\"\[Dagger]\"\>"],
                      Subsuperscript[ c, 
                        RowBox[ {
                          StyleForm[ 
                          "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                        "\[Dagger]"],
                      Editable->False],
                    ScriptSizeMultipliers->1,
                    ScriptBaselineShifts->{1, 1}],
                  DisplayForm], 
                StyleBox["\[CenterDot]",
                  FontColor->RGBColor[0, 0.392187, 0]], 
                TagBox[
                  StyleBox[
                    InterpretationBox[
                      SubsuperscriptBox["c", 
                        TagBox[
                          StyleBox["\<\"\[DownArrow]\"\>",
                            FontColor->RGBColor[0, 0, 1]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            0, 0, 1]]&)], "\<\"\"\>"],
                      Subsuperscript[ c, 
                        RowBox[ {
                          StyleForm[ 
                          "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], 
                        ""],
                      Editable->False],
                    ScriptSizeMultipliers->1,
                    ScriptBaselineShifts->{1, 1}],
                  DisplayForm], 
                StyleBox["\[CenterDot]",
                  FontColor->RGBColor[0, 0.392187, 0]], 
                TagBox[
                  StyleBox[
                    InterpretationBox[
                      SubsuperscriptBox["c", 
                        TagBox[
                          StyleBox["\<\"\[UpArrow]\"\>",
                            FontColor->RGBColor[1, 0, 0]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            1, 0, 0]]&)], "\<\"\"\>"],
                      Subsuperscript[ c, 
                        RowBox[ {
                          StyleForm[ 
                          "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                        ""],
                      Editable->False],
                    ScriptSizeMultipliers->1,
                    ScriptBaselineShifts->{1, 1}],
                  DisplayForm]}]}]}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      Function[ BoxForm`e$, 
        TableForm[ BoxForm`e$]]]], "Output",
  CellLabel->"Out[8]//TableForm="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(op = spinx[c[]]\), "\[IndentingNewLine]", 
    \(Table[{i, pow[op, i]}, {i, 0, 5}] // TableForm\)}], "Input",
  CellLabel->"In[9]:="],

Cell[BoxData[
    RowBox[{\(1\/2\), " ", 
      RowBox[{"(", 
        RowBox[{
          RowBox[{
            TagBox[
              StyleBox[
                InterpretationBox[
                  SubsuperscriptBox["c", 
                    TagBox[
                      StyleBox["\<\"\[DownArrow]\"\>",
                        FontColor->RGBColor[0, 0, 1]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        0, 0, 1]]&)], "\<\"\[Dagger]\"\>"],
                  Subsuperscript[ c, 
                    RowBox[ {
                      StyleForm[ 
                      "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], 
                    "\[Dagger]"],
                  Editable->False],
                ScriptSizeMultipliers->1,
                ScriptBaselineShifts->{1, 1}],
              DisplayForm], 
            StyleBox["\[CenterDot]",
              FontColor->RGBColor[0, 0.392187, 0]], 
            TagBox[
              StyleBox[
                InterpretationBox[
                  SubsuperscriptBox["c", 
                    TagBox[
                      StyleBox["\<\"\[UpArrow]\"\>",
                        FontColor->RGBColor[1, 0, 0]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        1, 0, 0]]&)], "\<\"\"\>"],
                  Subsuperscript[ c, 
                    RowBox[ {
                      StyleForm[ 
                      "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], ""],
                  Editable->False],
                ScriptSizeMultipliers->1,
                ScriptBaselineShifts->{1, 1}],
              DisplayForm]}], "+", 
          RowBox[{
            TagBox[
              StyleBox[
                InterpretationBox[
                  SubsuperscriptBox["c", 
                    TagBox[
                      StyleBox["\<\"\[UpArrow]\"\>",
                        FontColor->RGBColor[1, 0, 0]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        1, 0, 0]]&)], "\<\"\[Dagger]\"\>"],
                  Subsuperscript[ c, 
                    RowBox[ {
                      StyleForm[ 
                      "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                    "\[Dagger]"],
                  Editable->False],
                ScriptSizeMultipliers->1,
                ScriptBaselineShifts->{1, 1}],
              DisplayForm], 
            StyleBox["\[CenterDot]",
              FontColor->RGBColor[0, 0.392187, 0]], 
            TagBox[
              StyleBox[
                InterpretationBox[
                  SubsuperscriptBox["c", 
                    TagBox[
                      StyleBox["\<\"\[DownArrow]\"\>",
                        FontColor->RGBColor[0, 0, 1]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        0, 0, 1]]&)], "\<\"\"\>"],
                  Subsuperscript[ c, 
                    RowBox[ {
                      StyleForm[ 
                      "\[DownArrow]", FontColor -> RGBColor[ 0, 0, 1]]}], ""],
                  
                  Editable->False],
                ScriptSizeMultipliers->1,
                ScriptBaselineShifts->{1, 1}],
              DisplayForm]}]}], ")"}]}]], "Output",
  CellLabel->"Out[9]="],

Cell[BoxData[
    TagBox[GridBox[{
          {"0", "1"},
          {"1", 
            RowBox[{\(1\/2\), " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{
                    TagBox[
                      StyleBox[
                        InterpretationBox[
                          SubsuperscriptBox["c", 
                            TagBox[
                              StyleBox["\<\"\[DownArrow]\"\>",
                                FontColor->RGBColor[0, 0, 1]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                0, 0, 1]]&)], "\<\"\[Dagger]\"\>"],
                          Subsuperscript[ c, 
                            RowBox[ {
                              StyleForm[ 
                              "\[DownArrow]", FontColor -> RGBColor[ 
                                0, 0, 1]]}], "\[Dagger]"],
                          Editable->False],
                        ScriptSizeMultipliers->1,
                        ScriptBaselineShifts->{1, 1}],
                      DisplayForm], 
                    StyleBox["\[CenterDot]",
                      FontColor->RGBColor[0, 0.392187, 0]], 
                    TagBox[
                      StyleBox[
                        InterpretationBox[
                          SubsuperscriptBox["c", 
                            TagBox[
                              StyleBox["\<\"\[UpArrow]\"\>",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1, 0, 0]]&)], "\<\"\"\>"],
                          Subsuperscript[ c, 
                            RowBox[ {
                              StyleForm[ 
                              "\[UpArrow]", FontColor -> RGBColor[ 
                                1, 0, 0]]}], ""],
                          Editable->False],
                        ScriptSizeMultipliers->1,
                        ScriptBaselineShifts->{1, 1}],
                      DisplayForm]}], "+", 
                  RowBox[{
                    TagBox[
                      StyleBox[
                        InterpretationBox[
                          SubsuperscriptBox["c", 
                            TagBox[
                              StyleBox["\<\"\[UpArrow]\"\>",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1, 0, 0]]&)], "\<\"\[Dagger]\"\>"],
                          Subsuperscript[ c, 
                            RowBox[ {
                              StyleForm[ 
                              "\[UpArrow]", FontColor -> RGBColor[ 
                                1, 0, 0]]}], "\[Dagger]"],
                          Editable->False],
                        ScriptSizeMultipliers->1,
                        ScriptBaselineShifts->{1, 1}],
                      DisplayForm], 
                    StyleBox["\[CenterDot]",
                      FontColor->RGBColor[0, 0.392187, 0]], 
                    TagBox[
                      StyleBox[
                        InterpretationBox[
                          SubsuperscriptBox["c", 
                            TagBox[
                              StyleBox["\<\"\[DownArrow]\"\>",
                                FontColor->RGBColor[0, 0, 1]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                0, 0, 1]]&)], "\<\"\"\>"],
                          Subsuperscript[ c, 
                            RowBox[ {
                              StyleForm[ 
                              "\[DownArrow]", FontColor -> RGBColor[ 
                                0, 0, 1]]}], ""],
                          Editable->False],
                        ScriptSizeMultipliers->1,
                        ScriptBaselineShifts->{1, 1}],
                      DisplayForm]}]}], ")"}]}]},
          {"2", 
            RowBox[{\(1\/4\), " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{
                    TagBox[
                      StyleBox[
                        InterpretationBox[
                          SubsuperscriptBox["c", 
                            TagBox[
                              StyleBox["\<\"\[DownArrow]\"\>",
                                FontColor->RGBColor[0, 0, 1]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                0, 0, 1]]&)], "\<\"\[Dagger]\"\>"],
                          Subsuperscript[ c, 
                            RowBox[ {
                              StyleForm[ 
                              "\[DownArrow]", FontColor -> RGBColor[ 
                                0, 0, 1]]}], "\[Dagger]"],
                          Editable->False],
                        ScriptSizeMultipliers->1,
                        ScriptBaselineShifts->{1, 1}],
                      DisplayForm], 
                    StyleBox["\[CenterDot]",
                      FontColor->RGBColor[0, 0.392187, 0]], 
                    TagBox[
                      StyleBox[
                        InterpretationBox[
                          SubsuperscriptBox["c", 
                            TagBox[
                              StyleBox["\<\"\[DownArrow]\"\>",
                                FontColor->RGBColor[0, 0, 1]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                0, 0, 1]]&)], "\<\"\"\>"],
                          Subsuperscript[ c, 
                            RowBox[ {
                              StyleForm[ 
                              "\[DownArrow]", FontColor -> RGBColor[ 
                                0, 0, 1]]}], ""],
                          Editable->False],
                        ScriptSizeMultipliers->1,
                        ScriptBaselineShifts->{1, 1}],
                      DisplayForm]}], "+", 
                  RowBox[{
                    TagBox[
                      StyleBox[
                        InterpretationBox[
                          SubsuperscriptBox["c", 
                            TagBox[
                              StyleBox["\<\"\[UpArrow]\"\>",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1, 0, 0]]&)], "\<\"\[Dagger]\"\>"],
                          Subsuperscript[ c, 
                            RowBox[ {
                              StyleForm[ 
                              "\[UpArrow]", FontColor -> RGBColor[ 
                                1, 0, 0]]}], "\[Dagger]"],
                          Editable->False],
                        ScriptSizeMultipliers->1,
                        ScriptBaselineShifts->{1, 1}],
                      DisplayForm], 
                    StyleBox["\[CenterDot]",
                      FontColor->RGBColor[0, 0.392187, 0]], 
                    TagBox[
                      StyleBox[
                        InterpretationBox[
                          SubsuperscriptBox["c", 
                            TagBox[
                              StyleBox["\<\"\[UpArrow]\"\>",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1, 0, 0]]&)], "\<\"\"\>"],
                          Subsuperscript[ c, 
                            RowBox[ {
                              StyleForm[ 
                              "\[UpArrow]", FontColor -> RGBColor[ 
                                1, 0, 0]]}], ""],
                          Editable->False],
                        ScriptSizeMultipliers->1,
                        ScriptBaselineShifts->{1, 1}],
                      DisplayForm]}], "+", 
                  RowBox[{"2", 
                    RowBox[{
                      TagBox[
                        StyleBox[
                          InterpretationBox[
                            SubsuperscriptBox["c", 
                              TagBox[
                                StyleBox["\<\"\[DownArrow]\"\>",
                                  FontColor->RGBColor[0, 0, 1]],
                                (StyleForm[ #, FontColor -> RGBColor[ 
                                  0, 0, 1]]&)], "\<\"\[Dagger]\"\>"],
                            Subsuperscript[ c, 
                              RowBox[ {
                                StyleForm[ 
                                "\[DownArrow]", FontColor -> RGBColor[ 
                                  0, 0, 1]]}], "\[Dagger]"],
                            Editable->False],
                          ScriptSizeMultipliers->1,
                          ScriptBaselineShifts->{1, 1}],
                        DisplayForm], 
                      StyleBox["\[CenterDot]",
                        FontColor->RGBColor[0, 0.392187, 0]], 
                      TagBox[
                        StyleBox[
                          InterpretationBox[
                            SubsuperscriptBox["c", 
                              TagBox[
                                StyleBox["\<\"\[UpArrow]\"\>",
                                  FontColor->RGBColor[1, 0, 0]],
                                (
                                StyleForm[ #, FontColor -> RGBColor[ 
                                  1, 0, 0]]&)], "\<\"\[Dagger]\"\>"],
                            Subsuperscript[ c, 
                              RowBox[ {
                                StyleForm[ 
                                "\[UpArrow]", FontColor -> RGBColor[ 
                                  1, 0, 0]]}], "\[Dagger]"],
                            Editable->False],
                          ScriptSizeMultipliers->1,
                          ScriptBaselineShifts->{1, 1}],
                        DisplayForm], 
                      StyleBox["\[CenterDot]",
                        FontColor->RGBColor[0, 0.392187, 0]], 
                      TagBox[
                        StyleBox[
                          InterpretationBox[
                            SubsuperscriptBox["c", 
                              TagBox[
                                StyleBox["\<\"\[DownArrow]\"\>",
                                  FontColor->RGBColor[0, 0, 1]],
                                (StyleForm[ #, FontColor -> RGBColor[ 
                                  0, 0, 1]]&)], "\<\"\"\>"],
                            Subsuperscript[ c, 
                              RowBox[ {
                                StyleForm[ 
                                "\[DownArrow]", FontColor -> RGBColor[ 
                                  0, 0, 1]]}], ""],
                            Editable->False],
                          ScriptSizeMultipliers->1,
                          ScriptBaselineShifts->{1, 1}],
                        DisplayForm], 
                      StyleBox["\[CenterDot]",
                        FontColor->RGBColor[0, 0.392187, 0]], 
                      TagBox[
                        StyleBox[
                          InterpretationBox[
                            SubsuperscriptBox["c", 
                              TagBox[
                                StyleBox["\<\"\[UpArrow]\"\>",
                                  FontColor->RGBColor[1, 0, 0]],
                                (
                                StyleForm[ #, FontColor -> RGBColor[ 
                                  1, 0, 0]]&)], "\<\"\"\>"],
                            Subsuperscript[ c, 
                              RowBox[ {
                                StyleForm[ 
                                "\[UpArrow]", FontColor -> RGBColor[ 
                                  1, 0, 0]]}], ""],
                            Editable->False],
                          ScriptSizeMultipliers->1,
                          ScriptBaselineShifts->{1, 1}],
                        DisplayForm]}]}]}], ")"}]}]},
          {"3", 
            RowBox[{\(1\/8\), " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{
                    TagBox[
                      StyleBox[
                        InterpretationBox[
                          SubsuperscriptBox["c", 
                            TagBox[
                              StyleBox["\<\"\[DownArrow]\"\>",
                                FontColor->RGBColor[0, 0, 1]],
                              (StyleForm[ #, FontColor -> RGBColor[ 
                                0, 0, 1]]&)], "\<\"\[Dagger]\"\>"],
                          Subsuperscript[ c, 
                            RowBox[ {
                              StyleForm[ 
                              "\[DownArrow]", FontColor -> RGBColor[ 
                                0, 0, 1]]}], "\[Dagger]"],
                          Editable->False],
                        ScriptSizeMultipliers->1,
                        ScriptBaselineShifts->{1, 1}],
                      DisplayForm], 
                    StyleBox["\[CenterDot]",
                      FontColor->RGBColor[0, 0.392187, 0]], 
                    TagBox[
                      StyleBox[
                        InterpretationBox[
                          SubsuperscriptBox["c", 
                            TagBox[
                              StyleBox["\<\"\[UpArrow]\"\>",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1, 0, 0]]&)], "\<\"\"\>"],
                          Subsuperscript[ c, 
                            RowBox[ {
                              StyleForm[ 
                              "\[UpArrow]", FontColor -> RGBColor[ 
                                1, 0, 0]]}], ""],
                          Editable->False],
                        ScriptSizeMultipliers->1,
                        ScriptBaselineShifts->{1, 1}],
                      DisplayForm]}], "+", 
                  RowBox[{
                    TagBox[
                      StyleBox[
                        InterpretationBox[
                          SubsuperscriptBox["c", 
                            TagBox[
                              StyleBox["\<\"\[UpArrow]\"\>",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1, 0, 0]]&)], "\<\"\[Dagger]\"\>"],
                          Subsuperscript[ c, 
                            RowBox[ {
                              StyleForm[ 
                              "\[UpArrow]", FontColor -> RGBColor[ 
                                1, 0, 0]]}], "\[Dagger]"],
                          Editable->False],
                        ScriptSizeMultipliers->1,
                        ScriptBaselineShifts->{1, 1}],
                      DisplayForm], 
                    StyleBox["\[CenterDot]",
                      FontColor->RGBColor[0, 0.392187, 0]], 
                    TagBox[
                      StyleBox[
                        InterpretationBox[
                          SubsuperscriptBox["c", 
                            TagBox[
                              StyleBox["\<\"\[DownArrow]\"\>",
                                FontColor->RGBColor[0, 0, 1]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                0, 0, 1]]&)], "\<\"\"\>"],
                          Subsuperscript[ c, 
                            RowBox[ {
                              StyleForm[ 
                              "\[DownArrow]", FontColor -> RGBColor[ 
                                0, 0, 1]]}], ""],
                          Editable->False],
                        ScriptSizeMultipliers->1,
                        ScriptBaselineShifts->{1, 1}],
                      DisplayForm]}]}], ")"}]}]},
          {"4", 
            RowBox[{\(1\/16\), " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{
                    TagBox[
                      StyleBox[
                        InterpretationBox[
                          SubsuperscriptBox["c", 
                            TagBox[
                              StyleBox["\<\"\[DownArrow]\"\>",
                                FontColor->RGBColor[0, 0, 1]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                0, 0, 1]]&)], "\<\"\[Dagger]\"\>"],
                          Subsuperscript[ c, 
                            RowBox[ {
                              StyleForm[ 
                              "\[DownArrow]", FontColor -> RGBColor[ 
                                0, 0, 1]]}], "\[Dagger]"],
                          Editable->False],
                        ScriptSizeMultipliers->1,
                        ScriptBaselineShifts->{1, 1}],
                      DisplayForm], 
                    StyleBox["\[CenterDot]",
                      FontColor->RGBColor[0, 0.392187, 0]], 
                    TagBox[
                      StyleBox[
                        InterpretationBox[
                          SubsuperscriptBox["c", 
                            TagBox[
                              StyleBox["\<\"\[DownArrow]\"\>",
                                FontColor->RGBColor[0, 0, 1]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                0, 0, 1]]&)], "\<\"\"\>"],
                          Subsuperscript[ c, 
                            RowBox[ {
                              StyleForm[ 
                              "\[DownArrow]", FontColor -> RGBColor[ 
                                0, 0, 1]]}], ""],
                          Editable->False],
                        ScriptSizeMultipliers->1,
                        ScriptBaselineShifts->{1, 1}],
                      DisplayForm]}], "+", 
                  RowBox[{
                    TagBox[
                      StyleBox[
                        InterpretationBox[
                          SubsuperscriptBox["c", 
                            TagBox[
                              StyleBox["\<\"\[UpArrow]\"\>",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1, 0, 0]]&)], "\<\"\[Dagger]\"\>"],
                          Subsuperscript[ c, 
                            RowBox[ {
                              StyleForm[ 
                              "\[UpArrow]", FontColor -> RGBColor[ 
                                1, 0, 0]]}], "\[Dagger]"],
                          Editable->False],
                        ScriptSizeMultipliers->1,
                        ScriptBaselineShifts->{1, 1}],
                      DisplayForm], 
                    StyleBox["\[CenterDot]",
                      FontColor->RGBColor[0, 0.392187, 0]], 
                    TagBox[
                      StyleBox[
                        InterpretationBox[
                          SubsuperscriptBox["c", 
                            TagBox[
                              StyleBox["\<\"\[UpArrow]\"\>",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1, 0, 0]]&)], "\<\"\"\>"],
                          Subsuperscript[ c, 
                            RowBox[ {
                              StyleForm[ 
                              "\[UpArrow]", FontColor -> RGBColor[ 
                                1, 0, 0]]}], ""],
                          Editable->False],
                        ScriptSizeMultipliers->1,
                        ScriptBaselineShifts->{1, 1}],
                      DisplayForm]}], "+", 
                  RowBox[{"2", 
                    RowBox[{
                      TagBox[
                        StyleBox[
                          InterpretationBox[
                            SubsuperscriptBox["c", 
                              TagBox[
                                StyleBox["\<\"\[DownArrow]\"\>",
                                  FontColor->RGBColor[0, 0, 1]],
                                (
                                StyleForm[ #, FontColor -> RGBColor[ 
                                  0, 0, 1]]&)], "\<\"\[Dagger]\"\>"],
                            Subsuperscript[ c, 
                              RowBox[ {
                                StyleForm[ 
                                "\[DownArrow]", FontColor -> RGBColor[ 
                                  0, 0, 1]]}], "\[Dagger]"],
                            Editable->False],
                          ScriptSizeMultipliers->1,
                          ScriptBaselineShifts->{1, 1}],
                        DisplayForm], 
                      StyleBox["\[CenterDot]",
                        FontColor->RGBColor[0, 0.392187, 0]], 
                      TagBox[
                        StyleBox[
                          InterpretationBox[
                            SubsuperscriptBox["c", 
                              TagBox[
                                StyleBox["\<\"\[UpArrow]\"\>",
                                  FontColor->RGBColor[1, 0, 0]],
                                (
                                StyleForm[ #, FontColor -> RGBColor[ 
                                  1, 0, 0]]&)], "\<\"\[Dagger]\"\>"],
                            Subsuperscript[ c, 
                              RowBox[ {
                                StyleForm[ 
                                "\[UpArrow]", FontColor -> RGBColor[ 
                                  1, 0, 0]]}], "\[Dagger]"],
                            Editable->False],
                          ScriptSizeMultipliers->1,
                          ScriptBaselineShifts->{1, 1}],
                        DisplayForm], 
                      StyleBox["\[CenterDot]",
                        FontColor->RGBColor[0, 0.392187, 0]], 
                      TagBox[
                        StyleBox[
                          InterpretationBox[
                            SubsuperscriptBox["c", 
                              TagBox[
                                StyleBox["\<\"\[DownArrow]\"\>",
                                  FontColor->RGBColor[0, 0, 1]],
                                (
                                StyleForm[ #, FontColor -> RGBColor[ 
                                  0, 0, 1]]&)], "\<\"\"\>"],
                            Subsuperscript[ c, 
                              RowBox[ {
                                StyleForm[ 
                                "\[DownArrow]", FontColor -> RGBColor[ 
                                  0, 0, 1]]}], ""],
                            Editable->False],
                          ScriptSizeMultipliers->1,
                          ScriptBaselineShifts->{1, 1}],
                        DisplayForm], 
                      StyleBox["\[CenterDot]",
                        FontColor->RGBColor[0, 0.392187, 0]], 
                      TagBox[
                        StyleBox[
                          InterpretationBox[
                            SubsuperscriptBox["c", 
                              TagBox[
                                StyleBox["\<\"\[UpArrow]\"\>",
                                  FontColor->RGBColor[1, 0, 0]],
                                (
                                StyleForm[ #, FontColor -> RGBColor[ 
                                  1, 0, 0]]&)], "\<\"\"\>"],
                            Subsuperscript[ c, 
                              RowBox[ {
                                StyleForm[ 
                                "\[UpArrow]", FontColor -> RGBColor[ 
                                  1, 0, 0]]}], ""],
                            Editable->False],
                          ScriptSizeMultipliers->1,
                          ScriptBaselineShifts->{1, 1}],
                        DisplayForm]}]}]}], ")"}]}]},
          {"5", 
            RowBox[{\(1\/32\), " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{
                    TagBox[
                      StyleBox[
                        InterpretationBox[
                          SubsuperscriptBox["c", 
                            TagBox[
                              StyleBox["\<\"\[DownArrow]\"\>",
                                FontColor->RGBColor[0, 0, 1]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                0, 0, 1]]&)], "\<\"\[Dagger]\"\>"],
                          Subsuperscript[ c, 
                            RowBox[ {
                              StyleForm[ 
                              "\[DownArrow]", FontColor -> RGBColor[ 
                                0, 0, 1]]}], "\[Dagger]"],
                          Editable->False],
                        ScriptSizeMultipliers->1,
                        ScriptBaselineShifts->{1, 1}],
                      DisplayForm], 
                    StyleBox["\[CenterDot]",
                      FontColor->RGBColor[0, 0.392187, 0]], 
                    TagBox[
                      StyleBox[
                        InterpretationBox[
                          SubsuperscriptBox["c", 
                            TagBox[
                              StyleBox["\<\"\[UpArrow]\"\>",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1, 0, 0]]&)], "\<\"\"\>"],
                          Subsuperscript[ c, 
                            RowBox[ {
                              StyleForm[ 
                              "\[UpArrow]", FontColor -> RGBColor[ 
                                1, 0, 0]]}], ""],
                          Editable->False],
                        ScriptSizeMultipliers->1,
                        ScriptBaselineShifts->{1, 1}],
                      DisplayForm]}], "+", 
                  RowBox[{
                    TagBox[
                      StyleBox[
                        InterpretationBox[
                          SubsuperscriptBox["c", 
                            TagBox[
                              StyleBox["\<\"\[UpArrow]\"\>",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1, 0, 0]]&)], "\<\"\[Dagger]\"\>"],
                          Subsuperscript[ c, 
                            RowBox[ {
                              StyleForm[ 
                              "\[UpArrow]", FontColor -> RGBColor[ 
                                1, 0, 0]]}], "\[Dagger]"],
                          Editable->False],
                        ScriptSizeMultipliers->1,
                        ScriptBaselineShifts->{1, 1}],
                      DisplayForm], 
                    StyleBox["\[CenterDot]",
                      FontColor->RGBColor[0, 0.392187, 0]], 
                    TagBox[
                      StyleBox[
                        InterpretationBox[
                          SubsuperscriptBox["c", 
                            TagBox[
                              StyleBox["\<\"\[DownArrow]\"\>",
                                FontColor->RGBColor[0, 0, 1]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                0, 0, 1]]&)], "\<\"\"\>"],
                          Subsuperscript[ c, 
                            RowBox[ {
                              StyleForm[ 
                              "\[DownArrow]", FontColor -> RGBColor[ 
                                0, 0, 1]]}], ""],
                          Editable->False],
                        ScriptSizeMultipliers->1,
                        ScriptBaselineShifts->{1, 1}],
                      DisplayForm]}]}], ")"}]}]}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      Function[ BoxForm`e$, 
        TableForm[ BoxForm`e$]]]], "Output",
  CellLabel->"Out[10]//TableForm="]
}, Open  ]]
}, Closed]]
}, Open  ]]
},
FrontEndVersion->"5.1 for X",
ScreenRectangle->{{0, 2880}, {0, 1200}},
WindowSize->{520, 600},
WindowMargins->{{Automatic, 180}, {119, Automatic}},
ShowSelection->True,
StyleDefinitions -> "HelpBrowser.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 25, 0, 38, "ObjectName"],
Cell[1804, 55, 356, 14, 48, "Usage"],
Cell[2163, 71, 129, 4, 24, "Notes"],
Cell[2295, 77, 380, 13, 40, "Notes"],
Cell[2678, 92, 273, 11, 24, "Notes"],

Cell[CellGroupData[{
Cell[2976, 107, 42, 0, 38, "ExampleSection"],
Cell[3021, 109, 117, 4, 34, "ExampleText"],

Cell[CellGroupData[{
Cell[3163, 117, 139, 3, 42, "Input"],
Cell[3305, 122, 103, 2, 21, "Print"]
}, Open  ]],

Cell[CellGroupData[{
Cell[3445, 129, 155, 3, 42, "Input"],
Cell[3603, 134, 2934, 81, 33, "Output"],
Cell[6540, 217, 33824, 765, 168, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[40401, 987, 159, 3, 42, "Input"],
Cell[40563, 992, 1388, 40, 33, "Output"],
Cell[41954, 1034, 8861, 219, 168, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[50852, 1258, 156, 3, 42, "Input"],
Cell[51011, 1263, 3007, 82, 33, "Output"],
Cell[54021, 1347, 18816, 435, 168, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[72874, 1787, 154, 3, 42, "Input"],
Cell[73031, 1792, 3355, 85, 42, "Output"],
Cell[76389, 1879, 28830, 605, 172, "Output"]
}, Open  ]]
}, Closed]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

