(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 8.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       157,          7]
NotebookDataLength[     43056,       1295]
NotebookOptionsPosition[     42351,       1265]
NotebookOutlinePosition[     42705,       1281]
CellTagsIndexPosition[     42662,       1278]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell["\<\
Generation of the matrix representation for a two-site Hubbard model
Rok Zitko, rok.zitko@ijs.si, March 2011\
\>", "Text",
 CellChangeTimes->{{3.5097803938278027`*^9, 3.5097804165383*^9}, {
  3.509780674737767*^9, 3.509780683568478*^9}},
 Background->RGBColor[0.87, 0.94, 1]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"<<", "sneg`sneg`"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"snegfermionoperators", "[", "c", "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"snegrealconstants", "[", 
   RowBox[{"\[Epsilon]", ",", "U", ",", "t"}], "]"}], ";"}]}], "Input",
 CellChangeTimes->{{3.50978038164751*^9, 3.509780388553472*^9}, {
  3.509780693011101*^9, 3.509780693114265*^9}}],

Cell[BoxData["\<\"sneg 1.229 Copyright (C) 2011 Rok Zitko\"\>"], "Print",
 CellChangeTimes->{3.509780423173333*^9, 3.509780704471222*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"H", "=", 
  RowBox[{
   RowBox[{"\[Epsilon]", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"number", "[", 
       RowBox[{"c", "[", "1", "]"}], "]"}], "+", 
      RowBox[{"number", "[", 
       RowBox[{"c", "[", "2", "]"}], "]"}]}], ")"}]}], "+", 
   RowBox[{"U", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"hubbard", "[", 
       RowBox[{"c", "[", "1", "]"}], "]"}], "+", 
      RowBox[{"hubbard", "[", 
       RowBox[{"c", "[", "2", "]"}], "]"}]}], ")"}]}], "+", 
   RowBox[{"t", " ", 
    RowBox[{"hop", "[", 
     RowBox[{
      RowBox[{"c", "[", "1", "]"}], ",", 
      RowBox[{"c", "[", "2", "]"}]}], "]"}]}]}]}]], "Input",
 CellChangeTimes->{{3.509780433271616*^9, 3.509780645240891*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"t", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      TagBox[
       StyleBox[
        InterpretationBox[
         SubsuperscriptBox["c", 
          RowBox[{"1", 
           TagBox[
            StyleBox["\<\"\[DownArrow]\"\>",
             FontColor->RGBColor[0, 0, 1]],
            
            StyleForm[#, FontColor -> 
             RGBColor[0, 0, 1]]& ]}], "\<\"\[Dagger]\"\>"],
         Subsuperscript[Sneg`c, 
          RowBox[{1, 
            StyleForm["\[DownArrow]", FontColor -> RGBColor[0, 0, 1]]}], 
          "\[Dagger]"],
         Editable->False],
        ScriptSizeMultipliers->1,
        ScriptBaselineShifts->{1, 1}],
       DisplayForm], 
      StyleBox["\[CenterDot]",
       FontColor->RGBColor[0, 1, 0]], 
      TagBox[
       StyleBox[
        InterpretationBox[
         SubsuperscriptBox["c", 
          RowBox[{"2", 
           TagBox[
            StyleBox["\<\"\[DownArrow]\"\>",
             FontColor->RGBColor[0, 0, 1]],
            StyleForm[#, FontColor -> RGBColor[0, 0, 1]]& ]}], "\<\"\"\>"],
         Subsuperscript[Sneg`c, 
          RowBox[{2, 
            StyleForm["\[DownArrow]", FontColor -> RGBColor[0, 0, 1]]}], ""],
         Editable->False],
        ScriptSizeMultipliers->1,
        ScriptBaselineShifts->{1, 1}],
       DisplayForm]}], "+", 
     RowBox[{
      TagBox[
       StyleBox[
        InterpretationBox[
         SubsuperscriptBox["c", 
          RowBox[{"1", 
           TagBox[
            StyleBox["\<\"\[DoubleUpArrow]\"\>",
             FontColor->RGBColor[1, 0, 0]],
            
            StyleForm[#, FontColor -> 
             RGBColor[1, 0, 0]]& ]}], "\<\"\[Dagger]\"\>"],
         Subsuperscript[Sneg`c, 
          RowBox[{1, 
            StyleForm["\[DoubleUpArrow]", FontColor -> RGBColor[1, 0, 0]]}], 
          "\[Dagger]"],
         Editable->False],
        ScriptSizeMultipliers->1,
        ScriptBaselineShifts->{1, 1}],
       DisplayForm], 
      StyleBox["\[CenterDot]",
       FontColor->RGBColor[0, 1, 0]], 
      TagBox[
       StyleBox[
        InterpretationBox[
         SubsuperscriptBox["c", 
          RowBox[{"2", 
           TagBox[
            StyleBox["\<\"\[DoubleUpArrow]\"\>",
             FontColor->RGBColor[1, 0, 0]],
            StyleForm[#, FontColor -> RGBColor[1, 0, 0]]& ]}], "\<\"\"\>"],
         Subsuperscript[Sneg`c, 
          RowBox[{2, 
            StyleForm["\[DoubleUpArrow]", FontColor -> RGBColor[1, 0, 0]]}], 
          ""],
         Editable->False],
        ScriptSizeMultipliers->1,
        ScriptBaselineShifts->{1, 1}],
       DisplayForm]}], "+", 
     RowBox[{
      TagBox[
       StyleBox[
        InterpretationBox[
         SubsuperscriptBox["c", 
          RowBox[{"2", 
           TagBox[
            StyleBox["\<\"\[DownArrow]\"\>",
             FontColor->RGBColor[0, 0, 1]],
            
            StyleForm[#, FontColor -> 
             RGBColor[0, 0, 1]]& ]}], "\<\"\[Dagger]\"\>"],
         Subsuperscript[Sneg`c, 
          RowBox[{2, 
            StyleForm["\[DownArrow]", FontColor -> RGBColor[0, 0, 1]]}], 
          "\[Dagger]"],
         Editable->False],
        ScriptSizeMultipliers->1,
        ScriptBaselineShifts->{1, 1}],
       DisplayForm], 
      StyleBox["\[CenterDot]",
       FontColor->RGBColor[0, 1, 0]], 
      TagBox[
       StyleBox[
        InterpretationBox[
         SubsuperscriptBox["c", 
          RowBox[{"1", 
           TagBox[
            StyleBox["\<\"\[DownArrow]\"\>",
             FontColor->RGBColor[0, 0, 1]],
            StyleForm[#, FontColor -> RGBColor[0, 0, 1]]& ]}], "\<\"\"\>"],
         Subsuperscript[Sneg`c, 
          RowBox[{1, 
            StyleForm["\[DownArrow]", FontColor -> RGBColor[0, 0, 1]]}], ""],
         Editable->False],
        ScriptSizeMultipliers->1,
        ScriptBaselineShifts->{1, 1}],
       DisplayForm]}], "+", 
     RowBox[{
      TagBox[
       StyleBox[
        InterpretationBox[
         SubsuperscriptBox["c", 
          RowBox[{"2", 
           TagBox[
            StyleBox["\<\"\[DoubleUpArrow]\"\>",
             FontColor->RGBColor[1, 0, 0]],
            
            StyleForm[#, FontColor -> 
             RGBColor[1, 0, 0]]& ]}], "\<\"\[Dagger]\"\>"],
         Subsuperscript[Sneg`c, 
          RowBox[{2, 
            StyleForm["\[DoubleUpArrow]", FontColor -> RGBColor[1, 0, 0]]}], 
          "\[Dagger]"],
         Editable->False],
        ScriptSizeMultipliers->1,
        ScriptBaselineShifts->{1, 1}],
       DisplayForm], 
      StyleBox["\[CenterDot]",
       FontColor->RGBColor[0, 1, 0]], 
      TagBox[
       StyleBox[
        InterpretationBox[
         SubsuperscriptBox["c", 
          RowBox[{"1", 
           TagBox[
            StyleBox["\<\"\[DoubleUpArrow]\"\>",
             FontColor->RGBColor[1, 0, 0]],
            StyleForm[#, FontColor -> RGBColor[1, 0, 0]]& ]}], "\<\"\"\>"],
         Subsuperscript[Sneg`c, 
          RowBox[{1, 
            StyleForm["\[DoubleUpArrow]", FontColor -> RGBColor[1, 0, 0]]}], 
          ""],
         Editable->False],
        ScriptSizeMultipliers->1,
        ScriptBaselineShifts->{1, 1}],
       DisplayForm]}]}], ")"}]}], "+", 
  RowBox[{"\[Epsilon]", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      TagBox[
       StyleBox[
        InterpretationBox[
         SubsuperscriptBox["c", 
          RowBox[{"1", 
           TagBox[
            StyleBox["\<\"\[DownArrow]\"\>",
             FontColor->RGBColor[0, 0, 1]],
            
            StyleForm[#, FontColor -> 
             RGBColor[0, 0, 1]]& ]}], "\<\"\[Dagger]\"\>"],
         Subsuperscript[Sneg`c, 
          RowBox[{1, 
            StyleForm["\[DownArrow]", FontColor -> RGBColor[0, 0, 1]]}], 
          "\[Dagger]"],
         Editable->False],
        ScriptSizeMultipliers->1,
        ScriptBaselineShifts->{1, 1}],
       DisplayForm], 
      StyleBox["\[CenterDot]",
       FontColor->RGBColor[0, 1, 0]], 
      TagBox[
       StyleBox[
        InterpretationBox[
         SubsuperscriptBox["c", 
          RowBox[{"1", 
           TagBox[
            StyleBox["\<\"\[DownArrow]\"\>",
             FontColor->RGBColor[0, 0, 1]],
            StyleForm[#, FontColor -> RGBColor[0, 0, 1]]& ]}], "\<\"\"\>"],
         Subsuperscript[Sneg`c, 
          RowBox[{1, 
            StyleForm["\[DownArrow]", FontColor -> RGBColor[0, 0, 1]]}], ""],
         Editable->False],
        ScriptSizeMultipliers->1,
        ScriptBaselineShifts->{1, 1}],
       DisplayForm]}], "+", 
     RowBox[{
      TagBox[
       StyleBox[
        InterpretationBox[
         SubsuperscriptBox["c", 
          RowBox[{"1", 
           TagBox[
            StyleBox["\<\"\[DoubleUpArrow]\"\>",
             FontColor->RGBColor[1, 0, 0]],
            
            StyleForm[#, FontColor -> 
             RGBColor[1, 0, 0]]& ]}], "\<\"\[Dagger]\"\>"],
         Subsuperscript[Sneg`c, 
          RowBox[{1, 
            StyleForm["\[DoubleUpArrow]", FontColor -> RGBColor[1, 0, 0]]}], 
          "\[Dagger]"],
         Editable->False],
        ScriptSizeMultipliers->1,
        ScriptBaselineShifts->{1, 1}],
       DisplayForm], 
      StyleBox["\[CenterDot]",
       FontColor->RGBColor[0, 1, 0]], 
      TagBox[
       StyleBox[
        InterpretationBox[
         SubsuperscriptBox["c", 
          RowBox[{"1", 
           TagBox[
            StyleBox["\<\"\[DoubleUpArrow]\"\>",
             FontColor->RGBColor[1, 0, 0]],
            StyleForm[#, FontColor -> RGBColor[1, 0, 0]]& ]}], "\<\"\"\>"],
         Subsuperscript[Sneg`c, 
          RowBox[{1, 
            StyleForm["\[DoubleUpArrow]", FontColor -> RGBColor[1, 0, 0]]}], 
          ""],
         Editable->False],
        ScriptSizeMultipliers->1,
        ScriptBaselineShifts->{1, 1}],
       DisplayForm]}], "+", 
     RowBox[{
      TagBox[
       StyleBox[
        InterpretationBox[
         SubsuperscriptBox["c", 
          RowBox[{"2", 
           TagBox[
            StyleBox["\<\"\[DownArrow]\"\>",
             FontColor->RGBColor[0, 0, 1]],
            
            StyleForm[#, FontColor -> 
             RGBColor[0, 0, 1]]& ]}], "\<\"\[Dagger]\"\>"],
         Subsuperscript[Sneg`c, 
          RowBox[{2, 
            StyleForm["\[DownArrow]", FontColor -> RGBColor[0, 0, 1]]}], 
          "\[Dagger]"],
         Editable->False],
        ScriptSizeMultipliers->1,
        ScriptBaselineShifts->{1, 1}],
       DisplayForm], 
      StyleBox["\[CenterDot]",
       FontColor->RGBColor[0, 1, 0]], 
      TagBox[
       StyleBox[
        InterpretationBox[
         SubsuperscriptBox["c", 
          RowBox[{"2", 
           TagBox[
            StyleBox["\<\"\[DownArrow]\"\>",
             FontColor->RGBColor[0, 0, 1]],
            StyleForm[#, FontColor -> RGBColor[0, 0, 1]]& ]}], "\<\"\"\>"],
         Subsuperscript[Sneg`c, 
          RowBox[{2, 
            StyleForm["\[DownArrow]", FontColor -> RGBColor[0, 0, 1]]}], ""],
         Editable->False],
        ScriptSizeMultipliers->1,
        ScriptBaselineShifts->{1, 1}],
       DisplayForm]}], "+", 
     RowBox[{
      TagBox[
       StyleBox[
        InterpretationBox[
         SubsuperscriptBox["c", 
          RowBox[{"2", 
           TagBox[
            StyleBox["\<\"\[DoubleUpArrow]\"\>",
             FontColor->RGBColor[1, 0, 0]],
            
            StyleForm[#, FontColor -> 
             RGBColor[1, 0, 0]]& ]}], "\<\"\[Dagger]\"\>"],
         Subsuperscript[Sneg`c, 
          RowBox[{2, 
            StyleForm["\[DoubleUpArrow]", FontColor -> RGBColor[1, 0, 0]]}], 
          "\[Dagger]"],
         Editable->False],
        ScriptSizeMultipliers->1,
        ScriptBaselineShifts->{1, 1}],
       DisplayForm], 
      StyleBox["\[CenterDot]",
       FontColor->RGBColor[0, 1, 0]], 
      TagBox[
       StyleBox[
        InterpretationBox[
         SubsuperscriptBox["c", 
          RowBox[{"2", 
           TagBox[
            StyleBox["\<\"\[DoubleUpArrow]\"\>",
             FontColor->RGBColor[1, 0, 0]],
            StyleForm[#, FontColor -> RGBColor[1, 0, 0]]& ]}], "\<\"\"\>"],
         Subsuperscript[Sneg`c, 
          RowBox[{2, 
            StyleForm["\[DoubleUpArrow]", FontColor -> RGBColor[1, 0, 0]]}], 
          ""],
         Editable->False],
        ScriptSizeMultipliers->1,
        ScriptBaselineShifts->{1, 1}],
       DisplayForm]}]}], ")"}]}], "+", 
  RowBox[{"U", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", 
      RowBox[{"(", 
       RowBox[{
        TagBox[
         StyleBox[
          InterpretationBox[
           SubsuperscriptBox["c", 
            RowBox[{"1", 
             TagBox[
              StyleBox["\<\"\[DownArrow]\"\>",
               FontColor->RGBColor[0, 0, 1]],
              
              StyleForm[#, FontColor -> 
               RGBColor[0, 0, 1]]& ]}], "\<\"\[Dagger]\"\>"],
           Subsuperscript[Sneg`c, 
            RowBox[{1, 
              StyleForm["\[DownArrow]", FontColor -> RGBColor[0, 0, 1]]}], 
            "\[Dagger]"],
           Editable->False],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
         DisplayForm], 
        StyleBox["\[CenterDot]",
         FontColor->RGBColor[0, 1, 0]], 
        TagBox[
         StyleBox[
          InterpretationBox[
           SubsuperscriptBox["c", 
            RowBox[{"1", 
             TagBox[
              StyleBox["\<\"\[DoubleUpArrow]\"\>",
               FontColor->RGBColor[1, 0, 0]],
              
              StyleForm[#, FontColor -> 
               RGBColor[1, 0, 0]]& ]}], "\<\"\[Dagger]\"\>"],
           Subsuperscript[Sneg`c, 
            RowBox[{1, 
              StyleForm["\[DoubleUpArrow]", FontColor -> RGBColor[1, 0, 0]]}],
             "\[Dagger]"],
           Editable->False],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
         DisplayForm], 
        StyleBox["\[CenterDot]",
         FontColor->RGBColor[0, 1, 0]], 
        TagBox[
         StyleBox[
          InterpretationBox[
           SubsuperscriptBox["c", 
            RowBox[{"1", 
             TagBox[
              StyleBox["\<\"\[DownArrow]\"\>",
               FontColor->RGBColor[0, 0, 1]],
              StyleForm[#, FontColor -> RGBColor[0, 0, 1]]& ]}], "\<\"\"\>"],
           Subsuperscript[Sneg`c, 
            RowBox[{1, 
              StyleForm["\[DownArrow]", FontColor -> RGBColor[0, 0, 1]]}], ""],
           Editable->False],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
         DisplayForm], 
        StyleBox["\[CenterDot]",
         FontColor->RGBColor[0, 1, 0]], 
        TagBox[
         StyleBox[
          InterpretationBox[
           SubsuperscriptBox["c", 
            RowBox[{"1", 
             TagBox[
              StyleBox["\<\"\[DoubleUpArrow]\"\>",
               FontColor->RGBColor[1, 0, 0]],
              StyleForm[#, FontColor -> RGBColor[1, 0, 0]]& ]}], "\<\"\"\>"],
           Subsuperscript[Sneg`c, 
            RowBox[{1, 
              StyleForm["\[DoubleUpArrow]", FontColor -> RGBColor[1, 0, 0]]}],
             ""],
           Editable->False],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
         DisplayForm]}], ")"}]}], "-", 
     RowBox[{
      TagBox[
       StyleBox[
        InterpretationBox[
         SubsuperscriptBox["c", 
          RowBox[{"2", 
           TagBox[
            StyleBox["\<\"\[DownArrow]\"\>",
             FontColor->RGBColor[0, 0, 1]],
            
            StyleForm[#, FontColor -> 
             RGBColor[0, 0, 1]]& ]}], "\<\"\[Dagger]\"\>"],
         Subsuperscript[Sneg`c, 
          RowBox[{2, 
            StyleForm["\[DownArrow]", FontColor -> RGBColor[0, 0, 1]]}], 
          "\[Dagger]"],
         Editable->False],
        ScriptSizeMultipliers->1,
        ScriptBaselineShifts->{1, 1}],
       DisplayForm], 
      StyleBox["\[CenterDot]",
       FontColor->RGBColor[0, 1, 0]], 
      TagBox[
       StyleBox[
        InterpretationBox[
         SubsuperscriptBox["c", 
          RowBox[{"2", 
           TagBox[
            StyleBox["\<\"\[DoubleUpArrow]\"\>",
             FontColor->RGBColor[1, 0, 0]],
            
            StyleForm[#, FontColor -> 
             RGBColor[1, 0, 0]]& ]}], "\<\"\[Dagger]\"\>"],
         Subsuperscript[Sneg`c, 
          RowBox[{2, 
            StyleForm["\[DoubleUpArrow]", FontColor -> RGBColor[1, 0, 0]]}], 
          "\[Dagger]"],
         Editable->False],
        ScriptSizeMultipliers->1,
        ScriptBaselineShifts->{1, 1}],
       DisplayForm], 
      StyleBox["\[CenterDot]",
       FontColor->RGBColor[0, 1, 0]], 
      TagBox[
       StyleBox[
        InterpretationBox[
         SubsuperscriptBox["c", 
          RowBox[{"2", 
           TagBox[
            StyleBox["\<\"\[DownArrow]\"\>",
             FontColor->RGBColor[0, 0, 1]],
            StyleForm[#, FontColor -> RGBColor[0, 0, 1]]& ]}], "\<\"\"\>"],
         Subsuperscript[Sneg`c, 
          RowBox[{2, 
            StyleForm["\[DownArrow]", FontColor -> RGBColor[0, 0, 1]]}], ""],
         Editable->False],
        ScriptSizeMultipliers->1,
        ScriptBaselineShifts->{1, 1}],
       DisplayForm], 
      StyleBox["\[CenterDot]",
       FontColor->RGBColor[0, 1, 0]], 
      TagBox[
       StyleBox[
        InterpretationBox[
         SubsuperscriptBox["c", 
          RowBox[{"2", 
           TagBox[
            StyleBox["\<\"\[DoubleUpArrow]\"\>",
             FontColor->RGBColor[1, 0, 0]],
            StyleForm[#, FontColor -> RGBColor[1, 0, 0]]& ]}], "\<\"\"\>"],
         Subsuperscript[Sneg`c, 
          RowBox[{2, 
            StyleForm["\[DoubleUpArrow]", FontColor -> RGBColor[1, 0, 0]]}], 
          ""],
         Editable->False],
        ScriptSizeMultipliers->1,
        ScriptBaselineShifts->{1, 1}],
       DisplayForm]}]}], ")"}]}]}]], "Output",
 CellChangeTimes->{3.509780646266118*^9, 3.509780705032426*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"MatrixForm", "[", 
  RowBox[{"b", "=", 
   RowBox[{"qsbasis", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"c", "[", "1", "]"}], ",", 
      RowBox[{"c", "[", "2", "]"}]}], "}"}], "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.509780433271616*^9, 3.509780645240891*^9}}],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "2"}], ",", "0"}], "}"}], 
      RowBox[{"{", "1", "}"}]},
     {
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "1"}], ",", 
        FractionBox["1", "2"]}], "}"}], 
      RowBox[{"{", 
       RowBox[{
        TagBox[
         StyleBox[
          InterpretationBox[
           SubsuperscriptBox["c", 
            RowBox[{"2", 
             TagBox[
              StyleBox["\<\"\[DoubleUpArrow]\"\>",
               FontColor->RGBColor[1, 0, 0]],
              
              StyleForm[#, FontColor -> 
               RGBColor[1, 0, 0]]& ]}], "\<\"\[Dagger]\"\>"],
           Subsuperscript[Sneg`c, 
            RowBox[{2, 
              StyleForm["\[DoubleUpArrow]", FontColor -> RGBColor[1, 0, 0]]}],
             "\[Dagger]"],
           Editable->False],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
         DisplayForm], ",", 
        TagBox[
         StyleBox[
          InterpretationBox[
           SubsuperscriptBox["c", 
            RowBox[{"1", 
             TagBox[
              StyleBox["\<\"\[DoubleUpArrow]\"\>",
               FontColor->RGBColor[1, 0, 0]],
              
              StyleForm[#, FontColor -> 
               RGBColor[1, 0, 0]]& ]}], "\<\"\[Dagger]\"\>"],
           Subsuperscript[Sneg`c, 
            RowBox[{1, 
              StyleForm["\[DoubleUpArrow]", FontColor -> RGBColor[1, 0, 0]]}],
             "\[Dagger]"],
           Editable->False],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
         DisplayForm]}], "}"}]},
     {
      RowBox[{"{", 
       RowBox[{"0", ",", "0"}], "}"}], 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         TagBox[
          StyleBox[
           InterpretationBox[
            SubsuperscriptBox["c", 
             RowBox[{"2", 
              TagBox[
               StyleBox["\<\"\[DownArrow]\"\>",
                FontColor->RGBColor[0, 0, 1]],
               
               StyleForm[#, FontColor -> 
                RGBColor[0, 0, 1]]& ]}], "\<\"\[Dagger]\"\>"],
            Subsuperscript[Sneg`c, 
             RowBox[{2, 
               StyleForm["\[DownArrow]", FontColor -> RGBColor[0, 0, 1]]}], 
             "\[Dagger]"],
            Editable->False],
           ScriptSizeMultipliers->1,
           ScriptBaselineShifts->{1, 1}],
          DisplayForm], 
         StyleBox["\[CenterDot]",
          FontColor->RGBColor[0, 1, 0]], 
         TagBox[
          StyleBox[
           InterpretationBox[
            SubsuperscriptBox["c", 
             RowBox[{"2", 
              TagBox[
               StyleBox["\<\"\[DoubleUpArrow]\"\>",
                FontColor->RGBColor[1, 0, 0]],
               
               StyleForm[#, FontColor -> 
                RGBColor[1, 0, 0]]& ]}], "\<\"\[Dagger]\"\>"],
            Subsuperscript[Sneg`c, 
             RowBox[{2, 
               StyleForm[
               "\[DoubleUpArrow]", FontColor -> RGBColor[1, 0, 0]]}], 
             "\[Dagger]"],
            Editable->False],
           ScriptSizeMultipliers->1,
           ScriptBaselineShifts->{1, 1}],
          DisplayForm]}], ",", 
        FractionBox[
         RowBox[{
          RowBox[{
           TagBox[
            StyleBox[
             InterpretationBox[
              SubsuperscriptBox["c", 
               RowBox[{"1", 
                TagBox[
                 StyleBox["\<\"\[DownArrow]\"\>",
                  FontColor->RGBColor[0, 0, 1]],
                 
                 StyleForm[#, FontColor -> 
                  RGBColor[0, 0, 1]]& ]}], "\<\"\[Dagger]\"\>"],
              Subsuperscript[Sneg`c, 
               RowBox[{1, 
                 StyleForm["\[DownArrow]", FontColor -> RGBColor[0, 0, 1]]}], 
               "\[Dagger]"],
              Editable->False],
             ScriptSizeMultipliers->1,
             ScriptBaselineShifts->{1, 1}],
            DisplayForm], 
           StyleBox["\[CenterDot]",
            FontColor->RGBColor[0, 1, 0]], 
           TagBox[
            StyleBox[
             InterpretationBox[
              SubsuperscriptBox["c", 
               RowBox[{"2", 
                TagBox[
                 StyleBox["\<\"\[DoubleUpArrow]\"\>",
                  FontColor->RGBColor[1, 0, 0]],
                 
                 StyleForm[#, FontColor -> 
                  RGBColor[1, 0, 0]]& ]}], "\<\"\[Dagger]\"\>"],
              Subsuperscript[Sneg`c, 
               RowBox[{2, 
                 StyleForm[
                 "\[DoubleUpArrow]", FontColor -> RGBColor[1, 0, 0]]}], 
               "\[Dagger]"],
              Editable->False],
             ScriptSizeMultipliers->1,
             ScriptBaselineShifts->{1, 1}],
            DisplayForm]}], "-", 
          RowBox[{
           TagBox[
            StyleBox[
             InterpretationBox[
              SubsuperscriptBox["c", 
               RowBox[{"1", 
                TagBox[
                 StyleBox["\<\"\[DoubleUpArrow]\"\>",
                  FontColor->RGBColor[1, 0, 0]],
                 
                 StyleForm[#, FontColor -> 
                  RGBColor[1, 0, 0]]& ]}], "\<\"\[Dagger]\"\>"],
              Subsuperscript[Sneg`c, 
               RowBox[{1, 
                 StyleForm[
                 "\[DoubleUpArrow]", FontColor -> RGBColor[1, 0, 0]]}], 
               "\[Dagger]"],
              Editable->False],
             ScriptSizeMultipliers->1,
             ScriptBaselineShifts->{1, 1}],
            DisplayForm], 
           StyleBox["\[CenterDot]",
            FontColor->RGBColor[0, 1, 0]], 
           TagBox[
            StyleBox[
             InterpretationBox[
              SubsuperscriptBox["c", 
               RowBox[{"2", 
                TagBox[
                 StyleBox["\<\"\[DownArrow]\"\>",
                  FontColor->RGBColor[0, 0, 1]],
                 
                 StyleForm[#, FontColor -> 
                  RGBColor[0, 0, 1]]& ]}], "\<\"\[Dagger]\"\>"],
              Subsuperscript[Sneg`c, 
               RowBox[{2, 
                 StyleForm["\[DownArrow]", FontColor -> RGBColor[0, 0, 1]]}], 
               "\[Dagger]"],
              Editable->False],
             ScriptSizeMultipliers->1,
             ScriptBaselineShifts->{1, 1}],
            DisplayForm]}]}], 
         SqrtBox["2"]], ",", 
        RowBox[{
         TagBox[
          StyleBox[
           InterpretationBox[
            SubsuperscriptBox["c", 
             RowBox[{"1", 
              TagBox[
               StyleBox["\<\"\[DownArrow]\"\>",
                FontColor->RGBColor[0, 0, 1]],
               
               StyleForm[#, FontColor -> 
                RGBColor[0, 0, 1]]& ]}], "\<\"\[Dagger]\"\>"],
            Subsuperscript[Sneg`c, 
             RowBox[{1, 
               StyleForm["\[DownArrow]", FontColor -> RGBColor[0, 0, 1]]}], 
             "\[Dagger]"],
            Editable->False],
           ScriptSizeMultipliers->1,
           ScriptBaselineShifts->{1, 1}],
          DisplayForm], 
         StyleBox["\[CenterDot]",
          FontColor->RGBColor[0, 1, 0]], 
         TagBox[
          StyleBox[
           InterpretationBox[
            SubsuperscriptBox["c", 
             RowBox[{"1", 
              TagBox[
               StyleBox["\<\"\[DoubleUpArrow]\"\>",
                FontColor->RGBColor[1, 0, 0]],
               
               StyleForm[#, FontColor -> 
                RGBColor[1, 0, 0]]& ]}], "\<\"\[Dagger]\"\>"],
            Subsuperscript[Sneg`c, 
             RowBox[{1, 
               StyleForm[
               "\[DoubleUpArrow]", FontColor -> RGBColor[1, 0, 0]]}], 
             "\[Dagger]"],
            Editable->False],
           ScriptSizeMultipliers->1,
           ScriptBaselineShifts->{1, 1}],
          DisplayForm]}]}], "}"}]},
     {
      RowBox[{"{", 
       RowBox[{"0", ",", "1"}], "}"}], 
      RowBox[{"{", 
       RowBox[{"-", 
        RowBox[{"(", 
         RowBox[{
          TagBox[
           StyleBox[
            InterpretationBox[
             SubsuperscriptBox["c", 
              RowBox[{"1", 
               TagBox[
                StyleBox["\<\"\[DoubleUpArrow]\"\>",
                 FontColor->RGBColor[1, 0, 0]],
                
                StyleForm[#, FontColor -> 
                 RGBColor[1, 0, 0]]& ]}], "\<\"\[Dagger]\"\>"],
             Subsuperscript[Sneg`c, 
              RowBox[{1, 
                StyleForm[
                "\[DoubleUpArrow]", FontColor -> RGBColor[1, 0, 0]]}], 
              "\[Dagger]"],
             Editable->False],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
           DisplayForm], 
          StyleBox["\[CenterDot]",
           FontColor->RGBColor[0, 1, 0]], 
          TagBox[
           StyleBox[
            InterpretationBox[
             SubsuperscriptBox["c", 
              RowBox[{"2", 
               TagBox[
                StyleBox["\<\"\[DoubleUpArrow]\"\>",
                 FontColor->RGBColor[1, 0, 0]],
                
                StyleForm[#, FontColor -> 
                 RGBColor[1, 0, 0]]& ]}], "\<\"\[Dagger]\"\>"],
             Subsuperscript[Sneg`c, 
              RowBox[{2, 
                StyleForm[
                "\[DoubleUpArrow]", FontColor -> RGBColor[1, 0, 0]]}], 
              "\[Dagger]"],
             Editable->False],
            ScriptSizeMultipliers->1,
            ScriptBaselineShifts->{1, 1}],
           DisplayForm]}], ")"}]}], "}"}]},
     {
      RowBox[{"{", 
       RowBox[{"1", ",", 
        FractionBox["1", "2"]}], "}"}], 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         TagBox[
          StyleBox[
           InterpretationBox[
            SubsuperscriptBox["c", 
             RowBox[{"1", 
              TagBox[
               StyleBox["\<\"\[DoubleUpArrow]\"\>",
                FontColor->RGBColor[1, 0, 0]],
               
               StyleForm[#, FontColor -> 
                RGBColor[1, 0, 0]]& ]}], "\<\"\[Dagger]\"\>"],
            Subsuperscript[Sneg`c, 
             RowBox[{1, 
               StyleForm[
               "\[DoubleUpArrow]", FontColor -> RGBColor[1, 0, 0]]}], 
             "\[Dagger]"],
            Editable->False],
           ScriptSizeMultipliers->1,
           ScriptBaselineShifts->{1, 1}],
          DisplayForm], 
         StyleBox["\[CenterDot]",
          FontColor->RGBColor[0, 1, 0]], 
         TagBox[
          StyleBox[
           InterpretationBox[
            SubsuperscriptBox["c", 
             RowBox[{"2", 
              TagBox[
               StyleBox["\<\"\[DownArrow]\"\>",
                FontColor->RGBColor[0, 0, 1]],
               
               StyleForm[#, FontColor -> 
                RGBColor[0, 0, 1]]& ]}], "\<\"\[Dagger]\"\>"],
            Subsuperscript[Sneg`c, 
             RowBox[{2, 
               StyleForm["\[DownArrow]", FontColor -> RGBColor[0, 0, 1]]}], 
             "\[Dagger]"],
            Editable->False],
           ScriptSizeMultipliers->1,
           ScriptBaselineShifts->{1, 1}],
          DisplayForm], 
         StyleBox["\[CenterDot]",
          FontColor->RGBColor[0, 1, 0]], 
         TagBox[
          StyleBox[
           InterpretationBox[
            SubsuperscriptBox["c", 
             RowBox[{"2", 
              TagBox[
               StyleBox["\<\"\[DoubleUpArrow]\"\>",
                FontColor->RGBColor[1, 0, 0]],
               
               StyleForm[#, FontColor -> 
                RGBColor[1, 0, 0]]& ]}], "\<\"\[Dagger]\"\>"],
            Subsuperscript[Sneg`c, 
             RowBox[{2, 
               StyleForm[
               "\[DoubleUpArrow]", FontColor -> RGBColor[1, 0, 0]]}], 
             "\[Dagger]"],
            Editable->False],
           ScriptSizeMultipliers->1,
           ScriptBaselineShifts->{1, 1}],
          DisplayForm]}], ",", 
        RowBox[{
         TagBox[
          StyleBox[
           InterpretationBox[
            SubsuperscriptBox["c", 
             RowBox[{"1", 
              TagBox[
               StyleBox["\<\"\[DownArrow]\"\>",
                FontColor->RGBColor[0, 0, 1]],
               
               StyleForm[#, FontColor -> 
                RGBColor[0, 0, 1]]& ]}], "\<\"\[Dagger]\"\>"],
            Subsuperscript[Sneg`c, 
             RowBox[{1, 
               StyleForm["\[DownArrow]", FontColor -> RGBColor[0, 0, 1]]}], 
             "\[Dagger]"],
            Editable->False],
           ScriptSizeMultipliers->1,
           ScriptBaselineShifts->{1, 1}],
          DisplayForm], 
         StyleBox["\[CenterDot]",
          FontColor->RGBColor[0, 1, 0]], 
         TagBox[
          StyleBox[
           InterpretationBox[
            SubsuperscriptBox["c", 
             RowBox[{"1", 
              TagBox[
               StyleBox["\<\"\[DoubleUpArrow]\"\>",
                FontColor->RGBColor[1, 0, 0]],
               
               StyleForm[#, FontColor -> 
                RGBColor[1, 0, 0]]& ]}], "\<\"\[Dagger]\"\>"],
            Subsuperscript[Sneg`c, 
             RowBox[{1, 
               StyleForm[
               "\[DoubleUpArrow]", FontColor -> RGBColor[1, 0, 0]]}], 
             "\[Dagger]"],
            Editable->False],
           ScriptSizeMultipliers->1,
           ScriptBaselineShifts->{1, 1}],
          DisplayForm], 
         StyleBox["\[CenterDot]",
          FontColor->RGBColor[0, 1, 0]], 
         TagBox[
          StyleBox[
           InterpretationBox[
            SubsuperscriptBox["c", 
             RowBox[{"2", 
              TagBox[
               StyleBox["\<\"\[DoubleUpArrow]\"\>",
                FontColor->RGBColor[1, 0, 0]],
               
               StyleForm[#, FontColor -> 
                RGBColor[1, 0, 0]]& ]}], "\<\"\[Dagger]\"\>"],
            Subsuperscript[Sneg`c, 
             RowBox[{2, 
               StyleForm[
               "\[DoubleUpArrow]", FontColor -> RGBColor[1, 0, 0]]}], 
             "\[Dagger]"],
            Editable->False],
           ScriptSizeMultipliers->1,
           ScriptBaselineShifts->{1, 1}],
          DisplayForm]}]}], "}"}]},
     {
      RowBox[{"{", 
       RowBox[{"2", ",", "0"}], "}"}], 
      RowBox[{"{", 
       RowBox[{
        TagBox[
         StyleBox[
          InterpretationBox[
           SubsuperscriptBox["c", 
            RowBox[{"1", 
             TagBox[
              StyleBox["\<\"\[DownArrow]\"\>",
               FontColor->RGBColor[0, 0, 1]],
              
              StyleForm[#, FontColor -> 
               RGBColor[0, 0, 1]]& ]}], "\<\"\[Dagger]\"\>"],
           Subsuperscript[Sneg`c, 
            RowBox[{1, 
              StyleForm["\[DownArrow]", FontColor -> RGBColor[0, 0, 1]]}], 
            "\[Dagger]"],
           Editable->False],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
         DisplayForm], 
        StyleBox["\[CenterDot]",
         FontColor->RGBColor[0, 1, 0]], 
        TagBox[
         StyleBox[
          InterpretationBox[
           SubsuperscriptBox["c", 
            RowBox[{"1", 
             TagBox[
              StyleBox["\<\"\[DoubleUpArrow]\"\>",
               FontColor->RGBColor[1, 0, 0]],
              
              StyleForm[#, FontColor -> 
               RGBColor[1, 0, 0]]& ]}], "\<\"\[Dagger]\"\>"],
           Subsuperscript[Sneg`c, 
            RowBox[{1, 
              StyleForm["\[DoubleUpArrow]", FontColor -> RGBColor[1, 0, 0]]}],
             "\[Dagger]"],
           Editable->False],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
         DisplayForm], 
        StyleBox["\[CenterDot]",
         FontColor->RGBColor[0, 1, 0]], 
        TagBox[
         StyleBox[
          InterpretationBox[
           SubsuperscriptBox["c", 
            RowBox[{"2", 
             TagBox[
              StyleBox["\<\"\[DownArrow]\"\>",
               FontColor->RGBColor[0, 0, 1]],
              
              StyleForm[#, FontColor -> 
               RGBColor[0, 0, 1]]& ]}], "\<\"\[Dagger]\"\>"],
           Subsuperscript[Sneg`c, 
            RowBox[{2, 
              StyleForm["\[DownArrow]", FontColor -> RGBColor[0, 0, 1]]}], 
            "\[Dagger]"],
           Editable->False],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
         DisplayForm], 
        StyleBox["\[CenterDot]",
         FontColor->RGBColor[0, 1, 0]], 
        TagBox[
         StyleBox[
          InterpretationBox[
           SubsuperscriptBox["c", 
            RowBox[{"2", 
             TagBox[
              StyleBox["\<\"\[DoubleUpArrow]\"\>",
               FontColor->RGBColor[1, 0, 0]],
              
              StyleForm[#, FontColor -> 
               RGBColor[1, 0, 0]]& ]}], "\<\"\[Dagger]\"\>"],
           Subsuperscript[Sneg`c, 
            RowBox[{2, 
              StyleForm["\[DoubleUpArrow]", FontColor -> RGBColor[1, 0, 0]]}],
             "\[Dagger]"],
           Editable->False],
          ScriptSizeMultipliers->1,
          ScriptBaselineShifts->{1, 1}],
         DisplayForm]}], "}"}]}
    },
    GridBoxAlignment->{
     "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{{3.509780628846278*^9, 3.5097806468931723`*^9}, 
   3.5097807050825043`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"m", "=", 
   RowBox[{"makematricesbzop", "[", 
    RowBox[{"H", ",", "b"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"MatrixForm", "@", 
  RowBox[{"Map", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"First", "[", "#", "]"}], ",", 
       RowBox[{"MatrixForm", "[", 
        RowBox[{"Last", "[", "#", "]"}], "]"}]}], "}"}], "&"}], ",", "m"}], 
   "]"}]}]}], "Input",
 CellChangeTimes->{{3.509780433271616*^9, 3.509780657274465*^9}}],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "2"}], ",", "0"}], "}"}], 
      TagBox[
       RowBox[{"(", "\[NoBreak]", GridBox[{
          {"0"}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.7]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
       Function[BoxForm`e$, 
        MatrixForm[BoxForm`e$]]]},
     {
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "1"}], ",", 
        FractionBox["1", "2"]}], "}"}], 
      TagBox[
       RowBox[{"(", "\[NoBreak]", GridBox[{
          {"\[Epsilon]", "t"},
          {"t", "\[Epsilon]"}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.7]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
       Function[BoxForm`e$, 
        MatrixForm[BoxForm`e$]]]},
     {
      RowBox[{"{", 
       RowBox[{"0", ",", "0"}], "}"}], 
      TagBox[
       RowBox[{"(", "\[NoBreak]", GridBox[{
          {
           RowBox[{"U", "+", 
            RowBox[{"2", " ", "\[Epsilon]"}]}], 
           RowBox[{
            SqrtBox["2"], " ", "t"}], "0"},
          {
           RowBox[{
            SqrtBox["2"], " ", "t"}], 
           RowBox[{"2", " ", "\[Epsilon]"}], 
           RowBox[{
            SqrtBox["2"], " ", "t"}]},
          {"0", 
           RowBox[{
            SqrtBox["2"], " ", "t"}], 
           RowBox[{"U", "+", 
            RowBox[{"2", " ", "\[Epsilon]"}]}]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.7]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
       Function[BoxForm`e$, 
        MatrixForm[BoxForm`e$]]]},
     {
      RowBox[{"{", 
       RowBox[{"0", ",", "1"}], "}"}], 
      TagBox[
       RowBox[{"(", "\[NoBreak]", GridBox[{
          {
           RowBox[{"2", " ", "\[Epsilon]"}]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.7]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
       Function[BoxForm`e$, 
        MatrixForm[BoxForm`e$]]]},
     {
      RowBox[{"{", 
       RowBox[{"1", ",", 
        FractionBox["1", "2"]}], "}"}], 
      TagBox[
       RowBox[{"(", "\[NoBreak]", GridBox[{
          {
           RowBox[{"U", "+", 
            RowBox[{"3", " ", "\[Epsilon]"}]}], 
           RowBox[{"-", "t"}]},
          {
           RowBox[{"-", "t"}], 
           RowBox[{"U", "+", 
            RowBox[{"3", " ", "\[Epsilon]"}]}]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.7]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
       Function[BoxForm`e$, 
        MatrixForm[BoxForm`e$]]]},
     {
      RowBox[{"{", 
       RowBox[{"2", ",", "0"}], "}"}], 
      TagBox[
       RowBox[{"(", "\[NoBreak]", GridBox[{
          {
           RowBox[{"2", " ", 
            RowBox[{"(", 
             RowBox[{"U", "+", 
              RowBox[{"2", " ", "\[Epsilon]"}]}], ")"}]}]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.7]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
       Function[BoxForm`e$, 
        MatrixForm[BoxForm`e$]]]}
    },
    GridBoxAlignment->{
     "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{{3.5097805593398657`*^9, 3.5097806157429*^9}, 
   3.5097806584488277`*^9, 3.509780705510508*^9}]
}, Open  ]]
},
WindowSize->{828, 895},
WindowMargins->{{4, Automatic}, {Automatic, 4}},
FrontEndVersion->"8.0 for Mac OS X x86 (32-bit, 64-bit Kernel) (November 6, \
2010)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[557, 20, 285, 6, 57, "Text"],
Cell[CellGroupData[{
Cell[867, 30, 415, 10, 58, "Input"],
Cell[1285, 42, 137, 1, 20, "Print"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1459, 48, 735, 22, 27, "Input"],
Cell[2197, 72, 15813, 477, 64, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[18047, 554, 302, 8, 27, "Input"],
Cell[18352, 564, 17615, 513, 181, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[36004, 1082, 510, 15, 43, "Input"],
Cell[36517, 1099, 5818, 163, 203, "Output"]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
